/////////////////////////////////////////////////////////////////////////////
// Name:        devdjcdlg.cpp
// Purpose:     Implement GUI for DJ Console Dialog.
// Author:      Yann Hamiaux
// Modified by: -
// Created:     02/15/2008
// Copyright:   Written for Guillemot Corporation by Yann Hamiaux
// Licence:     The GNU General Public License v2+.
/////////////////////////////////////////////////////////////////////////////
#include "devdjcdlg.h"
#include "localization.h"

extern CLocalization	g_LOCALIZATION;


CDevDjcDlg::CDevDjcDlg( wxMemoryDC *pSkinMemDC, wxMemoryDC *pSkinAlphaMemDC ) : 
	CGDialog(pSkinMemDC, pSkinAlphaMemDC, 546, 347)
{
	CHECKBOX_STATE_INFO	checkboxInfo[2];
	BUTTON_STATE_INFO	buttonInfo[3];
	STATIC_STATE_INFO	staticInfo[2];
	SLIDER_INFO		sliderInfo;
	COMBO_INFO		comboInfo;
	CGControl		*pCtrl;
	CGStaticText	   	*pStatic;
	CGStatic		*pStaticImg;
	CGSlider		*pSlider;
	CGCheckBox		*pCheckBox;
	CGComboBox		*pComboBox;
	int			i;
	bool			bModeTest, bAboutTest;
	char			szText[512];

	// --- Hercules Logo ---
	for(i=0;i<4;++i)
		buttonInfo[0].coordinates[i].y = 0;
	buttonInfo[0].nProcessAlpha = FALSE;
	buttonInfo[0].coordinates[0].x = 547;
	buttonInfo[0].coordinates[1].x = 547;
	buttonInfo[0].coordinates[2].x = 626;
	buttonInfo[0].coordinates[3].x = 705;

	pCtrl = (CGControl *) new CGButton(&m_eventList, IDC_DJC_HERCULES_LOGO, 
		237,283,78,55,m_pSkinMemDC, m_pSkinAlphaMemDC, 1, buttonInfo);
	AddControl(pCtrl);

	// --- Speaker Background ---
	staticInfo[0].nProcessAlpha = FALSE;
	staticInfo[0].x = 547;
	staticInfo[0].y = 56;
	pCtrl = (CGControl *) new CGStatic(&m_eventList, IDC_DJC_SPK_BACKGROUND, 
		84,129,113,109,m_pSkinMemDC, m_pSkinAlphaMemDC, 1, staticInfo);
	AddControl(pCtrl);

	// --- Speaker Front Left ---
	staticInfo[0].x = 349;
	staticInfo[0].y = 414;
	pCtrl = (CGControl *) new CGStatic(&m_eventList, IDC_DJC_SPK_LEFT, 
		89,134,22,22,m_pSkinMemDC, m_pSkinAlphaMemDC, 1, staticInfo);
	AddControl(pCtrl);

	// --- Speaker Center ---
	staticInfo[0].x = 349;
	staticInfo[0].y = 437;
	pCtrl = (CGControl *) new CGStatic(&m_eventList, IDC_DJC_SPK_TOP, 
		127,132,26,15,m_pSkinMemDC, m_pSkinAlphaMemDC, 1, staticInfo);
	AddControl(pCtrl);

	// --- Speaker Front Right ---
	staticInfo[0].x = 349;
	staticInfo[0].y = 453;
	pCtrl = (CGControl *) new CGStatic(&m_eventList, IDC_DJC_SPK_RIGHT, 
		170,134,23,22,m_pSkinMemDC, m_pSkinAlphaMemDC, 1, staticInfo);
	AddControl(pCtrl);

	// --- Speaker Surround Left ---
	staticInfo[0].x = 565;
	staticInfo[0].y = 410;
	pCtrl = (CGControl *) new CGStatic(&m_eventList, IDC_DJC_SPK_SLEFT, 
		86,195,16,25,m_pSkinMemDC, m_pSkinAlphaMemDC, 1, staticInfo);
	AddControl(pCtrl);

	// --- Speaker Surround Right ---
	staticInfo[0].x = 565;
	staticInfo[0].y = 436;
	pCtrl = (CGControl *) new CGStatic(&m_eventList, IDC_DJC_SPK_SRIGHT, 
		180,195,16,25,m_pSkinMemDC, m_pSkinAlphaMemDC, 1, staticInfo);
	AddControl(pCtrl);

	// --- Speaker LFE ---
	staticInfo[0].x = 565;
	staticInfo[0].y = 462;
	pCtrl = (CGControl *) new CGStatic(&m_eventList, IDC_DJC_SPK_LFE, 
		93,168,22,13,m_pSkinMemDC, m_pSkinAlphaMemDC, 1, staticInfo);
	AddControl(pCtrl);

	// --- Speaker 1 ---
	staticInfo[0].x = 755;
	staticInfo[0].y = 184;
	pCtrl = (CGControl *) new CGStatic(&m_eventList, IDC_DJC_SPK_ID_1, 
		42,120,13,15,m_pSkinMemDC, m_pSkinAlphaMemDC, 1, staticInfo);
	AddControl(pCtrl);

	// --- Speaker 2 ---
	staticInfo[0].x = 769;
	staticInfo[0].y = 184;
	pCtrl = (CGControl *) new CGStatic(&m_eventList, IDC_DJC_SPK_ID_2, 
		228,120,10,13,m_pSkinMemDC, m_pSkinAlphaMemDC, 1, staticInfo);
	AddControl(pCtrl);

	// --- Speaker 3 ---
	staticInfo[0].x = 780;
	staticInfo[0].y = 184;
	pCtrl = (CGControl *) new CGStatic(&m_eventList, IDC_DJC_SPK_ID_3, 
		117,96,13,14,m_pSkinMemDC, m_pSkinAlphaMemDC, 1, staticInfo);
	AddControl(pCtrl);

	// --- Speaker 4 ---
	staticInfo[0].x = 755;
	staticInfo[0].y = 200;
	pCtrl = (CGControl *) new CGStatic(&m_eventList, IDC_DJC_SPK_ID_4, 
		42,171,12,13,m_pSkinMemDC, m_pSkinAlphaMemDC, 1, staticInfo);
	AddControl(pCtrl);

	// --- Speaker 5 ---
	staticInfo[0].x = 768;
	staticInfo[0].y = 200;
	pCtrl = (CGControl *) new CGStatic(&m_eventList, IDC_DJC_SPK_ID_5, 
		42,223,12,14,m_pSkinMemDC, m_pSkinAlphaMemDC, 1, staticInfo);
	AddControl(pCtrl);

	// --- Speaker 6 ---
	staticInfo[0].x = 781;
	staticInfo[0].y = 200;
	pCtrl = (CGControl *) new CGStatic(&m_eventList, IDC_DJC_SPK_ID_6, 
		228,225,11,12,m_pSkinMemDC, m_pSkinAlphaMemDC, 1, staticInfo);
	AddControl(pCtrl);

	// --- Prepare Mini Sliders ---
	for(i=0;i<4;++i) {
		sliderInfo.coordinates[i].x = 679;
		sliderInfo.coordinates[i].y = 56;
		sliderInfo.coordinates[i].x_highlight = 715;
		sliderInfo.coordinates[i].y_highlight = 56;
		sliderInfo.coordinates[i].thumb_x = 749;
		sliderInfo.coordinates[i].thumb_y = 56;
		sliderInfo.coordinates[i].thumb_w = 15;
		sliderInfo.coordinates[i].thumb_h = 4;
	}
	sliderInfo.coordinates[0].x = 661;
	sliderInfo.coordinates[0].y = 56;
	sliderInfo.coordinates[0].x_highlight = 697;
	sliderInfo.coordinates[0].y_highlight = 56;
	sliderInfo.coordinates[0].thumb_x = 733;
	sliderInfo.coordinates[0].thumb_y = 56;
	sliderInfo.nThumbOffsetX = 0;
	sliderInfo.nThumbOffsetY = 0;
	sliderInfo.nProcessAlpha = FALSE;
	sliderInfo.nHorizontal = FALSE;
	sliderInfo.nBorderSizeAtMin = 3;
	sliderInfo.nBorderSizeAtMax = 3;

	// --- Mini Slider Volume 1 ---
	pSlider = new CGSlider(&m_eventList, IDC_DJC_SPK_MINI_VOL_1, 58, 112, 17, 36, 
		m_pSkinMemDC, m_pSkinAlphaMemDC, &sliderInfo);
	pSlider->SetRange(0, 0xFF);
	AddControl((CGControl *) pSlider);

	// --- Mini Slider Volume 2 ---
	pSlider = new CGSlider(&m_eventList, IDC_DJC_SPK_MINI_VOL_2, 205, 112, 17, 36, 
		m_pSkinMemDC, m_pSkinAlphaMemDC, &sliderInfo);
	pSlider->SetRange(0, 0xFF);
	AddControl((CGControl *) pSlider);

	// --- Mini Slider Volume 3 ---
	pSlider = new CGSlider(&m_eventList, IDC_DJC_SPK_MINI_VOL_3, 132, 88, 17, 36, 
		m_pSkinMemDC, m_pSkinAlphaMemDC, &sliderInfo);
	pSlider->SetRange(0, 0xFF);
	AddControl((CGControl *) pSlider);

	// --- Mini Slider Volume 4 ---
	pSlider = new CGSlider(&m_eventList, IDC_DJC_SPK_MINI_VOL_4, 58, 161, 17, 36, 
		m_pSkinMemDC, m_pSkinAlphaMemDC, &sliderInfo);
	pSlider->SetRange(0, 0xFF);
	AddControl((CGControl *) pSlider);

	// --- Mini Slider Volume 5 ---
	pSlider = new CGSlider(&m_eventList, IDC_DJC_SPK_MINI_VOL_5, 58, 214, 17, 36, 
		m_pSkinMemDC, m_pSkinAlphaMemDC, &sliderInfo);
	pSlider->SetRange(0, 0xFF);
	AddControl((CGControl *) pSlider);

	// --- Mini Slider Volume 6 ---
	pSlider = new CGSlider(&m_eventList, IDC_DJC_SPK_MINI_VOL_6, 205, 214, 17, 36, 
		m_pSkinMemDC, m_pSkinAlphaMemDC, &sliderInfo);
	pSlider->SetRange(0, 0xFF);
	AddControl((CGControl *) pSlider);

	// --- Mini Slider - Talkover Attenuation ---
	pSlider = new CGSlider(&m_eventList, IDC_DJC_TALK_ATTENUATION_SLIDER, 348, 267, 17, 36, 
		m_pSkinMemDC, m_pSkinAlphaMemDC, &sliderInfo);
	pSlider->SetRange(0, 2);
	AddControl((CGControl *) pSlider);

	// --- Prepare Master Slider ---
	for(i=0;i<4;++i) {
		sliderInfo.coordinates[i].x = 573;
		sliderInfo.coordinates[i].y = 166;
		sliderInfo.coordinates[i].x_highlight = 625;
		sliderInfo.coordinates[i].y_highlight = 166;
		sliderInfo.coordinates[i].thumb_x = 673;
		sliderInfo.coordinates[i].thumb_y = 166;
		sliderInfo.coordinates[i].thumb_w = 21;
		sliderInfo.coordinates[i].thumb_h = 8;
	}
	sliderInfo.coordinates[0].x = 547;
	sliderInfo.coordinates[0].y = 166;
	sliderInfo.coordinates[0].x_highlight = 599;
	sliderInfo.coordinates[0].y_highlight = 166;
	sliderInfo.coordinates[0].thumb_x = 651;
	sliderInfo.coordinates[0].thumb_y = 166;
	sliderInfo.nThumbOffsetX = 0;
	sliderInfo.nThumbOffsetY = 0;
	sliderInfo.nProcessAlpha = FALSE;
	sliderInfo.nHorizontal = FALSE;
	sliderInfo.nBorderSizeAtMin = 3;
	sliderInfo.nBorderSizeAtMax = 3;

	// --- Master Slider ---
	pSlider = new CGSlider(&m_eventList, IDC_DJC_SPK_MASTER_VOL, 263, 99, 25, 116, 
		m_pSkinMemDC, m_pSkinAlphaMemDC, &sliderInfo);
	pSlider->SetRange(0, 0xFF);
	AddControl((CGControl *) pSlider);

	// --- Prepare Mode Slider ---
	for(i=0;i<4;++i) {
		sliderInfo.coordinates[i].x = 687;
		sliderInfo.coordinates[i].y = 126;
		sliderInfo.coordinates[i].x_highlight = 687;
		sliderInfo.coordinates[i].y_highlight = 126;
		sliderInfo.coordinates[i].thumb_x = 723;
		sliderInfo.coordinates[i].thumb_y = 126;
		sliderInfo.coordinates[i].thumb_w = 9;
		sliderInfo.coordinates[i].thumb_h = 9;
	}
	sliderInfo.coordinates[0].x = 661;
	sliderInfo.coordinates[0].y = 126;
	sliderInfo.coordinates[0].x_highlight = 661;
	sliderInfo.coordinates[0].y_highlight = 126;
	sliderInfo.coordinates[0].thumb_x = 713;
	sliderInfo.coordinates[0].thumb_y = 126;
	sliderInfo.nThumbOffsetX = 0;
	sliderInfo.nThumbOffsetY = 0;
	sliderInfo.nProcessAlpha = TRUE;
	sliderInfo.nHorizontal = TRUE;
	sliderInfo.nBorderSizeAtMin = 1;
	sliderInfo.nBorderSizeAtMax = 1;

	// --- DJ Mode Slider ---
	pSlider = new CGSlider(&m_eventList, IDC_DJC_DJ_MODE, 119, 52, 25, 12, 
		m_pSkinMemDC, m_pSkinAlphaMemDC, &sliderInfo);
	pSlider->SetRange(0, 1);
	pSlider->AddToolTips(g_LOCALIZATION.GetString(IDS_DJCONSOLE_MODE_TTIPS));
	AddControl((CGControl *) pSlider);

	// --- Sampling Rate Slider ---
	pSlider = new CGSlider(&m_eventList, IDC_DJC_SAMP_RATE, 406, 52, 25, 12, 
		m_pSkinMemDC, m_pSkinAlphaMemDC, &sliderInfo);
	pSlider->SetRange(0, 1);
	pSlider->AddToolTips(g_LOCALIZATION.GetString(IDS_SAMPLE_RATE_TTIPS));
	AddControl((CGControl *) pSlider);

	// --- Prepare Dual Channel Volume Slider ---
	for(i=0;i<4;++i) {
		sliderInfo.coordinates[i].x = 677;
		sliderInfo.coordinates[i].y = 175;
		sliderInfo.coordinates[i].x_highlight = 729;
		sliderInfo.coordinates[i].y_highlight = 175;
		sliderInfo.coordinates[i].thumb_x = 777;
		sliderInfo.coordinates[i].thumb_y = 175;
		sliderInfo.coordinates[i].thumb_w = 21;
		sliderInfo.coordinates[i].thumb_h = 8;
	}
	sliderInfo.coordinates[0].x = 651;
	sliderInfo.coordinates[0].y = 175;
	sliderInfo.coordinates[0].x_highlight = 703;
	sliderInfo.coordinates[0].y_highlight = 175;
	sliderInfo.coordinates[0].thumb_x = 755;
	sliderInfo.coordinates[0].thumb_y = 175;
	sliderInfo.nThumbOffsetX = 0;
	sliderInfo.nThumbOffsetY = 0;
	sliderInfo.nProcessAlpha = FALSE;
	sliderInfo.nHorizontal = FALSE;
	sliderInfo.nBorderSizeAtMin = 3;
	sliderInfo.nBorderSizeAtMax = 3;

	// --- Volume 1-2 Slider ---
	pSlider = new CGSlider(&m_eventList, IDC_DJC_VOL12, 65, 140, 25, 90, 
		m_pSkinMemDC, m_pSkinAlphaMemDC, &sliderInfo);
	pSlider->SetRange(0, 0xFF);
	AddControl((CGControl *) pSlider);

	// --- Volume 3-4 Slider ---
	pSlider = new CGSlider(&m_eventList, IDC_DJC_VOL34, 140, 140, 25, 90, 
		m_pSkinMemDC, m_pSkinAlphaMemDC, &sliderInfo);
	pSlider->SetRange(0, 0xFF);
	AddControl((CGControl *) pSlider);

	// --- Volume 5-6 Slider ---
	pSlider = new CGSlider(&m_eventList, IDC_DJC_VOL56, 215, 140, 25, 90, 
		m_pSkinMemDC, m_pSkinAlphaMemDC, &sliderInfo);
	pSlider->SetRange(0, 0xFF);
	AddControl((CGControl *) pSlider);

	// --- Prepare Dual Channel Balance Slider ---
	for(i=0;i<4;++i) {
		sliderInfo.coordinates[i].x = 697;
		sliderInfo.coordinates[i].y = 93;
		sliderInfo.coordinates[i].x_highlight = 697;
		sliderInfo.coordinates[i].y_highlight = 93;
		sliderInfo.coordinates[i].thumb_x = 739;
		sliderInfo.coordinates[i].thumb_y = 93;
		sliderInfo.coordinates[i].thumb_w = 5;
		sliderInfo.coordinates[i].thumb_h = 14;
	}
	sliderInfo.coordinates[0].x = 661;
	sliderInfo.coordinates[0].y = 93;
	sliderInfo.coordinates[0].x_highlight = 661;
	sliderInfo.coordinates[0].y_highlight = 93;
	sliderInfo.coordinates[0].thumb_x = 733;
	sliderInfo.coordinates[0].thumb_y = 93;
	sliderInfo.nThumbOffsetX = 0;
	sliderInfo.nThumbOffsetY = 0;
	sliderInfo.nProcessAlpha = FALSE;
	sliderInfo.nHorizontal = TRUE;
	sliderInfo.nBorderSizeAtMin = 3;
	sliderInfo.nBorderSizeAtMax = 3;

	// --- Balance 1-2 Slider ---
	pSlider = new CGSlider(&m_eventList, IDC_DJC_BAL12, 60, 117, 35, 16, 
		m_pSkinMemDC, m_pSkinAlphaMemDC, &sliderInfo);
	pSlider->SetRange(0, 0xFF);
	AddControl((CGControl *) pSlider);

	// --- Balance 3-4 Slider ---
	pSlider = new CGSlider(&m_eventList, IDC_DJC_BAL34, 135, 117, 35, 16, 
		m_pSkinMemDC, m_pSkinAlphaMemDC, &sliderInfo);
	pSlider->SetRange(0, 0xFF);
	AddControl((CGControl *) pSlider);

	// --- Balance 5-6 Slider ---
	pSlider = new CGSlider(&m_eventList, IDC_DJC_BAL56, 210, 117, 35, 16, 
		m_pSkinMemDC, m_pSkinAlphaMemDC, &sliderInfo);
	pSlider->SetRange(0, 0xFF);
	AddControl((CGControl *) pSlider);

	// --- Prepare CheckBox ---
	for(i=0;i<4;++i) {
		checkboxInfo[0].coordinates[i].y = 110;
		checkboxInfo[1].coordinates[i].y = 110;

		checkboxInfo[0].coordinates[i].r = 0;
		checkboxInfo[0].coordinates[i].g = 0;
		checkboxInfo[0].coordinates[i].b = 0;
		checkboxInfo[1].coordinates[i].r = 0;
		checkboxInfo[1].coordinates[i].g = 0;
		checkboxInfo[1].coordinates[i].b = 0;
	}
	checkboxInfo[0].coordinates[0].r = 90;
	checkboxInfo[0].coordinates[0].g = 90;
	checkboxInfo[0].coordinates[0].b = 90;
	checkboxInfo[1].coordinates[0].r = 90;
	checkboxInfo[1].coordinates[0].g = 90;
	checkboxInfo[1].coordinates[0].b = 90;

	checkboxInfo[0].coordinates[0].x = 661;
	checkboxInfo[0].coordinates[1].x = 677;
	checkboxInfo[0].coordinates[2].x = 693;
	checkboxInfo[0].coordinates[3].x = 709;
	checkboxInfo[1].coordinates[0].x = 725;
	checkboxInfo[1].coordinates[1].x = 741;
	checkboxInfo[1].coordinates[2].x = 757;
	checkboxInfo[1].coordinates[3].x = 773;
	checkboxInfo[0].nProcessAlpha = FALSE;
	checkboxInfo[1].nProcessAlpha = FALSE;

	// --- DJ Mouse ---
	pCheckBox = new CGCheckBox(&m_eventList, IDC_DJC_CHECKBOX_DJ_MOUSE, 
		35, 290, 15, 15, g_LOCALIZATION.GetString(IDS_DJ_MOUSE), 
		135, 15, m_pSkinMemDC, m_pSkinAlphaMemDC, 2, checkboxInfo, ALIGN_LEFT|VALIGN_TOP);
	AddControl((CGControl *) pCheckBox);

	// --- Talkover Attenuation ---
	pCheckBox = new CGCheckBox(&m_eventList, IDC_DJC_CHECKBOX_TALKOVER_ATT, 
		321, 224, 15, 15, g_LOCALIZATION.GetString(IDS_TALKOVER_ATT),
		160, 15, m_pSkinMemDC, m_pSkinAlphaMemDC, 2, checkboxInfo, ALIGN_LEFT|VALIGN_TOP);
	pCheckBox->AddToolTips(g_LOCALIZATION.GetString(IDS_TALKOVER_ATT_TTIPS));
	AddControl((CGControl *) pCheckBox);

	// --- On Air Status ---
	staticInfo[0].x = 708;
	staticInfo[0].y = 266;
	staticInfo[0].nProcessAlpha = FALSE;
	staticInfo[1].x = 708;
	staticInfo[1].y = 289;
	staticInfo[1].nProcessAlpha = FALSE;

	pStaticImg = new CGStatic(&m_eventList, IDC_DJC_ON_AIR_STATUS, 
		415,273,74,22, m_pSkinMemDC, m_pSkinAlphaMemDC, 2, staticInfo);
	AddControl((CGControl *) pStaticImg);

	// --- Headphone Selection Button ---
	for(i=0;i<2;++i) {
		buttonInfo[i].nProcessAlpha = TRUE;
	}
	for(i=0;i<4;++i) {
		buttonInfo[0].coordinates[i].y = 348;
		buttonInfo[1].coordinates[i].y = 381;
	}
	for(i=0;i<2;++i) {
		buttonInfo[i].coordinates[0].x = 349;
		buttonInfo[i].coordinates[1].x = 385;
		buttonInfo[i].coordinates[2].x = 421;
		buttonInfo[i].coordinates[3].x = 457;
	}

	// --- Headphone Selection Channel 1-2 ---
	pCtrl = (CGControl *) new CGButton(&m_eventList, IDC_DJC_SPKSEL_12, 
		60, 257, 35, 32,m_pSkinMemDC, m_pSkinAlphaMemDC, 2, buttonInfo);
	AddControl(pCtrl);
	
	// --- Headphone Selection Channel 3-4 ---
	pCtrl = (CGControl *) new CGButton(&m_eventList, IDC_DJC_SPKSEL_34, 
		135, 257, 35, 32,m_pSkinMemDC, m_pSkinAlphaMemDC, 2, buttonInfo);
	AddControl(pCtrl);


	// --- Master Mute Button ---
	for(i=0;i<3;++i) {
		buttonInfo[i].nProcessAlpha = FALSE;
	}
	for(i=0;i<4;++i) {
		buttonInfo[0].coordinates[i].y = 520;
		buttonInfo[1].coordinates[i].y = 520;
		buttonInfo[2].coordinates[i].y = 520;
	}
	buttonInfo[0].coordinates[0].x = 349;
	buttonInfo[0].coordinates[1].x = 375;
	buttonInfo[0].coordinates[2].x = 401;
	buttonInfo[0].coordinates[3].x = 427;
	buttonInfo[1].coordinates[0].x = 453;
	buttonInfo[1].coordinates[1].x = 479;
	buttonInfo[1].coordinates[2].x = 505;
	buttonInfo[1].coordinates[3].x = 531;
	buttonInfo[2].coordinates[0].x = 557;
	buttonInfo[2].coordinates[1].x = 583;
	buttonInfo[2].coordinates[2].x = 609;
	buttonInfo[2].coordinates[3].x = 635;

	pCtrl = (CGControl *) new CGButton(&m_eventList, IDC_DJC_MASTER_MUTE, 
		263, 219,25,15,m_pSkinMemDC, m_pSkinAlphaMemDC, 3, buttonInfo);
	AddControl(pCtrl);

	// --- Mute Chanel 1-2 ---
	pCtrl = (CGControl *) new CGButton(&m_eventList, IDC_DJC_MUTE12, 
		65, 240, 25, 15,m_pSkinMemDC, m_pSkinAlphaMemDC, 2, buttonInfo);
	AddControl(pCtrl);

	// --- Mute Chanel 3-4 ---
	pCtrl = (CGControl *) new CGButton(&m_eventList, IDC_DJC_MUTE34, 
		140, 240, 25, 15,m_pSkinMemDC, m_pSkinAlphaMemDC, 2, buttonInfo);
	AddControl(pCtrl);

	// --- Mute Chanel 5-6 ---
	pCtrl = (CGControl *) new CGButton(&m_eventList, IDC_DJC_MUTE56, 
		215, 240, 25, 15,m_pSkinMemDC, m_pSkinAlphaMemDC, 2, buttonInfo);
	AddControl(pCtrl);

	// --- Static Information: Normal, DJ, 44.1, 48, Midi In, Rec. In., Master Vol ---
	pStatic = new CGStaticText(&m_eventList, IDC_DJC_STATIC_NORMAL, g_LOCALIZATION.GetString(IDS_NORMAL), 
		63, 52, 52, 12, ALIGN_RIGHT|VALIGN_CENTER);
	AddControl((CGControl *) pStatic);
	
	pStatic = new CGStaticText(&m_eventList, IDC_DJC_STATIC_DJ, g_LOCALIZATION.GetString(IDS_DJ), 
		149, 52, 52, 12, ALIGN_LEFT|VALIGN_CENTER);
	AddControl((CGControl *) pStatic);

	pStatic = new CGStaticText(&m_eventList, IDC_DJC_STATIC_44100, "44100 Hz", 
		344, 52, 59, 12, ALIGN_RIGHT|VALIGN_CENTER);
	AddControl((CGControl *) pStatic);

	pStatic = new CGStaticText(&m_eventList, IDC_DJC_STATIC_48000, "48000 Hz", 
		435, 52, 69, 12, ALIGN_LEFT|VALIGN_CENTER);
	AddControl((CGControl *) pStatic);

	pStatic = new CGStaticText(&m_eventList, IDC_DJC_STATIC_MIDI_IN, g_LOCALIZATION.GetString(IDS_MIDI_INPUT), 
		321, 134, 157, 12, ALIGN_LEFT|VALIGN_CENTER);
	AddControl((CGControl *) pStatic);

	pStatic = new CGStaticText(&m_eventList, IDC_DJC_STATIC_REC_IN, g_LOCALIZATION.GetString(IDS_RECORD_INPUT), 
		321, 183, 157, 12, ALIGN_LEFT|VALIGN_CENTER);
	AddControl((CGControl *) pStatic);

	pStatic = new CGStaticText(&m_eventList, IDC_DJC_STATIC_MASTER_VOL, g_LOCALIZATION.GetString(IDS_MASTER_VOLUME), 
		248, 238, 56, 14, ALIGN_CENTER|VALIGN_CENTER);
	AddControl((CGControl *) pStatic);

	pStatic = new CGStaticText(&m_eventList, IDC_DJC_STATIC_CH12_LABEL1, g_LOCALIZATION.GetString(IDS_MASTER), 
		52, 82, 52, 14, ALIGN_CENTER|VALIGN_CENTER);
	AddControl((CGControl *) pStatic);
	pStatic = new CGStaticText(&m_eventList, IDC_DJC_STATIC_CH12_LABEL2, "1-2", 
		52, 97, 52, 14, ALIGN_CENTER|VALIGN_CENTER);
	AddControl((CGControl *) pStatic);

	pStatic = new CGStaticText(&m_eventList, IDC_DJC_STATIC_CH34_LABEL1, g_LOCALIZATION.GetString(IDS_MONITOR), 
		127, 82, 52, 14, ALIGN_CENTER|VALIGN_CENTER);
	AddControl((CGControl *) pStatic);
	pStatic = new CGStaticText(&m_eventList, IDC_DJC_STATIC_CH34_LABEL2, "3-4", 
		127, 97, 52, 14, ALIGN_CENTER|VALIGN_CENTER);
	AddControl((CGControl *) pStatic);

	pStatic = new CGStaticText(&m_eventList, IDC_DJC_STATIC_CH56_LABEL1, g_LOCALIZATION.GetString(IDS_AUX), 
		202, 82, 52, 14, ALIGN_CENTER|VALIGN_CENTER);
	AddControl((CGControl *) pStatic);
	pStatic = new CGStaticText(&m_eventList, IDC_DJC_STATIC_CH56_LABEL2, "5-6", 
		202, 97, 52, 14, ALIGN_CENTER|VALIGN_CENTER);
	AddControl((CGControl *) pStatic);

	pStatic = new CGStaticText(&m_eventList, IDC_DJC_STATIC_TALK_ATT_LABEL, "0 dB", 
		370, 277, 34, 10, ALIGN_CENTER|VALIGN_CENTER);
	AddControl((CGControl *) pStatic);

	// --- ComboBox ---
	comboInfo.box[0].x = 349;
	comboInfo.box[0].y = 476;
	comboInfo.box[2].x = 349;
	comboInfo.box[2].y = 498;
	comboInfo.box[1].x = 510;
	comboInfo.box[1].y = 476;
	comboInfo.box[3].x = 510;
	comboInfo.box[3].y = 498;
	
	comboInfo.sbckBottom.x = 759;
	comboInfo.sbckBottom.y = 61;
	comboInfo.sbckBottom.w = 12;
	comboInfo.sbckBottom.h = 4;

	comboInfo.sbckMiddle.x = 746;
	comboInfo.sbckMiddle.y = 61;
	comboInfo.sbckMiddle.w = 12;
	comboInfo.sbckMiddle.h = 9;

	comboInfo.sbckTop.x = 733;
	comboInfo.sbckTop.y = 61;
	comboInfo.sbckTop.w = 12;
	comboInfo.sbckTop.h = 4;

	comboInfo.sbutBottom[0].x = 733;
	comboInfo.sbutBottom[0].y = 71;
	comboInfo.sbutBottom[0].w = 11;
	comboInfo.sbutBottom[0].h = 7;
	comboInfo.sbutBottom[1].x = 745;
	comboInfo.sbutBottom[1].y = 71;
	comboInfo.sbutBottom[1].w = 11;
	comboInfo.sbutBottom[1].h = 7;
	comboInfo.sbutBottom[2].x = 757;
	comboInfo.sbutBottom[2].y = 71;
	comboInfo.sbutBottom[2].w = 11;
	comboInfo.sbutBottom[2].h = 7;
	comboInfo.sbutBottom[3].x = 769;
	comboInfo.sbutBottom[3].y = 71;
	comboInfo.sbutBottom[3].w = 11;
	comboInfo.sbutBottom[3].h = 7;

	comboInfo.sbutTop[0].x = 733;
	comboInfo.sbutTop[0].y = 78;
	comboInfo.sbutTop[0].w = 11;
	comboInfo.sbutTop[0].h = 7;
	comboInfo.sbutTop[1].x = 745;
	comboInfo.sbutTop[1].y = 78;
	comboInfo.sbutTop[1].w = 11;
	comboInfo.sbutTop[1].h = 7;
	comboInfo.sbutTop[2].x = 757;
	comboInfo.sbutTop[2].y = 78;
	comboInfo.sbutTop[2].w = 11;
	comboInfo.sbutTop[2].h = 7;
	comboInfo.sbutTop[3].x = 769;
	comboInfo.sbutTop[3].y = 78;
	comboInfo.sbutTop[3].w = 11;
	comboInfo.sbutTop[3].h = 7;

	comboInfo.stmbBottom.x = 784;
	comboInfo.stmbBottom.y = 61;
	comboInfo.stmbBottom.w = 5;
	comboInfo.stmbBottom.h = 3;

	comboInfo.stmbMiddle.x = 778;
	comboInfo.stmbMiddle.y = 61;
	comboInfo.stmbMiddle.w = 5;
	comboInfo.stmbMiddle.h = 8;

	comboInfo.stmbTop.x = 772;
	comboInfo.stmbTop.y = 61;
	comboInfo.stmbTop.w = 5;
	comboInfo.stmbTop.h = 3;

	comboInfo.colorFont.r = 0x88;
	comboInfo.colorFont.g = 0xFF;
	comboInfo.colorFont.b = 0xFF;

	comboInfo.nBoxLeftSpace = 5;

	comboInfo.HighlightBckgrndColor.r = 0x88;
	comboInfo.HighlightBckgrndColor.g = 0xFF;
	comboInfo.HighlightBckgrndColor.b = 0xFF;

	comboInfo.HighlightForegrndColor.r = 0;
	comboInfo.HighlightForegrndColor.g = 0;
	comboInfo.HighlightForegrndColor.b = 0;

	comboInfo.nFontSizeBox = 8;
	comboInfo.nFontSizeList = 8;

	comboInfo.borderList.l = 3;
	comboInfo.borderList.r = 3;
	comboInfo.borderList.t = 5;
	comboInfo.borderList.b = 5;

	comboInfo.list.x = 547;	// Record Input.
	comboInfo.list.y = 283;

	pComboBox = new CGComboBox(&m_eventList, IDC_DJC_COMBO_REC_INPUT, 321, 199, 160, 21, 69, 
		m_pSkinMemDC, m_pSkinAlphaMemDC,&comboInfo);

	AddControl((CGControl *) pComboBox);
	pComboBox->ResetContent();
	pComboBox->AddString(g_LOCALIZATION.GetString(IDS_LINE_IN));
	pComboBox->AddString(g_LOCALIZATION.GetString(IDS_MIC));
	pComboBox->AddString(g_LOCALIZATION.GetString(IDS_DIGITAL_COAXIAL));
	pComboBox->AddString(g_LOCALIZATION.GetString(IDS_DIGITAL_OPTICAL));


	comboInfo.list.x = 493;	// Record Input.
	comboInfo.list.y = 353;

	pComboBox = new CGComboBox(&m_eventList, IDC_DJC_COMBO_MIDI, 321, 150, 160, 21, 41, 
		m_pSkinMemDC, m_pSkinAlphaMemDC,&comboInfo);

	AddControl((CGControl *) pComboBox);
	pComboBox->ResetContent();
	pComboBox->AddString(g_LOCALIZATION.GetString(IDS_MIDI_IN_PLUG));
	pComboBox->AddString(g_LOCALIZATION.GetString(IDS_MIDI_IN_BUTTONS));


	// --- About Box Background ---
	staticInfo[0].x = 0;
	staticInfo[0].y = 348;
	staticInfo[0].nProcessAlpha = FALSE;

	pStaticImg = new CGStatic(&m_eventList, IDC_DJC_ABOUTBOX_BCKGRND, 
		102,80,348,189, m_pSkinMemDC, m_pSkinAlphaMemDC, 1, staticInfo);
	AddControl((CGControl *) pStaticImg);

	// --- About Box: PRODUCT INFO Line 1 ---
	pStatic = new CGStaticText(&m_eventList, IDC_DJC_ABOUTBOX_STATIC_LINE1, 
		g_LOCALIZATION.GetString(IDS_DJ_CONSOLE_PROD_INFO_1),
		102+20, 80+18, 310, 10, ALIGN_CENTER|VALIGN_CENTER);
	AddControl((CGControl *) pStatic);
	// --- About Box: PRODUCT INFO Line 2 ---
	pStatic = new CGStaticText(&m_eventList, IDC_DJC_ABOUTBOX_STATIC_LINE2, 
		g_LOCALIZATION.GetString(IDS_DJ_CONSOLE_PROD_INFO_2),
		102+20, 80+31, 310, 10, ALIGN_CENTER|VALIGN_CENTER);
	AddControl((CGControl *) pStatic);

	// --- About Box: PRODUCT INFO Line 3 ---
	pStatic = new CGStaticText(&m_eventList, IDC_DJC_ABOUTBOX_STATIC_LINE3, 
		"Hercules DJ Console(tm) version n/a", 
		102+20, 80+86-5, 310, 10, ALIGN_CENTER|VALIGN_CENTER);
	AddControl((CGControl *) pStatic);
	// --- About Box: CORPORATE INFO Line 1 ---
	sprintf(szText, "%s", g_LOCALIZATION.GetString(IDS_COPYRIGHT));
	pStatic = new CGStaticText(&m_eventList, IDC_DJC_ABOUTBOX_STATIC_LINE4, 
		szText, 
		102+20, 80+99-5, 310, 10, ALIGN_CENTER|VALIGN_CENTER);
	AddControl((CGControl *) pStatic);

	sprintf(szText, "%s", g_LOCALIZATION.GetString(IDS_RIGHTS_RESERVED));
	pStatic = new CGStaticText(&m_eventList, IDC_DJC_ABOUTBOX_STATIC_LINE5, 
		szText, 
		102+20, 80+99+13-5, 310, 10, ALIGN_CENTER|VALIGN_CENTER);
	AddControl((CGControl *) pStatic);

	// --- About Box: VERSION Info Line 1 ---
	pStatic = new CGStaticText(&m_eventList, IDC_DJC_ABOUTBOX_STATIC_LINE6, 
		"Package: n/a", 
		102+20, 80+127, 310, 10, ALIGN_LEFT|VALIGN_CENTER);
	AddControl((CGControl *) pStatic);
	// --- About Box: VERSION Info Line 2 ---
	pStatic = new CGStaticText(&m_eventList, IDC_DJC_ABOUTBOX_STATIC_LINE7, 
		"Driver: n/a", 
		102+20, 80+140, 310, 10, ALIGN_LEFT|VALIGN_CENTER);
	AddControl((CGControl *) pStatic);
	// --- About Box: VERSION Info Line 3 ---
	pStatic = new CGStaticText(&m_eventList, IDC_DJC_ABOUTBOX_STATIC_LINE8, 
		"Firmware: n/a", 
		102+20, 80+153, 310, 10, ALIGN_LEFT|VALIGN_CENTER);
	AddControl((CGControl *) pStatic);
	// --- About Box: VERSION Info Line 4 ---
	pStatic = new CGStaticText(&m_eventList, IDC_DJC_ABOUTBOX_STATIC_LINE9, 
		"Bulk Status: n/a", 
		102+20, 80+166, 310, 10, ALIGN_LEFT|VALIGN_CENTER);
	AddControl((CGControl *) pStatic);

	// --- About Box: Web Link ---
	for(i=0;i<1;++i) {
		buttonInfo[i].nProcessAlpha = FALSE;
	}
	for(i=0;i<4;++i) {
		buttonInfo[0].coordinates[i].y = 538;
	}
	buttonInfo[0].coordinates[0].x = 0;
	buttonInfo[0].coordinates[1].x = 150;
	buttonInfo[0].coordinates[2].x = 300;
	buttonInfo[0].coordinates[3].x = 300;

	pCtrl = (CGControl *) new CGButton(&m_eventList, IDC_DJC_ABOUTBOX_WEBLINK, 
		102+97, 80+55,149,23,m_pSkinMemDC, m_pSkinAlphaMemDC, 1, buttonInfo);
	AddControl(pCtrl);

	// --- About Box: Ok ---
	for(i=0;i<1;++i) {
		buttonInfo[i].nProcessAlpha = FALSE;
	}
	buttonInfo[0].coordinates[0].x = 654;
	buttonInfo[0].coordinates[0].y = 353;
	buttonInfo[0].coordinates[1].x = 710;
	buttonInfo[0].coordinates[1].y = 353;
	buttonInfo[0].coordinates[2].x = 654;
	buttonInfo[0].coordinates[2].y = 375;
	buttonInfo[0].coordinates[3].x = 710;
	buttonInfo[0].coordinates[3].y = 375;

	pCtrl = (CGControl *) new CGButton(&m_eventList, IDC_DJC_ABOUTBOX_OK, 
		102+269, 80+147,55,21,m_pSkinMemDC, m_pSkinAlphaMemDC, 1, buttonInfo);
	AddControl(pCtrl);
	// --- About Box: Label 'OK' on Button OK ---
	pStatic = new CGStaticText(&m_eventList, IDC_DJC_ABOUTBOX_OK_LABEL, 
		"OK", 
		102+269, 80+146, 55, 21, ALIGN_CENTER|VALIGN_CENTER);
	AddControl((CGControl *) pStatic);


	// ---- Disable All Controls Related with Normal Mode ----
	bModeTest = false;
	bAboutTest = false;

	if (!bAboutTest) {
		GetControl(IDC_DJC_ABOUTBOX_BCKGRND)->Hide(TRUE);
		GetControl(IDC_DJC_ABOUTBOX_STATIC_LINE1)->Hide(TRUE);
		GetControl(IDC_DJC_ABOUTBOX_STATIC_LINE2)->Hide(TRUE);
		GetControl(IDC_DJC_ABOUTBOX_STATIC_LINE3)->Hide(TRUE);
		GetControl(IDC_DJC_ABOUTBOX_STATIC_LINE4)->Hide(TRUE);
		GetControl(IDC_DJC_ABOUTBOX_STATIC_LINE5)->Hide(TRUE);
		GetControl(IDC_DJC_ABOUTBOX_STATIC_LINE6)->Hide(TRUE);
		GetControl(IDC_DJC_ABOUTBOX_STATIC_LINE7)->Hide(TRUE);
		GetControl(IDC_DJC_ABOUTBOX_STATIC_LINE8)->Hide(TRUE);
		GetControl(IDC_DJC_ABOUTBOX_STATIC_LINE9)->Hide(TRUE);
		GetControl(IDC_DJC_ABOUTBOX_WEBLINK)->Hide(TRUE);
		GetControl(IDC_DJC_ABOUTBOX_OK)->Hide(TRUE);
		GetControl(IDC_DJC_ABOUTBOX_OK_LABEL)->Hide(TRUE);
	}

	if (bModeTest) {
		GetControl(IDC_DJC_SPK_BACKGROUND)->Hide(TRUE);
		GetControl(IDC_DJC_SPK_LEFT)->Hide(TRUE);
		GetControl(IDC_DJC_SPK_TOP)->Hide(TRUE);
		GetControl(IDC_DJC_SPK_RIGHT)->Hide(TRUE);
		GetControl(IDC_DJC_SPK_SLEFT)->Hide(TRUE);
		GetControl(IDC_DJC_SPK_SRIGHT)->Hide(TRUE);
		GetControl(IDC_DJC_SPK_LFE)->Hide(TRUE);
		GetControl(IDC_DJC_SPK_ID_1)->Hide(TRUE);
		GetControl(IDC_DJC_SPK_ID_2)->Hide(TRUE);
		GetControl(IDC_DJC_SPK_ID_3)->Hide(TRUE);
		GetControl(IDC_DJC_SPK_ID_4)->Hide(TRUE);
		GetControl(IDC_DJC_SPK_ID_5)->Hide(TRUE);
		GetControl(IDC_DJC_SPK_ID_6)->Hide(TRUE);
		GetControl(IDC_DJC_SPK_MINI_VOL_1)->Hide(TRUE);
		GetControl(IDC_DJC_SPK_MINI_VOL_2)->Hide(TRUE);
		GetControl(IDC_DJC_SPK_MINI_VOL_3)->Hide(TRUE);
		GetControl(IDC_DJC_SPK_MINI_VOL_4)->Hide(TRUE);
		GetControl(IDC_DJC_SPK_MINI_VOL_5)->Hide(TRUE);
		GetControl(IDC_DJC_SPK_MINI_VOL_6)->Hide(TRUE);
		GetControl(IDC_DJC_SPK_MASTER_VOL)->Hide(TRUE);
		GetControl(IDC_DJC_MASTER_MUTE)->Hide(TRUE);
		GetControl(IDC_DJC_STATIC_MASTER_VOL)->Hide(TRUE);
	}
	else {
		GetControl(IDC_DJC_VOL12)->Hide(TRUE);
		GetControl(IDC_DJC_VOL34)->Hide(TRUE);
		GetControl(IDC_DJC_VOL56)->Hide(TRUE);
		GetControl(IDC_DJC_BAL12)->Hide(TRUE);
		GetControl(IDC_DJC_BAL34)->Hide(TRUE);
		GetControl(IDC_DJC_BAL56)->Hide(TRUE);
		GetControl(IDC_DJC_MUTE12)->Hide(TRUE);
		GetControl(IDC_DJC_MUTE34)->Hide(TRUE);
		GetControl(IDC_DJC_MUTE56)->Hide(TRUE);
		GetControl(IDC_DJC_CHECKBOX_TALKOVER_ATT)->Hide(TRUE);
		GetControl(IDC_DJC_SPKSEL_12)->Hide(TRUE);
		GetControl(IDC_DJC_SPKSEL_34)->Hide(TRUE);
		GetControl(IDC_DJC_STATIC_CH12_LABEL1)->Hide(TRUE);
		GetControl(IDC_DJC_STATIC_CH12_LABEL2)->Hide(TRUE);
		GetControl(IDC_DJC_STATIC_CH34_LABEL1)->Hide(TRUE);
		GetControl(IDC_DJC_STATIC_CH34_LABEL2)->Hide(TRUE);
		GetControl(IDC_DJC_STATIC_CH56_LABEL1)->Hide(TRUE);
		GetControl(IDC_DJC_STATIC_CH56_LABEL2)->Hide(TRUE);
		GetControl(IDC_DJC_TALK_ATTENUATION_SLIDER)->Hide(TRUE);
		GetControl(IDC_DJC_STATIC_TALK_ATT_LABEL)->Hide(TRUE);
		GetControl(IDC_DJC_ON_AIR_STATUS)->Hide(TRUE);
	}
}

CDevDjcDlg::~CDevDjcDlg( )
{
}

// ---------------------------------------------------------------------------
// Function: SetDJMode
//
// Hide or show controls base on the DJ Mode: Normal or DJ.
// ---------------------------------------------------------------------------
void CDevDjcDlg::SetDJMode(unsigned long ulDJMode)
{
	bool bHide = (ulDJMode!=0);
	GetControl(IDC_DJC_SPK_BACKGROUND)->Hide(bHide);
	GetControl(IDC_DJC_SPK_LEFT)->Hide(bHide);
	GetControl(IDC_DJC_SPK_TOP)->Hide(bHide);
	GetControl(IDC_DJC_SPK_RIGHT)->Hide(bHide);
	GetControl(IDC_DJC_SPK_SLEFT)->Hide(bHide);
	GetControl(IDC_DJC_SPK_SRIGHT)->Hide(bHide);
	GetControl(IDC_DJC_SPK_LFE)->Hide(bHide);
	GetControl(IDC_DJC_SPK_ID_1)->Hide(bHide);
	GetControl(IDC_DJC_SPK_ID_2)->Hide(bHide);
	GetControl(IDC_DJC_SPK_ID_3)->Hide(bHide);
	GetControl(IDC_DJC_SPK_ID_4)->Hide(bHide);
	GetControl(IDC_DJC_SPK_ID_5)->Hide(bHide);
	GetControl(IDC_DJC_SPK_ID_6)->Hide(bHide);
	GetControl(IDC_DJC_SPK_MINI_VOL_1)->Hide(bHide);
	GetControl(IDC_DJC_SPK_MINI_VOL_2)->Hide(bHide);
	GetControl(IDC_DJC_SPK_MINI_VOL_3)->Hide(bHide);
	GetControl(IDC_DJC_SPK_MINI_VOL_4)->Hide(bHide);
	GetControl(IDC_DJC_SPK_MINI_VOL_5)->Hide(bHide);
	GetControl(IDC_DJC_SPK_MINI_VOL_6)->Hide(bHide);
	GetControl(IDC_DJC_SPK_MASTER_VOL)->Hide(bHide);
	GetControl(IDC_DJC_MASTER_MUTE)->Hide(bHide);
	GetControl(IDC_DJC_STATIC_MASTER_VOL)->Hide(bHide);

	GetControl(IDC_DJC_VOL12)->Hide(!bHide);
	GetControl(IDC_DJC_VOL34)->Hide(!bHide);
	GetControl(IDC_DJC_VOL56)->Hide(!bHide);
	GetControl(IDC_DJC_BAL12)->Hide(!bHide);
	GetControl(IDC_DJC_BAL34)->Hide(!bHide);
	GetControl(IDC_DJC_BAL56)->Hide(!bHide);
	GetControl(IDC_DJC_MUTE12)->Hide(!bHide);
	GetControl(IDC_DJC_MUTE34)->Hide(!bHide);
	GetControl(IDC_DJC_MUTE56)->Hide(!bHide);
	GetControl(IDC_DJC_CHECKBOX_TALKOVER_ATT)->Hide(!bHide);
	GetControl(IDC_DJC_SPKSEL_12)->Hide(!bHide);
	GetControl(IDC_DJC_SPKSEL_34)->Hide(!bHide);
	GetControl(IDC_DJC_STATIC_CH12_LABEL1)->Hide(!bHide);
	GetControl(IDC_DJC_STATIC_CH12_LABEL2)->Hide(!bHide);
	GetControl(IDC_DJC_STATIC_CH34_LABEL1)->Hide(!bHide);
	GetControl(IDC_DJC_STATIC_CH34_LABEL2)->Hide(!bHide);
	GetControl(IDC_DJC_STATIC_CH56_LABEL1)->Hide(!bHide);
	GetControl(IDC_DJC_STATIC_CH56_LABEL2)->Hide(!bHide);
	GetControl(IDC_DJC_TALK_ATTENUATION_SLIDER)->Hide(!bHide);
	GetControl(IDC_DJC_STATIC_TALK_ATT_LABEL)->Hide(!bHide);
	GetControl(IDC_DJC_ON_AIR_STATUS)->Hide(!bHide);
}

// ---------------------------------------------------------------------------
// Function: DisplayAboutBox
//
// Show or hide the about box and gray out or restore other controls.
// ---------------------------------------------------------------------------
void CDevDjcDlg::DisplayAboutBox(bool bDisplayAboutBox)
{
	static bool bEnableCtrl[IDC_DJC_ABOUTBOX_BCKGRND-IDC_DJC_HERCULES_LOGO];
	int i;

	GetControl(IDC_DJC_ABOUTBOX_BCKGRND)->Hide(!bDisplayAboutBox);
	GetControl(IDC_DJC_ABOUTBOX_STATIC_LINE1)->Hide(!bDisplayAboutBox);
	GetControl(IDC_DJC_ABOUTBOX_STATIC_LINE2)->Hide(!bDisplayAboutBox);
	GetControl(IDC_DJC_ABOUTBOX_STATIC_LINE3)->Hide(!bDisplayAboutBox);
	GetControl(IDC_DJC_ABOUTBOX_STATIC_LINE4)->Hide(!bDisplayAboutBox);
	GetControl(IDC_DJC_ABOUTBOX_STATIC_LINE5)->Hide(!bDisplayAboutBox);
	GetControl(IDC_DJC_ABOUTBOX_STATIC_LINE6)->Hide(!bDisplayAboutBox);
	GetControl(IDC_DJC_ABOUTBOX_STATIC_LINE7)->Hide(!bDisplayAboutBox);
	GetControl(IDC_DJC_ABOUTBOX_STATIC_LINE8)->Hide(!bDisplayAboutBox);
	GetControl(IDC_DJC_ABOUTBOX_STATIC_LINE9)->Hide(!bDisplayAboutBox);
	GetControl(IDC_DJC_ABOUTBOX_WEBLINK)->Hide(!bDisplayAboutBox);
	GetControl(IDC_DJC_ABOUTBOX_OK)->Hide(!bDisplayAboutBox);
	GetControl(IDC_DJC_ABOUTBOX_OK_LABEL)->Hide(!bDisplayAboutBox);

	for(i=IDC_DJC_HERCULES_LOGO;i<IDC_DJC_ABOUTBOX_BCKGRND;++i)
	{
		if (bDisplayAboutBox) 
		{
			bEnableCtrl[i-IDC_DJC_HERCULES_LOGO] = GetControl(i)->IsEnable();
			GetControl(i)->Enable(!bDisplayAboutBox);
		}
		else
		{
			GetControl(i)->Enable(bEnableCtrl[i-IDC_DJC_HERCULES_LOGO]);
		}
	}
}

// ---------------------------------------------------------------------------
// Function: UpdateVolumeSlider
//
// Update volume sliders base (could do single, master or stereo).
// ---------------------------------------------------------------------------
void CDevDjcDlg::UpdateVolumeSlider( bool bRefreshSingle, bool bRefreshMaster, bool bRefreshStereo )
{
	CGSlider 	*pSlider;
	int		i, nMax, nVol1, nVol2, nBal;

	// --- Refresh Single Volumes ---
	if (bRefreshSingle)
	{
		for(i=0;i<6;++i)
		{
			if (m_pDeviceState->bVolumeToApply[i])
			{
				pSlider = (CGSlider *) GetControl(i+IDC_DJC_SPK_MINI_VOL_1);
				pSlider->SetPos(m_pDeviceState->nVolumeToApply[i]);
			}
		}
	}

	// --- Refresh Master Volume  ---
	if (bRefreshMaster)
	{
		nMax = 0;
		for(i=0;i<6;++i)
		{
			if (m_pDeviceState->bVolumeToApply[i])
			{
				if (m_pDeviceState->nVolumeToApply[i]>nMax)
					nMax = m_pDeviceState->nVolumeToApply[i];
			}
			else
			{
				if (m_pDeviceState->djConsole.nVolume[i]>nMax)
					nMax = m_pDeviceState->djConsole.nVolume[i];
			}
		}
		
		pSlider = (CGSlider *) GetControl(IDC_DJC_SPK_MASTER_VOL);
		pSlider->SetPos(nMax);
	}

	// --- Refresh Stereo Volumes ---
	if (bRefreshStereo)
	{
		for(i=0;i<3;++i)
		{
			nVol1 = (m_pDeviceState->bVolumeToApply[2*i+0]) ? m_pDeviceState->nVolumeToApply[2*i+0] :
				m_pDeviceState->djConsole.nVolume[2*i+0];
			nVol2 = (m_pDeviceState->bVolumeToApply[2*i+1]) ? m_pDeviceState->nVolumeToApply[2*i+1] :
				m_pDeviceState->djConsole.nVolume[2*i+1];
			nMax = (nVol1>nVol2) ? nVol1 : nVol2;
			((CGSlider *) GetControl(IDC_DJC_VOL12+i))->SetPos(nMax);
			nBal = 128;
			if (nVol1>nVol2)
				nBal = 128 - 128 * (nVol1-nVol2) / nVol1;
			else if (nVol1<nVol2)
				nBal = 128 + 127 * (nVol2-nVol1) / nVol2;
			((CGSlider *) GetControl(IDC_DJC_BAL12+i))->SetPos(nBal);
		}
	}
}

// ---------------------------------------------------------------------------
// Function: MouseEvent
//
// Process mouse events for all controls available on the DJ Console.
// ---------------------------------------------------------------------------
bool CDevDjcDlg::MouseEvent( int x, int y, int button, PREFRESH_RECT refreshRect )
{
	bool		bMouseEvent = false;
	bool		bProcessEvent, bResult;
	int		nControlID, nMsg;
	unsigned long	ulParam1, ulParam2;
	CGSlider 	*pSlider;
	CGButton	*pButton;
	CGStaticText 	*pStatic;
	CGCheckBox 	*pCheckBox;
	int		i, nValue, nIndex, w[6], wMax;
	MIDI_INPUT_SEL  eMidiInput;
	RECORD_INPUT 	eRecordInput;
	char szText[40];

	bMouseEvent = CGDialog::MouseEvent(x,y,button, refreshRect);

	do
	{
		bProcessEvent = GetEvent(&nControlID, &nMsg, &ulParam1, &ulParam2);
		if (bProcessEvent) {
			refreshRect->x = 0; refreshRect->y = 0;
			refreshRect->w = m_nWidth; refreshRect->h = m_nHeight;
			switch (nControlID)
			{
			case IDC_DJC_DJ_MODE:
				SetDJMode(ulParam1);
				m_pDManager->EnableDJMode(ulParam1==1, m_pDeviceState);
				break;
			case IDC_DJC_SAMP_RATE:
				if (m_pDManager->SetSampleRate((ulParam1==0) ? 44100 : 48000, m_pDeviceState))
				{
					// Disable Control Panel Interface.
					// waiting for device departure/arrival or time-out.
					for(i=IDC_DJC_HERCULES_LOGO;i<=IDC_DJC_ABOUTBOX_OK_LABEL;++i)
					{
						GetControl(i)->Enable(false);
					}
				}
				break;
			case IDC_DJC_COMBO_MIDI:
				eMidiInput = (ulParam1==0) ? MIDI_IN_PLUG : DJ_CONSOLE_BUTTONS;
				m_pDManager->SetMidiInput( eMidiInput, m_pDeviceState );
				break;
			case IDC_DJC_SPKSEL_12:
				pButton = (CGButton *) GetControl(IDC_DJC_SPKSEL_12);
				pButton->SetState(1);
				pButton = (CGButton *) GetControl(IDC_DJC_SPKSEL_34);
				pButton->SetState(0);
				m_pDManager->SetHeadphoneToMainOut(true, m_pDeviceState);
				break;
			case IDC_DJC_SPKSEL_34:
				pButton = (CGButton *) GetControl(IDC_DJC_SPKSEL_12);
				pButton->SetState(0);
				pButton = (CGButton *) GetControl(IDC_DJC_SPKSEL_34);
				pButton->SetState(1);
				m_pDManager->SetHeadphoneToMainOut(false, m_pDeviceState);
				break;
			case IDC_DJC_COMBO_REC_INPUT:
				eRecordInput = DIGITAL_OPTICAL;
				if (ulParam1==0)
					eRecordInput = LINE_IN;
				else if (ulParam1==1)
					eRecordInput = MIC;
				else if (ulParam1==2)
					eRecordInput = DIGITAL_COAXIAL;
				m_pDManager->SetRecordInput( eRecordInput, m_pDeviceState );
				break;
			case IDC_DJC_HERCULES_LOGO:
				DisplayAboutBox(true);
				break;
			case IDC_DJC_ABOUTBOX_OK:
				DisplayAboutBox(false);
				break;
			case IDC_DJC_ABOUTBOX_WEBLINK:
				m_helpers.LaunchInternetBrowser(g_LOCALIZATION.GetString(IDS_HTTP_DJC));
				break;
			case IDC_DJC_SPK_MINI_VOL_1:
			case IDC_DJC_SPK_MINI_VOL_2:
			case IDC_DJC_SPK_MINI_VOL_3:
			case IDC_DJC_SPK_MINI_VOL_4:
			case IDC_DJC_SPK_MINI_VOL_5:
			case IDC_DJC_SPK_MINI_VOL_6:
				pSlider = (CGSlider *) GetControl(nControlID);
				nValue = pSlider->GetPos();
				m_pDeviceState->nVolumeToApply[nControlID-IDC_DJC_SPK_MINI_VOL_1] = nValue;
				m_pDeviceState->bVolumeToApply[nControlID-IDC_DJC_SPK_MINI_VOL_1] = true;
				break;
			case IDC_DJC_SPK_MASTER_VOL:
				pSlider = (CGSlider *) GetControl(nControlID);
				nValue = pSlider->GetPos();
				w[0] = ((CGSlider *) GetControl(IDC_DJC_SPK_MINI_VOL_1))->GetPos();
				w[1] = ((CGSlider *) GetControl(IDC_DJC_SPK_MINI_VOL_2))->GetPos();
				w[2] = ((CGSlider *) GetControl(IDC_DJC_SPK_MINI_VOL_3))->GetPos();
				w[3] = ((CGSlider *) GetControl(IDC_DJC_SPK_MINI_VOL_4))->GetPos();
				w[4] = ((CGSlider *) GetControl(IDC_DJC_SPK_MINI_VOL_5))->GetPos();
				w[5] = ((CGSlider *) GetControl(IDC_DJC_SPK_MINI_VOL_6))->GetPos();
				wMax = (w[0]>w[1]) ? w[0] : w[1];
				wMax = (wMax>w[2]) ? wMax : w[2];
				wMax = (wMax>w[3]) ? wMax : w[3];
				wMax = (wMax>w[4]) ? wMax : w[4];
				wMax = (wMax>w[5]) ? wMax : w[5];
				if (wMax==0)
				{
					wMax = 1;
					for(i=0;i<6;++i)
						w[i] = 1;
				}

				for(i=0;i<6;++i)
				{
					m_pDeviceState->nVolumeToApply[i] = w[i] * nValue / wMax;
					m_pDeviceState->bVolumeToApply[i] = true;
				}
				break;
			case IDC_DJC_VOL12:
			case IDC_DJC_VOL34:
			case IDC_DJC_VOL56:
				nIndex = 2*(nControlID-IDC_DJC_VOL12);
				pSlider = (CGSlider *) GetControl(IDC_DJC_BAL12 + nControlID-IDC_DJC_VOL12);
				nValue = pSlider->GetPos();
				w[nIndex] = (nValue<128) ? 128 : 128*(255-nValue)/127;
				w[nIndex+1] = (nValue>127) ? 128 : nValue;
				m_pDeviceState->nVolumeToApply[nIndex] = w[nIndex] * ulParam1 / 128;
				m_pDeviceState->nVolumeToApply[nIndex+1] = w[nIndex+1] * ulParam1 / 128;
				m_pDeviceState->bVolumeToApply[nIndex] = true;
				m_pDeviceState->bVolumeToApply[nIndex+1] = true;
				UpdateVolumeSlider(true, true, false);
				break;
			case IDC_DJC_BAL12:
			case IDC_DJC_BAL34:
			case IDC_DJC_BAL56:
				nIndex = 2*(nControlID-IDC_DJC_BAL12);
				if (nMsg==GEVENT_SLIDER_DCLICK)
				{
					pSlider = (CGSlider *) GetControl(nControlID);
					pSlider->SetPos(128);
					w[nIndex] = w[nIndex+1] = 128;
				}
				else
				{
					w[nIndex] = (ulParam1<128) ? 128 : 128*(255-ulParam1)/127;
					w[nIndex+1] = (ulParam1>127) ? 128 : ulParam1;
				}
				pSlider = (CGSlider *) GetControl(IDC_DJC_VOL12 + nIndex/2);
				nValue = pSlider->GetPos();
				m_pDeviceState->nVolumeToApply[nIndex] = w[nIndex] * nValue / 128;
				m_pDeviceState->nVolumeToApply[nIndex+1] = w[nIndex+1] * nValue / 128;
				m_pDeviceState->bVolumeToApply[nIndex] = true;
				m_pDeviceState->bVolumeToApply[nIndex+1] = true;
				break;
			case IDC_DJC_MUTE12:
			case IDC_DJC_MUTE34:
			case IDC_DJC_MUTE56:
				m_pDManager->SetMute(m_pDeviceState, nControlID-IDC_DJC_MUTE12, ulParam1==1);
				if (m_pDeviceState->djConsole.bMute[0] && m_pDeviceState->djConsole.bMute[1] &&
					m_pDeviceState->djConsole.bMute[2])
					nValue = 1;
				else if (!m_pDeviceState->djConsole.bMute[0] && !m_pDeviceState->djConsole.bMute[1] &&
					!m_pDeviceState->djConsole.bMute[2])
					nValue = 0;
				else
					nValue = 2;

				pButton = (CGButton *) GetControl(IDC_DJC_MASTER_MUTE);
				pButton->SetState(nValue);
				break;
			case IDC_DJC_MASTER_MUTE:
				pButton = (CGButton *) GetControl(IDC_DJC_MASTER_MUTE);
				nValue = (ulParam1==1) ? 1 : 0;
				pButton->SetState(nValue);
				m_pDManager->SetMute(m_pDeviceState, 0, nValue==1);
				m_pDManager->SetMute(m_pDeviceState, 1, nValue==1);
				m_pDManager->SetMute(m_pDeviceState, 2, nValue==1);
				((CGButton *) GetControl(IDC_DJC_MUTE12))->SetState(nValue);
				((CGButton *) GetControl(IDC_DJC_MUTE34))->SetState(nValue);
				((CGButton *) GetControl(IDC_DJC_MUTE56))->SetState(nValue);
				break;
			case IDC_DJC_CHECKBOX_DJ_MOUSE:
				m_pDManager->EnableDJMouse(ulParam1!=0, m_pDeviceState);
				break;
			case IDC_DJC_TALK_ATTENUATION_SLIDER:
				pSlider = (CGSlider *) GetControl(IDC_DJC_TALK_ATTENUATION_SLIDER);
				bResult = m_pDManager->SetTalkoverAttenuation(pSlider->GetPos()*3+3,
					m_pDeviceState);
				sprintf(szText, "-%d dB", m_pDeviceState->djConsole.nTalkoverAttenuation);
				pStatic = (CGStaticText *) GetControl(IDC_DJC_STATIC_TALK_ATT_LABEL);
				pStatic->SetLabel(szText);
				break;
			case IDC_DJC_CHECKBOX_TALKOVER_ATT:
				pCheckBox = (CGCheckBox *) GetControl(IDC_DJC_CHECKBOX_TALKOVER_ATT);
				pSlider = (CGSlider *) GetControl(IDC_DJC_TALK_ATTENUATION_SLIDER);
				pSlider->Enable(pCheckBox->GetState()==1);
				bResult = m_pDManager->EnableTalkover(pCheckBox->GetState()==1,
					m_pDeviceState);
				break;
			}
		}
	} while (bProcessEvent);

	return bMouseEvent;
}

// ---------------------------------------------------------------------------
// Function: InitializeHIDState
//
// Set the ON AIR state base on the device state.
// ---------------------------------------------------------------------------
void CDevDjcDlg::InitializeHIDState( DJ_DEVICE_STATE *pDeviceState, CDManager *pDeviceManager )
{
	CGStatic *pStatic;
	pStatic = (CGStatic *) GetControl(IDC_DJC_ON_AIR_STATUS);
	pStatic->SetState(pDeviceState->djConsole.bOnAir ? 1 : 0);
	DEBUG_PRINT("CDevDjcDlg::InitializeHIDState completed.");
}

// ---------------------------------------------------------------------------
// Function: InitializeMixerState
//
// Set the mixer (volume, mute) states base on the device state.
// ---------------------------------------------------------------------------
void CDevDjcDlg::InitializeMixerState( DJ_DEVICE_STATE *pDeviceState, CDManager *pDeviceManager )
{
	CGSlider	*pSlider;
	CGButton	*pButton;
	int nVol12, nVol34, nVol56, nMaster;
	int nBal12, nBal34, nBal56, nState;

	// --- Volumes ---
	nVol12 = pDeviceState->djConsole.nVolume[0]>pDeviceState->djConsole.nVolume[1] ?
		pDeviceState->djConsole.nVolume[0] : pDeviceState->djConsole.nVolume[1];
	nVol34 = pDeviceState->djConsole.nVolume[2]>pDeviceState->djConsole.nVolume[3] ?
		pDeviceState->djConsole.nVolume[2] : pDeviceState->djConsole.nVolume[3];
	nVol56 = pDeviceState->djConsole.nVolume[4]>pDeviceState->djConsole.nVolume[5] ?
		pDeviceState->djConsole.nVolume[4] : pDeviceState->djConsole.nVolume[5];

	nBal12 = 128;
	if (pDeviceState->djConsole.nVolume[0]<pDeviceState->djConsole.nVolume[1])
	{
		nBal12 = 128 + 127*(pDeviceState->djConsole.nVolume[1]-pDeviceState->djConsole.nVolume[0])/
			pDeviceState->djConsole.nVolume[1];
	}
	else if (pDeviceState->djConsole.nVolume[0]>pDeviceState->djConsole.nVolume[1])
	{
		nBal12 = 128 - 128*(pDeviceState->djConsole.nVolume[0]-pDeviceState->djConsole.nVolume[1])/
			pDeviceState->djConsole.nVolume[0];
	}

	nBal34 = 128;
	if (pDeviceState->djConsole.nVolume[2]<pDeviceState->djConsole.nVolume[3])
	{
		nBal34 = 128 + 127*(pDeviceState->djConsole.nVolume[3]-pDeviceState->djConsole.nVolume[2])/
			pDeviceState->djConsole.nVolume[3];
	}
	else if (pDeviceState->djConsole.nVolume[2]>pDeviceState->djConsole.nVolume[3])
	{
		nBal34 = 128 - 128*(pDeviceState->djConsole.nVolume[2]-pDeviceState->djConsole.nVolume[3])/
			pDeviceState->djConsole.nVolume[2];
	}

	nBal56 = 128;
	if (pDeviceState->djConsole.nVolume[4]<pDeviceState->djConsole.nVolume[5])
	{
		nBal56 = 128 + 127*(pDeviceState->djConsole.nVolume[5]-pDeviceState->djConsole.nVolume[4])/
			pDeviceState->djConsole.nVolume[5];
	}
	else if (pDeviceState->djConsole.nVolume[4]>pDeviceState->djConsole.nVolume[5])
	{
		nBal56 = 128 - 128*(pDeviceState->djConsole.nVolume[4]-pDeviceState->djConsole.nVolume[5])/
			pDeviceState->djConsole.nVolume[4];
	}

	nMaster = (nVol12>nVol34) ? nVol12 : nVol34;
	nMaster = (nVol56>nMaster) ? nVol56 : nMaster;

	pSlider = (CGSlider *) GetControl(IDC_DJC_SPK_MINI_VOL_1);
	pSlider->SetPos(pDeviceState->djConsole.nVolume[0]);
	pSlider = (CGSlider *) GetControl(IDC_DJC_SPK_MINI_VOL_2);
	pSlider->SetPos(pDeviceState->djConsole.nVolume[1]);
	pSlider = (CGSlider *) GetControl(IDC_DJC_SPK_MINI_VOL_3);
	pSlider->SetPos(pDeviceState->djConsole.nVolume[2]);
	pSlider = (CGSlider *) GetControl(IDC_DJC_SPK_MINI_VOL_4);
	pSlider->SetPos(pDeviceState->djConsole.nVolume[3]);
	pSlider = (CGSlider *) GetControl(IDC_DJC_SPK_MINI_VOL_5);
	pSlider->SetPos(pDeviceState->djConsole.nVolume[4]);
	pSlider = (CGSlider *) GetControl(IDC_DJC_SPK_MINI_VOL_6);
	pSlider->SetPos(pDeviceState->djConsole.nVolume[5]);

	pSlider = (CGSlider *) GetControl(IDC_DJC_VOL12);
	pSlider->SetPos(nVol12);
	pSlider = (CGSlider *) GetControl(IDC_DJC_VOL34);
	pSlider->SetPos(nVol34);
	pSlider = (CGSlider *) GetControl(IDC_DJC_VOL56);
	pSlider->SetPos(nVol56);

	pSlider = (CGSlider *) GetControl(IDC_DJC_SPK_MASTER_VOL);
	pSlider->SetPos(nMaster);

	// --- Balance ---
	pSlider = (CGSlider *) GetControl(IDC_DJC_BAL12);
	pSlider->SetPos(nBal12);

	pSlider = (CGSlider *) GetControl(IDC_DJC_BAL34);
	pSlider->SetPos(nBal34);

	pSlider = (CGSlider *) GetControl(IDC_DJC_BAL56);
	pSlider->SetPos(nBal56);

	// --- Mute ---
	pButton = (CGButton *) GetControl(IDC_DJC_MUTE12);
	pButton->SetState(pDeviceState->djConsole.bMute[0] ? 1 : 0);

	pButton = (CGButton *) GetControl(IDC_DJC_MUTE34);
	pButton->SetState(pDeviceState->djConsole.bMute[1] ? 1 : 0);

	pButton = (CGButton *) GetControl(IDC_DJC_MUTE56);
	pButton->SetState(pDeviceState->djConsole.bMute[2] ? 1 : 0);

	if (pDeviceState->djConsole.bMute[0] && pDeviceState->djConsole.bMute[1] &&
		pDeviceState->djConsole.bMute[2])
		nState = 1;
	else if (!pDeviceState->djConsole.bMute[0] && !pDeviceState->djConsole.bMute[1] &&
		!pDeviceState->djConsole.bMute[2])
		nState = 0;
	else
		nState = 2;

	pButton = (CGButton *) GetControl(IDC_DJC_MASTER_MUTE);
	pButton->SetState(nState);
	DEBUG_PRINT("CDevDjcDlg::InitializeMixerState completed.");
}

// ---------------------------------------------------------------------------
// Function: ApplyVolume
//
// For each volume which need to be set, call SetVolume to adjust it.
// ---------------------------------------------------------------------------
bool CDevDjcDlg::ApplyVolume( DJ_DEVICE_STATE *pDeviceState )
{
	int nValue, i;
	bool bRefresh = false;
	
	UpdateVolumeSlider(true, true, true);
	for(i=0;i<6;++i)
	{
		if (pDeviceState->bVolumeToApply[i])
		{
			pDeviceState->bVolumeToApply[i] = false;
			nValue = pDeviceState->nVolumeToApply[i];
			m_pDManager->SetVolume(m_pDeviceState, i, nValue);
			pDeviceState->djConsole.nVolume[i] = nValue;
			bRefresh = true;
		}
	}
	return bRefresh;
}

// ---------------------------------------------------------------------------
// Function: InitializeDlgState
//
// Set various hardware setting (excluding HID and Audio Mixer).
// ---------------------------------------------------------------------------
void CDevDjcDlg::InitializeDlgState( DJ_DEVICE_STATE *pDeviceState, CDManager *pDeviceManager )
{
	char 		 szText[80];
	CGStaticText	*pStatic;
	CGCheckBox	*pCheckBox;
	CGComboBox	*pComboBox;
	CGButton	*pButton;
	CGSlider	*pSlider;

	CGDialog::InitializeDlgState(pDeviceState, pDeviceManager);
	InitializeMixerState(pDeviceState, pDeviceManager);
	InitializeHIDState(pDeviceState, pDeviceManager);

	// --- Talkover Attenuation ---
	pCheckBox = (CGCheckBox *) GetControl(IDC_DJC_CHECKBOX_TALKOVER_ATT);
	pCheckBox->SetState(pDeviceState->djConsole.bTalkoverAttenuation);
	pSlider = (CGSlider *) GetControl(IDC_DJC_TALK_ATTENUATION_SLIDER);
	pSlider->SetPos(pDeviceState->djConsole.nTalkoverAttenuation/3-1);
	pSlider->Enable(pDeviceState->djConsole.bTalkoverAttenuation);
	sprintf(szText, "-%d dB", pDeviceState->djConsole.nTalkoverAttenuation);
	pStatic = (CGStaticText *) GetControl(IDC_DJC_STATIC_TALK_ATT_LABEL);
	pStatic->SetLabel(szText);

	// --- Headphone Monitoring ---
	pButton = (CGButton *) GetControl(IDC_DJC_SPKSEL_12);
	pButton->SetState(pDeviceState->djConsole.bHeadphoneOnMaster ? 1 : 0);
	pButton = (CGButton *) GetControl(IDC_DJC_SPKSEL_34);
	pButton->SetState(pDeviceState->djConsole.bHeadphoneOnMaster ? 0 : 1);

	// --- Record Source ---
	pComboBox = (CGComboBox *) GetControl(IDC_DJC_COMBO_REC_INPUT);
	switch(pDeviceState->djConsole.eRecordingInput)
	{
	case LINE_IN:
		pComboBox->SetCurSel(0);
		break;
	case MIC:
		pComboBox->SetCurSel(1);
		break;
	case DIGITAL_COAXIAL:
		pComboBox->SetCurSel(2);
		break;
	case DIGITAL_OPTICAL:
		pComboBox->SetCurSel(3);
		break;
	}

	// --- MIDI Input ---
	pComboBox = (CGComboBox *) GetControl(IDC_DJC_COMBO_MIDI);
	pComboBox->SetCurSel(pDeviceState->djConsole.eMidiInput==MIDI_IN_PLUG ? 0 : 1);

	// --- DJ Mouse ---
	pCheckBox = (CGCheckBox *) GetControl(IDC_DJC_CHECKBOX_DJ_MOUSE);
	pCheckBox->SetState(pDeviceState->djConsole.bEnableDJMouse ? 1 : 0);

	// --- DJ Mode ---
	pSlider = (CGSlider *) GetControl(IDC_DJC_DJ_MODE);
	pSlider->SetPos(pDeviceState->djConsole.bEnableDJMode ? 1 : 0);
	SetDJMode(pDeviceState->djConsole.bEnableDJMode);

	// --- Sample Rate ---
	pSlider = (CGSlider *) GetControl(IDC_DJC_SAMP_RATE);
	pSlider->SetPos((pDeviceState->djConsole.nSampleRate==48000) ? 1 : 0);

	// --- About Box ---
	sprintf(szText, "%s %s", g_LOCALIZATION.GetString(IDS_DJ_CONSOLE_VERSION), INFO_CONTROL_PANEL);
	pStatic = (CGStaticText *) GetControl(IDC_DJC_ABOUTBOX_STATIC_LINE3);
	pStatic->SetLabel(szText);

	sprintf(szText, "%s %s", g_LOCALIZATION.GetString(IDS_PACKAGE), INFO_PACKAGE_NAME);
	pStatic = (CGStaticText *) GetControl(IDC_DJC_ABOUTBOX_STATIC_LINE6);
	pStatic->SetLabel(szText);

	sprintf(szText, "%s %d.%d.%d.%d", g_LOCALIZATION.GetString(IDS_DRIVER),
		ConvertBCDtoInt((int) (pDeviceState->ulBULK_Version>>24)&0xFF),
		ConvertBCDtoInt((int) (pDeviceState->ulBULK_Version>>16)&0xFF),
		ConvertBCDtoInt((int) (pDeviceState->ulBULK_Version>>8)&0xFF),
		ConvertBCDtoInt((int) (pDeviceState->ulBULK_Version>>0)&0xFF));
	pStatic = (CGStaticText *) GetControl(IDC_DJC_ABOUTBOX_STATIC_LINE7);
	pStatic->SetLabel(szText);

	sprintf(szText, "%s %d", g_LOCALIZATION.GetString(IDS_FIRMWARE),
		(int) (pDeviceState->djConsole.lFirmwareVersion&0xFF));
	pStatic = (CGStaticText *) GetControl(IDC_DJC_ABOUTBOX_STATIC_LINE8);
	pStatic->SetLabel(szText);

	// Bulk Status has to be increase by 1 if non zero 
	// (to be coherent with the first version launch on PC).
	if ( ((pDeviceState->djConsole.lFirmwareVersion>>8)&0xFF)==0 )
		sprintf(szText, "%s 0", g_LOCALIZATION.GetString(IDS_BULK_STATUS));
	else
		sprintf(szText, "%s %d", g_LOCALIZATION.GetString(IDS_BULK_STATUS),
			(int) ((pDeviceState->djConsole.lFirmwareVersion>>8)&0xFF) + 1);

	pStatic = (CGStaticText *) GetControl(IDC_DJC_ABOUTBOX_STATIC_LINE9);
	pStatic->SetLabel(szText);

	DEBUG_PRINT("CDevDjcDlg::InitializeDlgState completed.");
}


