/////////////////////////////////////////////////////////////////////////////
// Name:        devmk2dlg.cpp
// Purpose:     Implement GUI for DJ Console Mk2 Dialog.
// Author:      Yann Hamiaux
// Modified by: -
// Created:     02/15/2008
// Copyright:   Written for Guillemot Corporation by Yann Hamiaux
// Licence:     The GNU General Public License v2+.
/////////////////////////////////////////////////////////////////////////////
#include "devmk2dlg.h"
#include "localization.h"

extern CLocalization	g_LOCALIZATION;


CDevMk2Dlg::CDevMk2Dlg( wxMemoryDC *pSkinMemDC, wxMemoryDC *pSkinAlphaMemDC ) : 
	CGDialog(pSkinMemDC, pSkinAlphaMemDC, 538, 399)
{
	BUTTON_STATE_INFO	buttonInfo[4];
	STATIC_STATE_INFO	staticInfo[7];
	SLIDER_INFO		sliderInfo;
	COMBO_INFO		comboInfo;
	CGControl		*pCtrl;
	CGStaticText		*pStatic;
	CGStatic		*pStaticImg;
	CGSlider		*pSlider;
	CGComboBox		*pComboBox;
	bool			bASIOMode;
	int			i;
	int			nCPLTab;

	// --- Advanced Tab ---
	staticInfo[0].x = 539;
	staticInfo[0].y = 0;
	staticInfo[0].nProcessAlpha = FALSE;

	pStaticImg = new CGStatic(&m_eventList, IDC_MK2_ADVANCED_TAB, 
		206,103,318,280, m_pSkinMemDC, m_pSkinAlphaMemDC, 1, staticInfo);
	AddControl((CGControl *) pStaticImg);

	// --- About Tab ---
	staticInfo[0].x = 858;
	staticInfo[0].y = 0;
	staticInfo[0].nProcessAlpha = FALSE;

	pStaticImg = new CGStatic(&m_eventList, IDC_MK2_ABOUT_TAB, 
		206,103,318,280, m_pSkinMemDC, m_pSkinAlphaMemDC, 1, staticInfo);
	AddControl((CGControl *) pStaticImg);

	// --- Volume Sliders ---
	for(i=0;i<4;++i) {
		sliderInfo.coordinates[i].x = 842;
		sliderInfo.coordinates[i].y = 281;
		sliderInfo.coordinates[i].x_highlight = 896;
		sliderInfo.coordinates[i].y_highlight = 281;
		sliderInfo.coordinates[i].thumb_x = 950;
		sliderInfo.coordinates[i].thumb_y = 281;
		sliderInfo.coordinates[i].thumb_w = 26;
		sliderInfo.coordinates[i].thumb_h = 32;
	}
	sliderInfo.coordinates[0].x = 815;
	sliderInfo.coordinates[0].y = 281;
	sliderInfo.coordinates[0].x_highlight = 869;
	sliderInfo.coordinates[0].y_highlight = 281;
	sliderInfo.coordinates[0].thumb_x = 923;
	sliderInfo.coordinates[0].thumb_y = 281;
	sliderInfo.nThumbOffsetX = -1;
	sliderInfo.nThumbOffsetY = 0;
	sliderInfo.nProcessAlpha = FALSE;
	sliderInfo.nHorizontal = FALSE;
	sliderInfo.nBorderSizeAtMin = 3;
	sliderInfo.nBorderSizeAtMax = 5;

	// --- Volume Channel 1-2 ---
	pSlider = new CGSlider(&m_eventList, IDC_MK2_VOLUME_12, 67, 165, 26, 89, 
		m_pSkinMemDC, m_pSkinAlphaMemDC, &sliderInfo);
	pSlider->SetRange(0, 0xFF);

	pSlider->AddToolTips(g_LOCALIZATION.GetString(IDS_HW_VOLUME_CONTROL));
	AddControl((CGControl *) pSlider);

	// --- Volume Channel 3-4 ---
	pSlider = new CGSlider(&m_eventList, IDC_MK2_VOLUME_34, 131, 165, 26, 89, 
		m_pSkinMemDC, m_pSkinAlphaMemDC, &sliderInfo);
	pSlider->SetRange(0, 0xFF);
	pSlider->AddToolTips(g_LOCALIZATION.GetString(IDS_HW_VOLUME_CONTROL));
	AddControl((CGControl *) pSlider);

	// --- Balance Sliders ---
	for(i=0;i<4;++i) {
		sliderInfo.coordinates[i].x = 1032;
		sliderInfo.coordinates[i].y = 281;
		sliderInfo.coordinates[i].x_highlight = 1032;
		sliderInfo.coordinates[i].y_highlight = 281;
		sliderInfo.coordinates[i].thumb_x = 1105;
		sliderInfo.coordinates[i].thumb_y = 281;
		sliderInfo.coordinates[i].thumb_w = 17;
		sliderInfo.coordinates[i].thumb_h = 25;
	}
	sliderInfo.coordinates[0].x = 977;
	sliderInfo.coordinates[0].y = 281;
	sliderInfo.coordinates[0].x_highlight = 977;
	sliderInfo.coordinates[0].y_highlight = 281;
	sliderInfo.coordinates[0].thumb_x = 1087;
	sliderInfo.coordinates[0].thumb_y = 281;
	sliderInfo.nThumbOffsetX = 0;
	sliderInfo.nThumbOffsetY = 0;
	sliderInfo.nProcessAlpha = FALSE;
	sliderInfo.nHorizontal = TRUE;
	sliderInfo.nBorderSizeAtMin = 3;
	sliderInfo.nBorderSizeAtMax = 3;

	// --- Balance Channel 1-2 ---
	pSlider = new CGSlider(&m_eventList, IDC_MK2_BALANCE_12, 52, 142, 54, 25, 
		m_pSkinMemDC, m_pSkinAlphaMemDC, &sliderInfo);
	pSlider->SetRange(0, 0xFF);
	pSlider->AddToolTips(g_LOCALIZATION.GetString(IDS_DBL_CLICK_RESET_BALANCE));
	AddControl((CGControl *) pSlider);

	// --- Balance Channel 3-4 ---
	pSlider = new CGSlider(&m_eventList, IDC_MK2_BALANCE_34, 117, 142, 54, 25, 
		m_pSkinMemDC, m_pSkinAlphaMemDC, &sliderInfo);
	pSlider->SetRange(0, 0xFF);
	pSlider->AddToolTips(g_LOCALIZATION.GetString(IDS_DBL_CLICK_RESET_BALANCE));
	AddControl((CGControl *) pSlider);

	// --- Talkover Slider ---
	for(i=0;i<4;++i) {
		sliderInfo.coordinates[i].x = 1021;
		sliderInfo.coordinates[i].y = 314;
		sliderInfo.coordinates[i].x_highlight = 1021;
		sliderInfo.coordinates[i].y_highlight = 314;
		sliderInfo.coordinates[i].thumb_x = 1137;
		sliderInfo.coordinates[i].thumb_y = 314;
		sliderInfo.coordinates[i].thumb_w = 17;
		sliderInfo.coordinates[i].thumb_h = 26;
	}
	sliderInfo.coordinates[0].x = 923;
	sliderInfo.coordinates[0].y = 314;
	sliderInfo.coordinates[0].x_highlight = 923;
	sliderInfo.coordinates[0].y_highlight = 314;
	sliderInfo.coordinates[0].thumb_x = 1119;
	sliderInfo.coordinates[0].thumb_y = 314;
	sliderInfo.nThumbOffsetX = 0;
	sliderInfo.nThumbOffsetY = 0;
	sliderInfo.nProcessAlpha = FALSE;
	sliderInfo.nHorizontal = TRUE;
	sliderInfo.nBorderSizeAtMin = 12;
	sliderInfo.nBorderSizeAtMax = 12;

	// --- Talkover Slider ---
	pSlider = new CGSlider(&m_eventList, IDC_MK2_TALKOVER_SLIDER, 280, 346, 97, 26, 
		m_pSkinMemDC, m_pSkinAlphaMemDC, &sliderInfo);
	pSlider->SetRange(0, 2);
	AddControl((CGControl *) pSlider);


	// --- Hercules Logo ---
	for(i=0;i<4;++i)
		buttonInfo[0].coordinates[i].y = 581;
	buttonInfo[0].nProcessAlpha = FALSE;
	buttonInfo[0].coordinates[0].x = 152;
	buttonInfo[0].coordinates[1].x = 240;
	buttonInfo[0].coordinates[2].x = 328;
	buttonInfo[0].coordinates[3].x = 416;

	pCtrl = (CGControl *) new CGButton(&m_eventList, IDC_MK2_HERCULES_LOGO, 
		22,24,87,57,m_pSkinMemDC, m_pSkinAlphaMemDC, 1, buttonInfo);
	AddControl(pCtrl);

	// --- Tab Left ---
	for(i=0;i<4;++i) {
		buttonInfo[0].coordinates[i].y = 400;
		buttonInfo[1].coordinates[i].y = 400;
		buttonInfo[1].coordinates[i].x = 456;
	}
	buttonInfo[0].nProcessAlpha = FALSE;
	buttonInfo[1].nProcessAlpha = FALSE;
	buttonInfo[0].coordinates[0].x = 558;
	buttonInfo[0].coordinates[1].x = 558;
	buttonInfo[0].coordinates[2].x = 660;
	buttonInfo[0].coordinates[3].x = 558;

	pCtrl = (CGControl *) new CGButton(&m_eventList, IDC_MK2_TAB_LEFT, 
		204,100,101,33,m_pSkinMemDC, m_pSkinAlphaMemDC, 2, buttonInfo);
	AddControl(pCtrl);

	// --- Tab Center ---
	for(i=0;i<4;++i) {
		buttonInfo[0].coordinates[i].y = 434;
		buttonInfo[1].coordinates[i].y = 434;
		buttonInfo[1].coordinates[i].x = 456;
	}
	buttonInfo[0].nProcessAlpha = FALSE;
	buttonInfo[1].nProcessAlpha = FALSE;
	buttonInfo[0].coordinates[0].x = 574;
	buttonInfo[0].coordinates[1].x = 574;
	buttonInfo[0].coordinates[2].x = 692;
	buttonInfo[0].coordinates[3].x = 574;

	pCtrl = (CGControl *) new CGButton(&m_eventList, IDC_MK2_TAB_CENTER, 
		305,100,117,33,m_pSkinMemDC, m_pSkinAlphaMemDC, 2, buttonInfo);
	AddControl(pCtrl);

	// --- Tab Right ---
	for(i=0;i<4;++i) {
		buttonInfo[0].coordinates[i].y = 468;
		buttonInfo[1].coordinates[i].y = 468;
		buttonInfo[1].coordinates[i].x = 456;
	}
	buttonInfo[0].nProcessAlpha = FALSE;
	buttonInfo[1].nProcessAlpha = FALSE;
	buttonInfo[0].coordinates[0].x = 563;
	buttonInfo[0].coordinates[1].x = 563;
	buttonInfo[0].coordinates[2].x = 670;
	buttonInfo[0].coordinates[3].x = 563;

	pCtrl = (CGControl *) new CGButton(&m_eventList, IDC_MK2_TAB_RIGHT, 
		422,100,105,33,m_pSkinMemDC, m_pSkinAlphaMemDC, 2, buttonInfo);
	AddControl(pCtrl);

	// --- Lock 1-2 and 3-4 ---
	for(i=0;i<4;++i) {
		buttonInfo[0].coordinates[i].y = 536;
		buttonInfo[1].coordinates[i].y = 536;
	}
	buttonInfo[0].nProcessAlpha = FALSE;
	buttonInfo[1].nProcessAlpha = FALSE;
	buttonInfo[0].coordinates[0].x = 332;
	buttonInfo[0].coordinates[1].x = 353;
	buttonInfo[0].coordinates[2].x = 374;
	buttonInfo[0].coordinates[3].x = 395;
	buttonInfo[1].coordinates[0].x = 416;
	buttonInfo[1].coordinates[1].x = 437;
	buttonInfo[1].coordinates[2].x = 458;
	buttonInfo[1].coordinates[3].x = 479;

	pCtrl = (CGControl *) new CGButton(&m_eventList, IDC_MK2_LOCK_12, 
		35,254,20,22,m_pSkinMemDC, m_pSkinAlphaMemDC, 2, buttonInfo);
	pCtrl->AddToolTips(g_LOCALIZATION.GetString(IDS_AUDIO_SOURCE_LOCK_TTIPS));
	AddControl(pCtrl);
	pCtrl = (CGControl *) new CGButton(&m_eventList, IDC_MK2_LOCK_34, 
		168,254,20,22,m_pSkinMemDC, m_pSkinAlphaMemDC, 2, buttonInfo);
	pCtrl->AddToolTips(g_LOCALIZATION.GetString(IDS_AUDIO_SOURCE_LOCK_TTIPS));
	AddControl(pCtrl);

	// --- Mute 1-2 and 3-4 ---
	for(i=0;i<4;++i) {
		buttonInfo[0].coordinates[i].y = 559;
		buttonInfo[1].coordinates[i].y = 559;
	}
	buttonInfo[0].nProcessAlpha = FALSE;
	buttonInfo[1].nProcessAlpha = FALSE;
	buttonInfo[0].coordinates[0].x = 332;
	buttonInfo[0].coordinates[1].x = 353;
	buttonInfo[0].coordinates[2].x = 374;
	buttonInfo[0].coordinates[3].x = 395;
	buttonInfo[1].coordinates[0].x = 416;
	buttonInfo[1].coordinates[1].x = 437;
	buttonInfo[1].coordinates[2].x = 458;
	buttonInfo[1].coordinates[3].x = 479;

	pCtrl = (CGControl *) new CGButton(&m_eventList, IDC_MK2_MUTE_12, 
		35,176,20,21,m_pSkinMemDC, m_pSkinAlphaMemDC, 2, buttonInfo);
	AddControl(pCtrl);
	pCtrl = (CGControl *) new CGButton(&m_eventList, IDC_MK2_MUTE_34, 
		168,176,20,21,m_pSkinMemDC, m_pSkinAlphaMemDC, 2, buttonInfo);
	AddControl(pCtrl);


	// --- Mic ---
	for(i=0;i<4;++i) {
		buttonInfo[0].coordinates[i].y = 341;
		buttonInfo[1].coordinates[i].y = 341;
	}
	buttonInfo[0].nProcessAlpha = FALSE;
	buttonInfo[1].nProcessAlpha = FALSE;
	buttonInfo[0].coordinates[0].x = 923;
	buttonInfo[0].coordinates[1].x = 962;
	buttonInfo[0].coordinates[2].x = 1001;
	buttonInfo[0].coordinates[3].x = 1040;
	buttonInfo[1].coordinates[0].x = 1079;
	buttonInfo[1].coordinates[1].x = 1118;
	buttonInfo[1].coordinates[2].x = 1118;
	buttonInfo[1].coordinates[3].x = 1118;

	pCtrl = (CGControl *) new CGButton(&m_eventList, IDC_MK2_MIC, 
		37,335,38,33,m_pSkinMemDC, m_pSkinAlphaMemDC, 2, buttonInfo);
	pCtrl->AddToolTips(g_LOCALIZATION.GetString(IDS_INPUT_12_MIC_LINEIN_TTIPS), 220);
	AddControl(pCtrl);

	// --- Line In ---
	for(i=0;i<4;++i) {
		buttonInfo[0].coordinates[i].y = 468;
		buttonInfo[1].coordinates[i].y = 468;
	}
	buttonInfo[0].nProcessAlpha = FALSE;
	buttonInfo[1].nProcessAlpha = FALSE;
	buttonInfo[0].coordinates[0].x = 777;
	buttonInfo[0].coordinates[1].x = 816;
	buttonInfo[0].coordinates[2].x = 855;
	buttonInfo[0].coordinates[3].x = 894;
	buttonInfo[1].coordinates[0].x = 933;
	buttonInfo[1].coordinates[1].x = 972;
	buttonInfo[1].coordinates[2].x = 972;
	buttonInfo[1].coordinates[3].x = 972;

	pCtrl = (CGControl *) new CGButton(&m_eventList, IDC_MK2_LINEIN, 
		77,335,38,33,m_pSkinMemDC, m_pSkinAlphaMemDC, 2, buttonInfo);
	pCtrl->AddToolTips(g_LOCALIZATION.GetString(IDS_INPUT_12_MIC_LINEIN_TTIPS), 220);
	AddControl(pCtrl);

	// --- Talk-Over Attenuation ---
	for(i=0;i<4;++i) {
		buttonInfo[0].coordinates[i].y = 668;
		buttonInfo[1].coordinates[i].y = 668;
	}
	buttonInfo[0].nProcessAlpha = FALSE;
	buttonInfo[1].nProcessAlpha = FALSE;
	buttonInfo[0].coordinates[0].x = 0;
	buttonInfo[0].coordinates[1].x = 39;
	buttonInfo[0].coordinates[2].x = 78;
	buttonInfo[0].coordinates[3].x = 117;
	buttonInfo[1].coordinates[0].x = 156;
	buttonInfo[1].coordinates[1].x = 195;
	buttonInfo[1].coordinates[2].x = 234;
	buttonInfo[1].coordinates[3].x = 273;

	pCtrl = (CGControl *) new CGButton(&m_eventList, IDC_MK2_TALKOVER_ATT, 
		228,335,38,31,m_pSkinMemDC, m_pSkinAlphaMemDC, 2, buttonInfo);
	pCtrl->AddToolTips(g_LOCALIZATION.GetString(IDS_TALKOVER_ATT_LEVEL_TTIPS));
	AddControl(pCtrl);

	// --- Use External Mixer Button ---
	pCtrl = (CGControl *) new CGButton(&m_eventList, IDC_MK2_USE_EXT_MIXER, 
		226,280,38,31,m_pSkinMemDC, m_pSkinAlphaMemDC, 2, buttonInfo);
	pCtrl->AddToolTips(g_LOCALIZATION.GetString(IDS_USE_EXTERNAL_MIXER_TTIPS));
	AddControl(pCtrl);

	// --- DJ Mouse Enable Button ---
	pCtrl = (CGControl *) new CGButton(&m_eventList, IDC_MK2_DJ_MOUSE_ENABLE, 
		226,317,38,31,m_pSkinMemDC, m_pSkinAlphaMemDC, 2, buttonInfo);
	pCtrl->AddToolTips(g_LOCALIZATION.GetString(IDS_DJ_MOUSE_TTIPS));
	AddControl(pCtrl);

	// --- Audio Source ---
	for(i=0;i<4;++i) {
		buttonInfo[0].coordinates[i].y = 571;
		buttonInfo[0].coordinates[i].x = 1099;
		buttonInfo[1].coordinates[i].y = 602;
		buttonInfo[1].coordinates[i].x = 1099;
	}
	buttonInfo[0].nProcessAlpha = FALSE;
	buttonInfo[1].nProcessAlpha = FALSE;
	buttonInfo[0].coordinates[0].x = 1056;
	buttonInfo[1].coordinates[0].x = 1056;
	pCtrl = (CGControl *) new CGButton(&m_eventList, IDC_MK2_AUDIO_SRC_CH12, 
		58,254,42,30,m_pSkinMemDC, m_pSkinAlphaMemDC, 2, buttonInfo);
	pCtrl->AddToolTips(g_LOCALIZATION.GetString(IDS_AUDIO_SOURCE_TTIPS));
	AddControl(pCtrl);
	pCtrl = (CGControl *) new CGButton(&m_eventList, IDC_MK2_AUDIO_SRC_CH34, 
		123,254,42,30,m_pSkinMemDC, m_pSkinAlphaMemDC, 2, buttonInfo);
	pCtrl->AddToolTips(g_LOCALIZATION.GetString(IDS_AUDIO_SOURCE_TTIPS));
	AddControl(pCtrl);

	// --- ON AIR ---
	for(i=0;i<4;++i) {
		buttonInfo[0].coordinates[i].y = 668;
		buttonInfo[0].coordinates[i].x = 364;
	}
	buttonInfo[0].nProcessAlpha = FALSE;
	buttonInfo[0].coordinates[0].x = 312;
	pCtrl = (CGControl *) new CGButton(&m_eventList, IDC_MK2_ON_AIR, 
		382,335,51,30,m_pSkinMemDC, m_pSkinAlphaMemDC, 1, buttonInfo);
	pCtrl->AddToolTips(g_LOCALIZATION.GetString(IDS_ON_AIR_TTIPS));
	AddControl(pCtrl);


	// --- Headphone Selection ---
	for(i=0;i<4;++i) {
		buttonInfo[0].coordinates[i].y = 447;
		buttonInfo[0].coordinates[i].x = 1089;
		buttonInfo[1].coordinates[i].y = 478;
		buttonInfo[1].coordinates[i].x = 1089;
		buttonInfo[2].coordinates[i].y = 509;
		buttonInfo[2].coordinates[i].x = 1089;
		buttonInfo[3].coordinates[i].y = 540;
		buttonInfo[3].coordinates[i].x = 1089;
	}
	buttonInfo[0].nProcessAlpha = FALSE;
	buttonInfo[1].nProcessAlpha = FALSE;
	buttonInfo[2].nProcessAlpha = FALSE;
	buttonInfo[3].nProcessAlpha = FALSE;
	buttonInfo[0].coordinates[0].x = 1036;
	buttonInfo[1].coordinates[0].x = 1036;
	buttonInfo[2].coordinates[0].x = 1036;
	buttonInfo[3].coordinates[0].x = 1036;
	pCtrl = (CGControl *) new CGButton(&m_eventList, IDC_MK2_HEADPHONE_SELECTION, 
		454,335,52,30,m_pSkinMemDC, m_pSkinAlphaMemDC, 4, buttonInfo);
	pCtrl->AddToolTips(g_LOCALIZATION.GetString(IDS_MK2_HEADPHONE_TTIPS));
	AddControl(pCtrl);

	// --- Input 3-4 Disable ---
	staticInfo[0].x = 456;
	staticInfo[0].y = 502;
	staticInfo[0].nProcessAlpha = FALSE;

	pStaticImg = new CGStatic(&m_eventList, IDC_MK2_INPUT_34_DISABLE, 
		131,335,34,29, m_pSkinMemDC, m_pSkinAlphaMemDC, 1, staticInfo);
	pStaticImg->Hide(TRUE);
	AddControl((CGControl *) pStaticImg);

	// --- Deck Mix ---
	staticInfo[0].x = 504;
	staticInfo[0].y = 502;
	staticInfo[0].nProcessAlpha = FALSE;
	staticInfo[1].x = 637;
	staticInfo[1].y = 502;
	staticInfo[1].nProcessAlpha = FALSE;
	staticInfo[2].x = 770;
	staticInfo[2].y = 502;
	staticInfo[2].nProcessAlpha = FALSE;
	staticInfo[3].x = 903;
	staticInfo[3].y = 502;
	staticInfo[3].nProcessAlpha = FALSE;
	staticInfo[4].x = 504;
	staticInfo[4].y = 611;
	staticInfo[4].nProcessAlpha = FALSE;
	staticInfo[5].x = 637;
	staticInfo[5].y = 611;
	staticInfo[5].nProcessAlpha = FALSE;
	staticInfo[6].x = 770;
	staticInfo[6].y = 611;
	staticInfo[6].nProcessAlpha = FALSE;

	pStaticImg = new CGStatic(&m_eventList, IDC_MK2_DECK_MIX, 
		375,258,132,108, m_pSkinMemDC, m_pSkinAlphaMemDC, 7, staticInfo);
	pStaticImg->AddToolTips(g_LOCALIZATION.GetString(IDS_CROSS_FADER_GRAPH_TTIPS));
	pStaticImg->SetState(4);
	AddControl((CGControl *) pStaticImg);


	// --- Static Information: Main, Advanced, About ---
	pStatic = new CGStaticText(&m_eventList, IDC_MK2_STATIC_MAIN, g_LOCALIZATION.GetString(IDS_TAB_MAIN), 
		204,102,101,33, ALIGN_CENTER|VALIGN_CENTER);
	pStatic->SetFontAttributes(true, false);
	AddControl((CGControl *) pStatic);
	pStatic = new CGStaticText(&m_eventList, IDC_MK2_STATIC_ADVANCED, g_LOCALIZATION.GetString(IDS_TAB_ADVANCED), 
		305,102,117,33, ALIGN_CENTER|VALIGN_CENTER);
	pStatic->SetFontAttributes(true, false);
	AddControl((CGControl *) pStatic);
	pStatic = new CGStaticText(&m_eventList, IDC_MK2_STATIC_ABOUT, g_LOCALIZATION.GetString(IDS_TAB_ABOUT), 
		422,102,105,33, ALIGN_CENTER|VALIGN_CENTER);
	pStatic->SetFontAttributes(true, false);
	AddControl((CGControl *) pStatic);

	pStatic = new CGStaticText(&m_eventList, IDC_MK2_STATIC_TALK_ATT, 
		g_LOCALIZATION.GetString(IDS_TALKOVER_ATT_UPCASE), 
		250,301,160,10, ALIGN_LEFT|VALIGN_CENTER);
	pStatic->SetFontAttributes(true, false);
	AddControl((CGControl *) pStatic);
	pStatic = new CGStaticText(&m_eventList, IDC_MK2_STATIC_OUT_CHANNELS, 
		g_LOCALIZATION.GetString(IDS_OUTPUT_CHANNELS), 
		56,106,109,10, ALIGN_CENTER|VALIGN_CENTER);
	pStatic->SetFontAttributes(true, false);
	AddControl((CGControl *) pStatic);
	pStatic = new CGStaticText(&m_eventList, IDC_MK2_STATIC_IN_CHANNELS, 
		g_LOCALIZATION.GetString(IDS_INPUT_CHANNELS), 
		56,301,109,10, ALIGN_CENTER|VALIGN_CENTER);
	pStatic->SetFontAttributes(true, false);
	AddControl((CGControl *) pStatic);
	pStatic = new CGStaticText(&m_eventList, IDC_MK2_STATIC_TALKATT_VALUE, "0 dB", 
		292,326,66,10, ALIGN_LEFT|VALIGN_CENTER);
	pStatic->SetFontAttributes(true, false);
	AddControl((CGControl *) pStatic);

	// --- ADVANCED Static ---
	pStatic = new CGStaticText(&m_eventList, IDC_MK2_STATIC_CROSS_FADER, 
		g_LOCALIZATION.GetString(IDS_CROSS_FADER_SETTINGS), 
		236,195,262,10, ALIGN_CENTER|VALIGN_CENTER);
	pStatic->SetFontAttributes(true, false);
	AddControl((CGControl *) pStatic);
	pStatic = new CGStaticText(&m_eventList, IDC_MK2_STATIC_USE_EXT_MIXER, 
		g_LOCALIZATION.GetString(IDS_USE_EXTERNAL_MIXER), 
		228,256,142,10, ALIGN_LEFT|VALIGN_CENTER);
	pStatic->SetFontAttributes(true, false);
	AddControl((CGControl *) pStatic);
	pStatic = new CGStaticText(&m_eventList, IDC_MK2_STATIC_ENABLE_DJ_MOUSE, 
		g_LOCALIZATION.GetString(IDS_DJ_MOUSE_UPCASE), 
		228,356,142,10, ALIGN_LEFT|VALIGN_CENTER);
	pStatic->SetFontAttributes(true, false);
	AddControl((CGControl *) pStatic);

	// --- ABOUT Static ---
	pStatic = new CGStaticText(&m_eventList, IDC_MK2_STATIC_ABOUT_NOTE1, 
		g_LOCALIZATION.GetString(IDS_TECH_SUPPORT_INFO_NOTE_1), 
		238,174,262,10, ALIGN_LEFT|VALIGN_CENTER);
	pStatic->SetFontAttributes(true, false);
	AddControl((CGControl *) pStatic);
	pStatic = new CGStaticText(&m_eventList, IDC_MK2_STATIC_ABOUT_NOTE2, 
		g_LOCALIZATION.GetString(IDS_TECH_SUPPORT_INFO_NOTE_2), 
		238,188,262,10, ALIGN_LEFT|VALIGN_CENTER);
	pStatic->SetFontAttributes(true, false);
	AddControl((CGControl *) pStatic);
	pStatic = new CGStaticText(&m_eventList, IDC_MK2_STATIC_ABOUT_INFO1, "Package: n/a", 
		238,224,262,10, ALIGN_LEFT|VALIGN_CENTER);
	pStatic->SetFontAttributes(true, false);
	AddControl((CGControl *) pStatic);
	pStatic = new CGStaticText(&m_eventList, IDC_MK2_STATIC_ABOUT_INFO2, "Firmware: n/a", 
		238,252,262,10, ALIGN_LEFT|VALIGN_CENTER);
	pStatic->SetFontAttributes(true, false);
	AddControl((CGControl *) pStatic);
	pStatic = new CGStaticText(&m_eventList, IDC_MK2_STATIC_ABOUT_INFO3, "Driver: n/a", 
		238,266,262,10, ALIGN_LEFT|VALIGN_CENTER);
	pStatic->SetFontAttributes(true, false);
	AddControl((CGControl *) pStatic);

	pStatic = new CGStaticText(&m_eventList, IDC_MK2_STATIC_ABOUT_INFO4, "CPL: n/a", 
		238,280,262,10, ALIGN_LEFT|VALIGN_CENTER);
	pStatic->SetFontAttributes(true, false);
	AddControl((CGControl *) pStatic);
	pStatic = new CGStaticText(&m_eventList, IDC_MK2_STATIC_ABOUT_COPYRIGHT1,
 		g_LOCALIZATION.GetString(IDS_COPYRIGHT), 
		238,330,262,10, ALIGN_LEFT|VALIGN_CENTER);
	pStatic->SetFontAttributes(true, false);
	AddControl((CGControl *) pStatic);
	pStatic = new CGStaticText(&m_eventList, IDC_MK2_STATIC_ABOUT_COPYRIGHT2,
 		g_LOCALIZATION.GetString(IDS_RIGHTS_RESERVED), 
		238,344,262,10, ALIGN_LEFT|VALIGN_CENTER);
	pStatic->SetFontAttributes(true, false);
	AddControl((CGControl *) pStatic);

	// --- Combo Box ---
	comboInfo.sbckBottom.x = 729;
	comboInfo.sbckBottom.y = 381;
	comboInfo.sbckBottom.w = 18;
	comboInfo.sbckBottom.h = 3;

	comboInfo.sbckMiddle.x = 710;
	comboInfo.sbckMiddle.y = 381;
	comboInfo.sbckMiddle.w = 18;
	comboInfo.sbckMiddle.h = 10+6;

	comboInfo.sbckTop.x = 691;
	comboInfo.sbckTop.y = 381;
	comboInfo.sbckTop.w = 18;
	comboInfo.sbckTop.h = 3;

	comboInfo.sbutBottom[0].x = 539;
	comboInfo.sbutBottom[0].y = 381;
	comboInfo.sbutBottom[0].w = 18;
	comboInfo.sbutBottom[0].h = 12;
	comboInfo.sbutBottom[1].x = 558;
	comboInfo.sbutBottom[1].y = 381;
	comboInfo.sbutBottom[1].w = 18;
	comboInfo.sbutBottom[1].h = 12;
	comboInfo.sbutBottom[2].x = 577;
	comboInfo.sbutBottom[2].y = 381;
	comboInfo.sbutBottom[2].w = 18;
	comboInfo.sbutBottom[2].h = 12;
	comboInfo.sbutBottom[3].x = 596;
	comboInfo.sbutBottom[3].y = 381;
	comboInfo.sbutBottom[3].w = 18;
	comboInfo.sbutBottom[3].h = 12;

	comboInfo.sbutTop[0].x = 615;
	comboInfo.sbutTop[0].y = 381;
	comboInfo.sbutTop[0].w = 18;
	comboInfo.sbutTop[0].h = 12;
	comboInfo.sbutTop[1].x = 634;
	comboInfo.sbutTop[1].y = 381;
	comboInfo.sbutTop[1].w = 18;
	comboInfo.sbutTop[1].h = 12;
	comboInfo.sbutTop[2].x = 653;
	comboInfo.sbutTop[2].y = 381;
	comboInfo.sbutTop[2].w = 18;
	comboInfo.sbutTop[2].h = 12;
	comboInfo.sbutTop[3].x = 672;
	comboInfo.sbutTop[3].y = 381;
	comboInfo.sbutTop[3].w = 18;
	comboInfo.sbutTop[3].h = 12;

	comboInfo.stmbBottom.x = 776;
	comboInfo.stmbBottom.y = 381;
	comboInfo.stmbBottom.w = 13;
	comboInfo.stmbBottom.h = 4;

	comboInfo.stmbMiddle.x = 762;
	comboInfo.stmbMiddle.y = 381;
	comboInfo.stmbMiddle.w = 13;
	comboInfo.stmbMiddle.h = 10;

	comboInfo.stmbTop.x = 748;
	comboInfo.stmbTop.y = 381;
	comboInfo.stmbTop.w = 13;
	comboInfo.stmbTop.h = 4;

	comboInfo.colorFont.r = 0x00;
	comboInfo.colorFont.g = 0x00;
	comboInfo.colorFont.b = 0x00;

	comboInfo.nBoxLeftSpace = 5;

	comboInfo.HighlightBckgrndColor.r = 0x00;
	comboInfo.HighlightBckgrndColor.g = 0x00;
	comboInfo.HighlightBckgrndColor.b = 0xFF;

	comboInfo.HighlightForegrndColor.r = 0xFF;
	comboInfo.HighlightForegrndColor.g = 0xFF;
	comboInfo.HighlightForegrndColor.b = 0xFF;

	comboInfo.nFontSizeBox = 8;
	comboInfo.nFontSizeList = 8;


	// --- Combo Box Long ---
	comboInfo.box[0].x = 815;
	comboInfo.box[0].y = 375;
	comboInfo.box[2].x = 815;
	comboInfo.box[2].y = 399;
	comboInfo.box[1].x = 815;
	comboInfo.box[1].y = 423;//476;
	comboInfo.box[3].x = 815;
	comboInfo.box[3].y = 423;//498;

	comboInfo.borderList.l = 3;
	comboInfo.borderList.r = 4;
	comboInfo.borderList.t = 10;
	comboInfo.borderList.b = 10;

	comboInfo.list.x = 539;	// Combo Cross Fader.
	comboInfo.list.y = 281;

	// --- Cross Fader Combo ---
	pComboBox = new CGComboBox(&m_eventList, IDC_MK2_COMBO_CROSS_FADER, 229, 209, 275, 23, 99, 
		m_pSkinMemDC, m_pSkinAlphaMemDC,&comboInfo);

	AddControl((CGControl *) pComboBox);
	pComboBox->ResetContent();
	pComboBox->AddString(g_LOCALIZATION.GetString(IDS_BEATMIX_CURVE));
	pComboBox->AddString(g_LOCALIZATION.GetString(IDS_DIPPED_CURVE));
	pComboBox->AddString(g_LOCALIZATION.GetString(IDS_SCRATCH_CURVE));
	pComboBox->AddString(g_LOCALIZATION.GetString(IDS_CROSS_FADER_LOCK_DECK_A));
	pComboBox->AddString(g_LOCALIZATION.GetString(IDS_CROSS_FADER_LOCK_DECK_B));
	pComboBox->AddString(g_LOCALIZATION.GetString(IDS_CROSS_FADER_LOCK_CENTER));
	pComboBox->AddToolTips(g_LOCALIZATION.GetString(IDS_CROSS_FADER_TTIPS));

	// --- CPL Test ---
	bASIOMode = true;
	nCPLTab = 0;

	SetTab(nCPLTab);
}

CDevMk2Dlg::~CDevMk2Dlg( )
{
}

// ---------------------------------------------------------------------------
// Function: SetTab
//
// Hide/Show controls base on the tab position (main, advanced or about).
// ---------------------------------------------------------------------------
bool CDevMk2Dlg::SetTab( int nTab )
{
	CGButton *pButton;
	bool bTab1, bTab2, bTab3;

	if (nTab<0 || nTab>2)
		return false;

	bTab1 = (nTab==0);
	bTab2 = (nTab==1);
	bTab3 = (nTab==2);

	pButton = (CGButton *) GetControl(IDC_MK2_TAB_LEFT);
	pButton->SetState(bTab1 ? 1 : 0);
	pButton = (CGButton *) GetControl(IDC_MK2_TAB_CENTER);
	pButton->SetState(bTab2 ? 1 : 0);
	pButton = (CGButton *) GetControl(IDC_MK2_TAB_RIGHT);
	pButton->SetState(bTab3 ? 1 : 0);

	GetControl(IDC_MK2_ADVANCED_TAB)->Hide(!bTab2);
	GetControl(IDC_MK2_ABOUT_TAB)->Hide(!bTab3);

	GetControl(IDC_MK2_TALKOVER_ATT)->Hide(!bTab1);
	GetControl(IDC_MK2_HEADPHONE_SELECTION)->Hide(!bTab1);
	GetControl(IDC_MK2_ON_AIR)->Hide(!bTab1);
	GetControl(IDC_MK2_TALKOVER_SLIDER)->Hide(!bTab1);
	GetControl(IDC_MK2_STATIC_TALK_ATT)->Hide(!bTab1);
	GetControl(IDC_MK2_STATIC_TALKATT_VALUE)->Hide(!bTab1);

	GetControl(IDC_MK2_USE_EXT_MIXER)->Hide(!bTab2);
	GetControl(IDC_MK2_DJ_MOUSE_ENABLE)->Hide(!bTab2);
	GetControl(IDC_MK2_COMBO_CROSS_FADER)->Hide(!bTab2);
	GetControl(IDC_MK2_STATIC_CROSS_FADER)->Hide(!bTab2);
	GetControl(IDC_MK2_STATIC_USE_EXT_MIXER)->Hide(!bTab2);
	GetControl(IDC_MK2_STATIC_ENABLE_DJ_MOUSE)->Hide(!bTab2);
	GetControl(IDC_MK2_DECK_MIX)->Hide(!bTab2);

	GetControl(IDC_MK2_STATIC_ABOUT_NOTE1)->Hide(!bTab3);
	GetControl(IDC_MK2_STATIC_ABOUT_NOTE2)->Hide(!bTab3);
	GetControl(IDC_MK2_STATIC_ABOUT_INFO1)->Hide(!bTab3);
	GetControl(IDC_MK2_STATIC_ABOUT_INFO2)->Hide(!bTab3);
	GetControl(IDC_MK2_STATIC_ABOUT_INFO3)->Hide(!bTab3);
	GetControl(IDC_MK2_STATIC_ABOUT_INFO4)->Hide(!bTab3);
	GetControl(IDC_MK2_STATIC_ABOUT_COPYRIGHT1)->Hide(!bTab3);
	GetControl(IDC_MK2_STATIC_ABOUT_COPYRIGHT2)->Hide(!bTab3);
	m_nTab = nTab;
	return true;
}

// ---------------------------------------------------------------------------
// Function: MouseEvent
//
// Process mouse events for all controls available on the DJ Console Mk2.
// ---------------------------------------------------------------------------
bool CDevMk2Dlg::MouseEvent( int x, int y, int button, PREFRESH_RECT refreshRect )
{
	bool		bMouseEvent = false;
	bool		bProcessEvent, bResult;
	int		nControlID, nMsg, nValue, w1, w2;
	unsigned long	ulParam1, ulParam2;
	char 		szText[40];
	CROSSFADER_SEL	crossFaderSelection;
	CGStatic 	*pStaticImg;
	CGStaticText	*pStatic;
	CGButton	*pButton, *pButton2;
	CGSlider	*pSlider;

	bMouseEvent = CGDialog::MouseEvent(x,y,button, refreshRect);

	do
	{
		bProcessEvent = GetEvent(&nControlID, &nMsg, &ulParam1, &ulParam2);
		if (bProcessEvent) {
			switch(nControlID)
			{
			case IDC_MK2_TAB_LEFT:
				SetTab(0);
				refreshRect->x = 0; refreshRect->y = 0;
				refreshRect->w = m_nWidth; refreshRect->h = m_nHeight;
				break;
			case IDC_MK2_TAB_CENTER:
				SetTab(1);
				refreshRect->x = 0; refreshRect->y = 0;
				refreshRect->w = m_nWidth; refreshRect->h = m_nHeight;
				break;
			case IDC_MK2_TAB_RIGHT:
				SetTab(2);
				refreshRect->x = 0; refreshRect->y = 0;
				refreshRect->w = m_nWidth; refreshRect->h = m_nHeight;
				break;
			case IDC_MK2_HERCULES_LOGO:
				m_helpers.LaunchInternetBrowser(g_LOCALIZATION.GetString(IDS_HTTP_MK2));
				break;
			}

			if(m_pDeviceState)
			{
				switch(nControlID)
				{
				case IDC_MK2_DJ_MOUSE_ENABLE:
					bResult = m_pDManager->EnableDJMouse(ulParam1==1, m_pDeviceState);
					break;
				case IDC_MK2_USE_EXT_MIXER:
					bResult = m_pDManager->UseExternalMixer(ulParam1==1, m_pDeviceState);
					break;
				case IDC_MK2_COMBO_CROSS_FADER:
					pStaticImg = (CGStatic *) GetControl(IDC_MK2_DECK_MIX);
					switch(ulParam1)
					{
					case 0:
					default:
						crossFaderSelection = BEATMIX;
						break;
					case 1:
						crossFaderSelection = DIPPED;
						break;
					case 2:
						crossFaderSelection = SCRATCH;
						break;
					case 3:
						crossFaderSelection = LOCK_ON_A;
						break;
					case 4:
						crossFaderSelection = LOCK_ON_B;
						break;
					case 5:
						crossFaderSelection = LOCK_ON_CENTER;
						break;
					}
					bResult = m_pDManager->SetCrossFaderCurve(crossFaderSelection, m_pDeviceState);
					pStaticImg->SetState(ulParam1+1);
					break;
				case IDC_MK2_TALKOVER_ATT:
					pButton = (CGButton *) GetControl(IDC_MK2_TALKOVER_ATT);
					pSlider = (CGSlider *) GetControl(IDC_MK2_TALKOVER_SLIDER);
					pSlider->Enable(pButton->GetState()==1);
					bResult = m_pDManager->EnableTalkover(pButton->GetState()==1,
						m_pDeviceState);
					break;
				case IDC_MK2_TALKOVER_SLIDER:
					pSlider = (CGSlider *) GetControl(IDC_MK2_TALKOVER_SLIDER);
					bResult = m_pDManager->SetTalkoverAttenuation(pSlider->GetPos()*3+3,
						m_pDeviceState);
					sprintf(szText, "-%d dB", m_pDeviceState->djConsoleMk2.nTalkoverAttenuation);
					pStatic = (CGStaticText *) GetControl(IDC_MK2_STATIC_TALKATT_VALUE);
					pStatic->SetLabel(szText);
					break;
				case IDC_MK2_MIC:
					pButton = (CGButton *) GetControl(IDC_MK2_MIC);
					pButton2= (CGButton *) GetControl(IDC_MK2_LINEIN);
					pButton2->SetState(pButton->GetState()==0);
					m_pDManager->SetRecordInput(MIC, m_pDeviceState);
					break;
				case IDC_MK2_LINEIN:
					pButton = (CGButton *) GetControl(IDC_MK2_LINEIN);
					pButton2= (CGButton *) GetControl(IDC_MK2_MIC);
					pButton2->SetState(pButton->GetState()==0);
					m_pDManager->SetRecordInput(LINE_IN, m_pDeviceState);
					break;
				case IDC_MK2_VOLUME_12:
					pSlider = (CGSlider *) GetControl(IDC_MK2_BALANCE_12);
					nValue = pSlider->GetPos();
					w1 = (nValue<128) ? 128 : 128*(255-nValue)/127;
					w2 = (nValue>127) ? 128 : nValue;
					m_pDeviceState->nVolumeToApply[0] = w1 * ulParam1 / 128;
					m_pDeviceState->nVolumeToApply[1] = w2 * ulParam1 / 128;
					m_pDeviceState->bVolumeToApply[0] = true;
					m_pDeviceState->bVolumeToApply[1] = true;
					break;
				case IDC_MK2_VOLUME_34:
					pSlider = (CGSlider *) GetControl(IDC_MK2_BALANCE_34);
					nValue = pSlider->GetPos();
					w1 = (nValue<128) ? 128 : 128*(255-nValue)/127;
					w2 = (nValue>127) ? 128 : nValue;
					m_pDeviceState->nVolumeToApply[2] = w1 * ulParam1 / 128;
					m_pDeviceState->nVolumeToApply[3] = w2 * ulParam1 / 128;
					m_pDeviceState->bVolumeToApply[2] = true;
					m_pDeviceState->bVolumeToApply[3] = true;
					break;
				case IDC_MK2_BALANCE_12:
					if (nMsg==GEVENT_SLIDER_DCLICK)
					{
						pSlider = (CGSlider *) GetControl(IDC_MK2_BALANCE_12);
						pSlider->SetPos(128);
						w1 = w2 = 128;
					}
					else
					{
						w1 = (ulParam1<128) ? 128 : 128*(255-ulParam1)/127;
						w2 = (ulParam1>127) ? 128 : ulParam1;
					}
					pSlider = (CGSlider *) GetControl(IDC_MK2_VOLUME_12);
					nValue = pSlider->GetPos();
					m_pDeviceState->nVolumeToApply[0] = w1 * nValue / 128;
					m_pDeviceState->nVolumeToApply[1] = w2 * nValue / 128;
					m_pDeviceState->bVolumeToApply[0] = true;
					m_pDeviceState->bVolumeToApply[1] = true;
					break;
				case IDC_MK2_BALANCE_34:
					if (nMsg==GEVENT_SLIDER_DCLICK)
					{
						pSlider = (CGSlider *) GetControl(IDC_MK2_BALANCE_34);
						pSlider->SetPos(128);
						w1 = w2 = 128;
					}
					else
					{
						w1 = (ulParam1<128) ? 128 : 128*(255-ulParam1)/127;
						w2 = (ulParam1>127) ? 128 : ulParam1;
					}
					pSlider = (CGSlider *) GetControl(IDC_MK2_VOLUME_34);
					nValue = pSlider->GetPos();
					m_pDeviceState->nVolumeToApply[2] = w1 * nValue / 128;
					m_pDeviceState->nVolumeToApply[3] = w2 * nValue / 128;
					m_pDeviceState->bVolumeToApply[2] = true;
					m_pDeviceState->bVolumeToApply[3] = true;
					break;
				case IDC_MK2_MUTE_12:
					m_pDManager->SetMute(m_pDeviceState, 0, ulParam1==1);
					break;
				case IDC_MK2_MUTE_34:
					m_pDManager->SetMute(m_pDeviceState, 1, ulParam1==1);
					break;
				case IDC_MK2_LOCK_12:
					m_pDManager->SetLockState(0, ulParam1==1, m_pDeviceState);
					break;
				case IDC_MK2_LOCK_34:
					m_pDManager->SetLockState(1, ulParam1==1, m_pDeviceState);
					break;
				case IDC_MK2_AUDIO_SRC_CH12:
				case IDC_MK2_AUDIO_SRC_CH34:
					pButton = (CGButton *) GetControl(nControlID);
					pButton->SetState(pButton->GetState()==0 ? 1 : 0);
					break;
				}
			}
		}
	} while (bProcessEvent);

	return bMouseEvent;
}

// ---------------------------------------------------------------------------
// Function: ApplyVolume
//
// For each volume which need to be set, call SetVolume to adjust it.
// ---------------------------------------------------------------------------
bool CDevMk2Dlg::ApplyVolume( DJ_DEVICE_STATE *pDeviceState )
{
	int nValue, i;
	bool bRefresh = false;
	
	for(i=0;i<4;++i)
	{
		if (pDeviceState->bVolumeToApply[i])
		{
			pDeviceState->bVolumeToApply[i] = false;
			nValue = pDeviceState->nVolumeToApply[i];
			m_pDManager->SetVolume(m_pDeviceState, i, nValue);
			pDeviceState->djConsoleMk2.nVolume[i] = nValue;
			bRefresh = true;
		}
	}
	return bRefresh;
}

// ---------------------------------------------------------------------------
// Function: InitializeHIDState
//
// Set the ON AIR state, Headphone Selection, Audio Sources and Lock state
// base on the device state.
// ---------------------------------------------------------------------------
void CDevMk2Dlg::InitializeHIDState( DJ_DEVICE_STATE *pDeviceState, CDManager *pDeviceManager )
{
	CGButton *pButton;

	// --- Headphone Selection ---
	pButton = (CGButton *) GetControl(IDC_MK2_HEADPHONE_SELECTION);
	switch(pDeviceState->djConsoleMk2.eHeadphoneSelection)
	{
	case DECK_A:
		pButton->SetState(0);
		break;
	case DECK_B:
		pButton->SetState(1);
		break;
	case MIX:
		pButton->SetState(2);
		break;
	case SPLIT:
		pButton->SetState(3);
		break;
	}

	// --- On Air ---
	pButton = (CGButton *) GetControl(IDC_MK2_ON_AIR);
	pButton->Enable(pDeviceState->djConsoleMk2.bOnAir);

	// --- Audio Sources ---
	pButton = (CGButton *) GetControl(IDC_MK2_AUDIO_SRC_CH12);
	pButton->SetState(pDeviceState->djConsoleMk2.eAudioSourceSelection[0]==MK2_AUDIO_INPUT);
	pButton = (CGButton *) GetControl(IDC_MK2_AUDIO_SRC_CH34);
	pButton->SetState(pDeviceState->djConsoleMk2.eAudioSourceSelection[1]==MK2_AUDIO_INPUT);

	// --- Lock State ---
	pButton = (CGButton *) GetControl(IDC_MK2_LOCK_12);
	pButton->SetState(pDeviceState->djConsoleMk2.bLockAudioSource[0]);
	pButton = (CGButton *) GetControl(IDC_MK2_LOCK_34);
	pButton->SetState(pDeviceState->djConsoleMk2.bLockAudioSource[1]);
	DEBUG_PRINT("CDevMk2Dlg::InitializeHIDState completed.");
}

// ---------------------------------------------------------------------------
// Function: InitializeMixerState
//
// Set the mixer (volume, mute) states base on the device state.
// ---------------------------------------------------------------------------
void CDevMk2Dlg::InitializeMixerState( DJ_DEVICE_STATE *pDeviceState, CDManager *pDeviceManager )
{
	CGButton *pButton;
	CGSlider *pSlider;
	int nValue;

	// --- Mute ---
	pButton = (CGButton *) GetControl(IDC_MK2_MUTE_12);
	pButton->SetState(pDeviceState->djConsoleMk2.bMute[0]);
	pButton = (CGButton *) GetControl(IDC_MK2_MUTE_34);
	pButton->SetState(pDeviceState->djConsoleMk2.bMute[1]);

	// --- Volumes ---
	pSlider = (CGSlider *) GetControl(IDC_MK2_VOLUME_12);
	pSlider->SetPos( (pDeviceState->djConsoleMk2.nVolume[0]>pDeviceState->djConsoleMk2.nVolume[1]) ?
		pDeviceState->djConsoleMk2.nVolume[0] : pDeviceState->djConsoleMk2.nVolume[1]);
	pSlider = (CGSlider *) GetControl(IDC_MK2_VOLUME_34);
	pSlider->SetPos( (pDeviceState->djConsoleMk2.nVolume[2]>pDeviceState->djConsoleMk2.nVolume[3]) ?
		pDeviceState->djConsoleMk2.nVolume[2] : pDeviceState->djConsoleMk2.nVolume[3]);

	// --- Balance ---
	nValue = 128;
	if (pDeviceState->djConsoleMk2.nVolume[0]<pDeviceState->djConsoleMk2.nVolume[1])
	{
		nValue = 128+127*(pDeviceState->djConsoleMk2.nVolume[1] - pDeviceState->djConsoleMk2.nVolume[0])/
			pDeviceState->djConsoleMk2.nVolume[1];
	}
	else if (pDeviceState->djConsoleMk2.nVolume[0]>pDeviceState->djConsoleMk2.nVolume[1])
	{
		nValue = 128-128*(pDeviceState->djConsoleMk2.nVolume[0] - pDeviceState->djConsoleMk2.nVolume[1])/
			pDeviceState->djConsoleMk2.nVolume[0];
	}
	pSlider = (CGSlider *) GetControl(IDC_MK2_BALANCE_12);
	pSlider->SetPos(nValue);

	nValue = 128;
	if (pDeviceState->djConsoleMk2.nVolume[2]<pDeviceState->djConsoleMk2.nVolume[3])
	{
		nValue = 128+127*(pDeviceState->djConsoleMk2.nVolume[3] - pDeviceState->djConsoleMk2.nVolume[2])/
			pDeviceState->djConsoleMk2.nVolume[3];
	}
	else if (pDeviceState->djConsoleMk2.nVolume[2]>pDeviceState->djConsoleMk2.nVolume[3])
	{
		nValue = 128-128*(pDeviceState->djConsoleMk2.nVolume[2] - pDeviceState->djConsoleMk2.nVolume[3])/
			pDeviceState->djConsoleMk2.nVolume[2];
	}
	pSlider = (CGSlider *) GetControl(IDC_MK2_BALANCE_34);
	pSlider->SetPos(nValue);
	DEBUG_PRINT("CDevMk2Dlg::InitializeMixerState completed.");
}

// ---------------------------------------------------------------------------
// Function: InitializeDlgState
//
// Set various hardware setting (excluding HID and Audio Mixer).
// ---------------------------------------------------------------------------
void CDevMk2Dlg::InitializeDlgState( DJ_DEVICE_STATE *pDeviceState, CDManager *pDeviceManager )
{
	char szText[80];
	CGStaticText *pStatic;
	CGStatic *pStaticImg;
	CGComboBox *pCombo;
	CGButton *pButton;
	CGSlider *pSlider;

	CGDialog::InitializeDlgState(pDeviceState, pDeviceManager);

	// --- Initialize mixer/HID controls ---
	InitializeMixerState(pDeviceState, pDeviceManager);
	InitializeHIDState(pDeviceState, pDeviceManager);

	// --- Record Input ---
	pButton = (CGButton *) GetControl(IDC_MK2_MIC);
	pButton->SetState(pDeviceState->djConsoleMk2.bEnableInputMic);
	pButton = (CGButton *) GetControl(IDC_MK2_LINEIN);
	pButton->SetState(!pDeviceState->djConsoleMk2.bEnableInputMic);

	// --- Talkover Attenuation ---
	pButton = (CGButton *) GetControl(IDC_MK2_TALKOVER_ATT);
	pButton->SetState(pDeviceState->djConsoleMk2.bTalkoverAttenuation);
	pSlider = (CGSlider *) GetControl(IDC_MK2_TALKOVER_SLIDER);
	pSlider->Enable(pDeviceState->djConsoleMk2.bTalkoverAttenuation);
	pSlider->SetPos((pDeviceState->djConsoleMk2.nTalkoverAttenuation-3)/3);
	sprintf(szText, "-%d dB", pDeviceState->djConsoleMk2.nTalkoverAttenuation);
	pStatic = (CGStaticText *) GetControl(IDC_MK2_STATIC_TALKATT_VALUE);
	pStatic->SetLabel(szText);


	// --- Cross Fader Curve ---
	pCombo = (CGComboBox *) GetControl(IDC_MK2_COMBO_CROSS_FADER);
	pStaticImg = (CGStatic *) GetControl(IDC_MK2_DECK_MIX);

	switch(pDeviceState->djConsoleMk2.eCrossFaderCurve)
	{
	case BEATMIX:
		pCombo->SetCurSel(0);
		pStaticImg->SetState(1);
		break;
	case DIPPED:
		pCombo->SetCurSel(1);
		pStaticImg->SetState(2);
		break;
	case SCRATCH:
		pCombo->SetCurSel(2);
		pStaticImg->SetState(3);
		break;
	case LOCK_ON_A:
		pCombo->SetCurSel(3);
		pStaticImg->SetState(4);
		break;
	case LOCK_ON_B:
		pCombo->SetCurSel(4);
		pStaticImg->SetState(5);
		break;
	case LOCK_ON_CENTER:
		pCombo->SetCurSel(5);
		pStaticImg->SetState(6);
		break;
	}

	// --- Use external mixer --
	pButton = (CGButton *) GetControl(IDC_MK2_USE_EXT_MIXER);
	pButton->SetState(pDeviceState->djConsoleMk2.bUseExternalMixer);

	// --- Enable DJ Mouse ---
	pButton = (CGButton *) GetControl(IDC_MK2_DJ_MOUSE_ENABLE);
	pButton->SetState(pDeviceState->djConsoleMk2.bEnableDJMouse);

	// --- Information ---
	pStatic = (CGStaticText *) GetControl(IDC_MK2_STATIC_ABOUT_INFO1);
	sprintf(szText, "%s %s", g_LOCALIZATION.GetString(IDS_PACKAGE), INFO_PACKAGE_NAME);
	pStatic->SetLabel(szText);
	pStatic = (CGStaticText *) GetControl(IDC_MK2_STATIC_ABOUT_INFO2);

	sprintf(szText, "%s %d.%d.%d.%d", g_LOCALIZATION.GetString(IDS_FIRMWARE),1, 
		(int) ((pDeviceState->djConsoleMk2.lFirmwareVersion&0x00030000)>>16), // Controller type (PSOC/Weltrend)
		(int) ((pDeviceState->djConsoleMk2.lFirmwareVersion&DJMK2_FIRMWARE_PSOC_VERSION)>>8),
		(int) (pDeviceState->djConsoleMk2.lFirmwareVersion&DJMK2_FIRMWARE_TUSB_VERSION));
	pStatic->SetLabel(szText);
	pStatic = (CGStaticText *) GetControl(IDC_MK2_STATIC_ABOUT_INFO3);
	sprintf(szText, "%s %d.%d.%d.%d", g_LOCALIZATION.GetString(IDS_DRIVER),
		ConvertBCDtoInt((int) (pDeviceState->ulBULK_Version>>24)&0xFF),
		ConvertBCDtoInt((int) (pDeviceState->ulBULK_Version>>16)&0xFF),
		ConvertBCDtoInt((int) (pDeviceState->ulBULK_Version>>8)&0xFF),
		ConvertBCDtoInt((int) (pDeviceState->ulBULK_Version>>0)&0xFF));
	pStatic->SetLabel(szText);
	
	pStatic = (CGStaticText *) GetControl(IDC_MK2_STATIC_ABOUT_INFO4);
	sprintf(szText, "%s %s",  g_LOCALIZATION.GetString(IDS_CONTROL_PANEL), INFO_CONTROL_PANEL);
	pStatic->SetLabel(szText);
	DEBUG_PRINT("CDevMk2Dlg::InitializeDlgState completed.");
}


