/////////////////////////////////////////////////////////////////////////////
// Name:        devmp3dlg.cpp
// Purpose:     Implement GUI for DJ Control MP3 Dialog.
// Author:      Yann Hamiaux
// Modified by: -
// Created:     09/09/2008
// Copyright:   Written for Guillemot Corporation by Yann Hamiaux
// Licence:     The GNU General Public License v2+.
/////////////////////////////////////////////////////////////////////////////
#include "devmp3dlg.h"
#include "localization.h"

extern CLocalization	g_LOCALIZATION;


CDevMp3Dlg::CDevMp3Dlg( wxMemoryDC *pSkinMemDC, wxMemoryDC *pSkinAlphaMemDC ) : 
	CGDialog(pSkinMemDC, pSkinAlphaMemDC, 362, 347)
{
	char 			 szText[40];
	CHECKBOX_STATE_INFO 	 checkboxInfo[2];
	BUTTON_STATE_INFO	 buttonInfo[3];
	COMBO_INFO		 comboInfo;
	CGControl		*pCtrl;
	CGStaticText		*pStatic;
	CGCheckBox		*pCheckBox;
	CGComboBox		*pComboBox;
	int i;

	// --- Hercules Logo ---
	for(i=0;i<4;++i)
		buttonInfo[0].coordinates[i].y = 349;
	buttonInfo[0].nProcessAlpha = FALSE;
	buttonInfo[0].coordinates[0].x = 0;
	buttonInfo[0].coordinates[1].x = 0;
	buttonInfo[0].coordinates[2].x = 81;
	buttonInfo[0].coordinates[3].x = 162;

	pCtrl = (CGControl *) new CGButton(&m_eventList, IDC_DJMP3_HERCULES_LOGO, 
		135,282,80,56,m_pSkinMemDC, m_pSkinAlphaMemDC, 1, buttonInfo);
	AddControl(pCtrl);

	// --- Prepare CheckBox ---
	for(i=0;i<4;++i) {
		checkboxInfo[0].coordinates[i].y = 349;
		checkboxInfo[1].coordinates[i].y = 365;

		checkboxInfo[0].coordinates[i].r = 0;
		checkboxInfo[0].coordinates[i].g = 0;
		checkboxInfo[0].coordinates[i].b = 0;
		checkboxInfo[1].coordinates[i].r = 0;
		checkboxInfo[1].coordinates[i].g = 0;
		checkboxInfo[1].coordinates[i].b = 0;
	}
	checkboxInfo[0].coordinates[0].r = 90;
	checkboxInfo[0].coordinates[0].g = 90;
	checkboxInfo[0].coordinates[0].b = 90;
	checkboxInfo[1].coordinates[0].r = 90;
	checkboxInfo[1].coordinates[0].g = 90;
	checkboxInfo[1].coordinates[0].b = 90;

	checkboxInfo[0].coordinates[0].x = 243;
	checkboxInfo[0].coordinates[1].x = 259;
	checkboxInfo[0].coordinates[2].x = 275;
	checkboxInfo[0].coordinates[3].x = 291;
	checkboxInfo[1].coordinates[0].x = 243;
	checkboxInfo[1].coordinates[1].x = 259;
	checkboxInfo[1].coordinates[2].x = 275;
	checkboxInfo[1].coordinates[3].x = 291;
	checkboxInfo[0].nProcessAlpha = FALSE;
	checkboxInfo[1].nProcessAlpha = FALSE;

	// --- Static: MIDI Channel ---
	pStatic = new CGStaticText(&m_eventList, IDC_DJMP3_STATIC_MIDI_CHANNEL, 
		g_LOCALIZATION.GetString(IDS_MIDI_CHANNEL),
		65, 139, 200, 15, ALIGN_LEFT|VALIGN_CENTER);
	AddControl((CGControl *) pStatic);

	// --- About Box: PRODUCT INFO Line 1 ---
	pStatic = new CGStaticText(&m_eventList, IDC_DJMP3_ABOUTBOX_STATIC_LINE1, 
		"Package: n/a", 
		32, 185, 328-32, 15, ALIGN_CENTER|VALIGN_CENTER);
	AddControl((CGControl *) pStatic);

	// --- About Box: PRODUCT INFO Line 2 ---
	pStatic = new CGStaticText(&m_eventList, IDC_DJMP3_ABOUTBOX_STATIC_LINE2, 
		"Firmware: n/a", 
		32, 185+15*1, 328-32, 15, ALIGN_CENTER|VALIGN_CENTER);
	AddControl((CGControl *) pStatic);

	// --- About Box: PRODUCT INFO Line 3 ---
	pStatic = new CGStaticText(&m_eventList, IDC_DJMP3_ABOUTBOX_STATIC_LINE3, 
		"Driver: n/a", 
		32, 185+15*2, 328-32, 15, ALIGN_CENTER|VALIGN_CENTER);
	AddControl((CGControl *) pStatic);

	// --- About Box: PRODUCT INFO Line 4 ---
	pStatic = new CGStaticText(&m_eventList, IDC_DJMP3_ABOUTBOX_STATIC_LINE4, 
		"Control Panel: n/a", 
		32, 185+15*3, 328-32, 15, ALIGN_CENTER|VALIGN_CENTER);
	AddControl((CGControl *) pStatic);

	// --- About Box: PRODUCT INFO Line 5 ---
	pStatic = new CGStaticText(&m_eventList, IDC_DJMP3_ABOUTBOX_STATIC_LINE5, 
		g_LOCALIZATION.GetString(IDS_RIGHTS_RESERVED), 
		32, 195+15*4, 328-32, 15, ALIGN_CENTER|VALIGN_CENTER);
	AddControl((CGControl *) pStatic);

	// --- ComboBox ---
	comboInfo.box[0].x = 0;
	comboInfo.box[0].y = 406;
	comboInfo.box[2].x = 161;
	comboInfo.box[2].y = 406;
	comboInfo.box[1].x = 0;
	comboInfo.box[1].y = 428;
	comboInfo.box[3].x = 161;
	comboInfo.box[3].y = 428;
	
	comboInfo.sbckBottom.x = 759-571;
	comboInfo.sbckBottom.y = 61+390;
	comboInfo.sbckBottom.w = 12;
	comboInfo.sbckBottom.h = 4;

	comboInfo.sbckMiddle.x = 746-571;
	comboInfo.sbckMiddle.y = 61+390;
	comboInfo.sbckMiddle.w = 12;
	comboInfo.sbckMiddle.h = 9;

	comboInfo.sbckTop.x = 733-571;
	comboInfo.sbckTop.y = 61+390;
	comboInfo.sbckTop.w = 12;
	comboInfo.sbckTop.h = 4;

	comboInfo.sbutBottom[0].x = 733-571;
	comboInfo.sbutBottom[0].y = 71+390;
	comboInfo.sbutBottom[0].w = 11;
	comboInfo.sbutBottom[0].h = 7;
	comboInfo.sbutBottom[1].x = 745-571;
	comboInfo.sbutBottom[1].y = 71+390;
	comboInfo.sbutBottom[1].w = 11;
	comboInfo.sbutBottom[1].h = 7;
	comboInfo.sbutBottom[2].x = 757-571;
	comboInfo.sbutBottom[2].y = 71+390;
	comboInfo.sbutBottom[2].w = 11;
	comboInfo.sbutBottom[2].h = 7;
	comboInfo.sbutBottom[3].x = 769-571;
	comboInfo.sbutBottom[3].y = 71+390;
	comboInfo.sbutBottom[3].w = 11;
	comboInfo.sbutBottom[3].h = 7;

	comboInfo.sbutTop[0].x = 733-571;
	comboInfo.sbutTop[0].y = 78+390;
	comboInfo.sbutTop[0].w = 11;
	comboInfo.sbutTop[0].h = 7;
	comboInfo.sbutTop[1].x = 745-571;
	comboInfo.sbutTop[1].y = 78+390;
	comboInfo.sbutTop[1].w = 11;
	comboInfo.sbutTop[1].h = 7;
	comboInfo.sbutTop[2].x = 757-571;
	comboInfo.sbutTop[2].y = 78+390;
	comboInfo.sbutTop[2].w = 11;
	comboInfo.sbutTop[2].h = 7;
	comboInfo.sbutTop[3].x = 769-571;
	comboInfo.sbutTop[3].y = 78+390;
	comboInfo.sbutTop[3].w = 11;
	comboInfo.sbutTop[3].h = 7;

	comboInfo.stmbBottom.x = 784-571;
	comboInfo.stmbBottom.y = 61+390;
	comboInfo.stmbBottom.w = 5;
	comboInfo.stmbBottom.h = 3;

	comboInfo.stmbMiddle.x = 778-571;
	comboInfo.stmbMiddle.y = 61+390;
	comboInfo.stmbMiddle.w = 5;
	comboInfo.stmbMiddle.h = 8;

	comboInfo.stmbTop.x = 772-571;
	comboInfo.stmbTop.y = 61+390;
	comboInfo.stmbTop.w = 5;
	comboInfo.stmbTop.h = 3;

	comboInfo.colorFont.r = 0x88;
	comboInfo.colorFont.g = 0xFF;
	comboInfo.colorFont.b = 0xFF;

	comboInfo.nBoxLeftSpace = 5;

	comboInfo.HighlightBckgrndColor.r = 0x88;
	comboInfo.HighlightBckgrndColor.g = 0xFF;
	comboInfo.HighlightBckgrndColor.b = 0xFF;

	comboInfo.HighlightForegrndColor.r = 0;
	comboInfo.HighlightForegrndColor.g = 0;
	comboInfo.HighlightForegrndColor.b = 0;

	comboInfo.nFontSizeBox = 8;
	comboInfo.nFontSizeList = 8;

	comboInfo.borderList.l = 3;
	comboInfo.borderList.r = 3;
	comboInfo.borderList.t = 3;
	comboInfo.borderList.b = 3;

	comboInfo.list.x = 0;	// MIDI Input
	comboInfo.list.y = 450;

	pComboBox = new CGComboBox(&m_eventList, IDC_DJMP3_COMBO_MIDI, 65, 157, 160, 21, 69, 
		m_pSkinMemDC, m_pSkinAlphaMemDC,&comboInfo);

	AddControl((CGControl *) pComboBox);
	pComboBox->ResetContent();
	for(i=0;i<16;++i)
	{
		if (i==0)
			sprintf(szText, "%d %s", i+1, g_LOCALIZATION.GetString(IDS_DEFAULT));
		else
			sprintf(szText, "%d", i+1);
		pComboBox->AddString(szText);
	}

	// --- DJ Mouse ---
	pCheckBox = new CGCheckBox(&m_eventList, IDC_DJMP3_CHECKBOX_DJ_MOUSE, 
		65, 103, 15, 15, g_LOCALIZATION.GetString(IDS_DJ_MOUSE), 
		135, 15, m_pSkinMemDC, m_pSkinAlphaMemDC, 2, checkboxInfo, ALIGN_LEFT|VALIGN_TOP);
	AddControl((CGControl *) pCheckBox);

}


CDevMp3Dlg::~CDevMp3Dlg( )
{
}

// ---------------------------------------------------------------------------
// Function: MouseEvent
//
// Process mouse events for all controls available on the DJ Control MP3.
// ---------------------------------------------------------------------------
bool CDevMp3Dlg::MouseEvent( int x, int y, int button, PREFRESH_RECT refreshRect )
{
	bool		bMouseEvent = false;
	bool		bProcessEvent;
	bool		bResult;
	int		nControlID, nMsg;
	unsigned long	ulParam1, ulParam2;

	bMouseEvent = CGDialog::MouseEvent(x,y,button, refreshRect);

	do
	{
		bProcessEvent = GetEvent(&nControlID, &nMsg, &ulParam1, &ulParam2);
		if (bProcessEvent) {
			switch (nControlID)
			{
			case IDC_DJMP3_HERCULES_LOGO:
				m_helpers.LaunchInternetBrowser(g_LOCALIZATION.GetString(IDS_HTTP_MP3));
				break;
			case IDC_DJMP3_CHECKBOX_DJ_MOUSE:
				bResult = m_pDManager->EnableDJMouse(ulParam1==1, m_pDeviceState);
				break;
			case IDC_DJMP3_COMBO_MIDI:
				bResult = m_pDManager->SetMidiChannel(ulParam1, m_pDeviceState);
				break;
			}
		}
	} while (bProcessEvent);

	return bMouseEvent;
}

// ---------------------------------------------------------------------------
// Function: InitializeDlgState
//
// Put the information on the MP3 Dialog box base on the device state.
// ---------------------------------------------------------------------------
void CDevMp3Dlg::InitializeDlgState( DJ_DEVICE_STATE *pDeviceState, CDManager *pDeviceManager )
{
	char 		 szText[80];
	CGStaticText	*pStatic;
	CGComboBox	*pCombo;
	CGCheckBox	*pCheckBox;

	CGDialog::InitializeDlgState(pDeviceState, pDeviceManager);

	pCombo = (CGComboBox *) GetControl(IDC_DJMP3_COMBO_MIDI);
	pCombo->SetCurSel(pDeviceState->djControlMP3.nMidiChannel);

	pCheckBox = (CGCheckBox *) GetControl(IDC_DJMP3_CHECKBOX_DJ_MOUSE);
	pCheckBox->SetState(pDeviceState->djControlMP3.bEnableDJMouse);

	sprintf(szText, "%s %s", g_LOCALIZATION.GetString(IDS_PACKAGE), INFO_PACKAGE_NAME);
	pStatic = (CGStaticText *) GetControl(IDC_DJMP3_ABOUTBOX_STATIC_LINE1);
	pStatic->SetLabel(szText);

	sprintf(szText, "%s %d.%d.%d.%d", g_LOCALIZATION.GetString(IDS_DRIVER),
		ConvertBCDtoInt((int) (pDeviceState->ulBULK_Version>>24)&0xFF),
		ConvertBCDtoInt((int) (pDeviceState->ulBULK_Version>>16)&0xFF),
		ConvertBCDtoInt((int) (pDeviceState->ulBULK_Version>>8)&0xFF),
		ConvertBCDtoInt((int) (pDeviceState->ulBULK_Version>>0)&0xFF));
	pStatic = (CGStaticText *) GetControl(IDC_DJMP3_ABOUTBOX_STATIC_LINE2);
	pStatic->SetLabel(szText);

	sprintf(szText, "%s %d.%.2X", g_LOCALIZATION.GetString(IDS_FIRMWARE),
		ConvertBCDtoInt((int) (pDeviceState->djControlMP3.lFirmwareVersion>>8)&0xFF),
		(unsigned int) (pDeviceState->djControlMP3.lFirmwareVersion)&0xFF);
	pStatic = (CGStaticText *) GetControl(IDC_DJMP3_ABOUTBOX_STATIC_LINE3);
	pStatic->SetLabel(szText);

	sprintf(szText, "%s %s", g_LOCALIZATION.GetString(IDS_CONTROL_PANEL), INFO_CONTROL_PANEL);
	pStatic = (CGStaticText *) GetControl(IDC_DJMP3_ABOUTBOX_STATIC_LINE4);
	pStatic->SetLabel(szText);
	DEBUG_PRINT("CDevMp3Dlg::InitializeDlgState completed.");
}


