/////////////////////////////////////////////////////////////////////////////
// Name:        devrmxdlg.cpp
// Purpose:     Implement GUI for DJ Console Rmx Dialog.
// Author:      Yann Hamiaux
// Modified by: -
// Created:     02/15/2008
// Copyright:   Written for Guillemot Corporation by Yann Hamiaux
// Licence:     The GNU General Public License v2+.
/////////////////////////////////////////////////////////////////////////////
#include "devrmxdlg.h"
#include "localization.h"

extern CLocalization	g_LOCALIZATION;


CDevRmxDlg::CDevRmxDlg( wxMemoryDC *pSkinMemDC, wxMemoryDC *pSkinAlphaMemDC ) : 
	CGDialog(pSkinMemDC, pSkinAlphaMemDC, 538, 400)
{
	STATIC_STATE_INFO	staticInfo[7];
	BUTTON_STATE_INFO	buttonInfo[4];
	CHECKBOX_STATE_INFO	checkboxInfo[2];
	COMBO_INFO	 	comboInfo;
	SLIDER_INFO	 	sliderInfo;
	CGStaticText	*pStatic;
	CGStatic	*pStaticImg;
	CGControl	*pCtrl;
	CGSlider	*pSlider;
	CGCheckBox	*pCheckBox;
	CGComboBox	*pComboBox;
	char		 szText[80];
	int		 nCPLTab;
	int		 i;

	// --- ADVANCED Tab ---
	staticInfo[0].x = 861;
	staticInfo[0].y = 0;
	staticInfo[0].nProcessAlpha = FALSE;

	pStaticImg = new CGStatic(&m_eventList, IDC_RMX_ADVANCED_TAB, 
		202,68,320,220, m_pSkinMemDC, m_pSkinAlphaMemDC, 1, staticInfo);
	AddControl((CGControl *) pStaticImg);

	// --- ABOUT Tab ---
	staticInfo[0].x = 1182;
	staticInfo[0].y = 0;
	staticInfo[0].nProcessAlpha = FALSE;

	pStaticImg = new CGStatic(&m_eventList, IDC_RMX_ABOUT_TAB, 
		202+1,68,320,220, m_pSkinMemDC, m_pSkinAlphaMemDC, 1, staticInfo);
	AddControl((CGControl *) pStaticImg);

	// --- Balance Sliders ---
	for(i=0;i<4;++i) {
		sliderInfo.coordinates[i].x = 1261;
		sliderInfo.coordinates[i].y = 321;
		sliderInfo.coordinates[i].x_highlight = 1261;
		sliderInfo.coordinates[i].y_highlight = 321;
		sliderInfo.coordinates[i].thumb_x = 1377;
		sliderInfo.coordinates[i].thumb_y = 321;
		sliderInfo.coordinates[i].thumb_w = 32;
		sliderInfo.coordinates[i].thumb_h = 17;
	}
	sliderInfo.coordinates[0].thumb_x = 1344;
	sliderInfo.coordinates[0].thumb_y = 321;
	sliderInfo.nThumbOffsetX = 0;
	sliderInfo.nThumbOffsetY = 3;
	sliderInfo.nProcessAlpha = TRUE;
	sliderInfo.nHorizontal = TRUE;
	sliderInfo.nBorderSizeAtMin = 0;
	sliderInfo.nBorderSizeAtMax = 0;

	// --- Balance Channel 1-2 ---
	pSlider = new CGSlider(&m_eventList, IDC_RMX_BALANCE_12, 14, 113, 82, 22, 
		m_pSkinMemDC, m_pSkinAlphaMemDC, &sliderInfo);
	pSlider->SetRange(0, 0xFF);
	AddControl((CGControl *) pSlider);

	// --- Balance Channel 3-4 ---
	for(i=0;i<4;++i) {
		sliderInfo.coordinates[i].x = 1261;
		sliderInfo.coordinates[i].y = 344;
		sliderInfo.coordinates[i].x_highlight = 1261;
		sliderInfo.coordinates[i].y_highlight = 344;
	}
	pSlider = new CGSlider(&m_eventList, IDC_RMX_BALANCE_34, 109, 113, 82, 22, 
		m_pSkinMemDC, m_pSkinAlphaMemDC, &sliderInfo);
	pSlider->SetRange(0, 0xFF);
	AddControl((CGControl *) pSlider);

	// --- Volume Sliders ---
	for(i=0;i<4;++i) {
		sliderInfo.coordinates[i].x = 1133;
		sliderInfo.coordinates[i].y = 285;
		sliderInfo.coordinates[i].x_highlight = 1133;
		sliderInfo.coordinates[i].y_highlight = 285;
		sliderInfo.coordinates[i].thumb_x = 1276;
		sliderInfo.coordinates[i].thumb_y = 285;
		sliderInfo.coordinates[i].thumb_w = 14;
		sliderInfo.coordinates[i].thumb_h = 35;
	}
	sliderInfo.coordinates[0].thumb_x = 1261;
	sliderInfo.coordinates[0].thumb_y = 285;
	sliderInfo.nThumbOffsetX = 0;
	sliderInfo.nThumbOffsetY = 0;
	sliderInfo.nProcessAlpha = TRUE;
	sliderInfo.nHorizontal = FALSE;
	sliderInfo.nBorderSizeAtMin = 0;
	sliderInfo.nBorderSizeAtMax = 0;

	// --- Volume Channel 1 ---
	pSlider = new CGSlider(&m_eventList, IDC_RMX_VOLUME_1, 23, 139, 31, 110, 
		m_pSkinMemDC, m_pSkinAlphaMemDC, &sliderInfo);
	pSlider->SetRange(0, 0xFF);
	AddControl((CGControl *) pSlider);

	// --- Volume Channel 2 ---
	for(i=0;i<4;++i) {
		sliderInfo.coordinates[i].x = 1165;
		sliderInfo.coordinates[i].x_highlight = 1165;
	}
	pSlider = new CGSlider(&m_eventList, IDC_RMX_VOLUME_2, 59, 139, 31, 110, 
		m_pSkinMemDC, m_pSkinAlphaMemDC, &sliderInfo);
	pSlider->SetRange(0, 0xFF);
	AddControl((CGControl *) pSlider);

	// --- Volume Channel 3 ---
	for(i=0;i<4;++i) {
		sliderInfo.coordinates[i].x = 1197;
		sliderInfo.coordinates[i].x_highlight = 1197;
	}
	pSlider = new CGSlider(&m_eventList, IDC_RMX_VOLUME_3, 117, 139, 31, 110, 
		m_pSkinMemDC, m_pSkinAlphaMemDC, &sliderInfo);
	pSlider->SetRange(0, 0xFF);
	AddControl((CGControl *) pSlider);

	// --- Volume Channel 4 ---
	for(i=0;i<4;++i) {
		sliderInfo.coordinates[i].x = 1229;
		sliderInfo.coordinates[i].x_highlight = 1229;
	}
	pSlider = new CGSlider(&m_eventList, IDC_RMX_VOLUME_4, 153, 139, 31, 110, 
		m_pSkinMemDC, m_pSkinAlphaMemDC, &sliderInfo);
	pSlider->SetRange(0, 0xFF);
	AddControl((CGControl *) pSlider);


	// --- Hercules Logo ---
	for(i=0;i<4;++i)
		buttonInfo[0].coordinates[i].y = 221;
	buttonInfo[0].nProcessAlpha = FALSE;
	buttonInfo[0].coordinates[0].x = 539;
	buttonInfo[0].coordinates[1].x = 539;
	buttonInfo[0].coordinates[2].x = 641;
	buttonInfo[0].coordinates[3].x = 743;

	pCtrl = (CGControl *) new CGButton(&m_eventList, IDC_RMX_HERCULES_LOGO, 
		415,313,101,67,m_pSkinMemDC, m_pSkinAlphaMemDC, 1, buttonInfo);
	AddControl(pCtrl);

	// --- Link Volumes ---
	for(i=0;i<4;++i) {
		buttonInfo[0].coordinates[i].y = 379;
		buttonInfo[1].coordinates[i].y = 379;
	}
	buttonInfo[0].nProcessAlpha = FALSE;
	buttonInfo[0].coordinates[0].x = 1261;
	buttonInfo[0].coordinates[1].x = 1285;
	buttonInfo[0].coordinates[2].x = 1309;
	buttonInfo[0].coordinates[3].x = 1333;
	buttonInfo[1].nProcessAlpha = FALSE;
	buttonInfo[1].coordinates[0].x = 1357;
	buttonInfo[1].coordinates[1].x = 1381;
	buttonInfo[1].coordinates[2].x = 1405;
	buttonInfo[1].coordinates[3].x = 1429;
	pCtrl = (CGControl *) new CGButton(&m_eventList, IDC_RMX_LINK_VOL_CH12, 
		44,250,23,16,m_pSkinMemDC, m_pSkinAlphaMemDC, 2, buttonInfo);
	pCtrl->AddToolTips(g_LOCALIZATION.GetString(IDS_LINK_VOLUMES_TTIPS));
	AddControl(pCtrl);

	pCtrl = (CGControl *) new CGButton(&m_eventList, IDC_RMX_LINK_VOL_CH34, 
		139,250,23,16,m_pSkinMemDC, m_pSkinAlphaMemDC, 2, buttonInfo);
	pCtrl->AddToolTips(g_LOCALIZATION.GetString(IDS_LINK_VOLUMES_TTIPS));
	AddControl(pCtrl);

	// --- Mute ---
	for(i=0;i<4;++i) {
		buttonInfo[0].coordinates[i].y = 303;
		buttonInfo[1].coordinates[i].y = 303;
	}
	buttonInfo[0].nProcessAlpha = FALSE;
	buttonInfo[0].coordinates[0].x = 1291;
	buttonInfo[0].coordinates[1].x = 1308;
	buttonInfo[0].coordinates[2].x = 1325;
	buttonInfo[0].coordinates[3].x = 1342;
	buttonInfo[1].nProcessAlpha = FALSE;
	buttonInfo[1].coordinates[0].x = 1360;
	buttonInfo[1].coordinates[1].x = 1376;
	buttonInfo[1].coordinates[2].x = 1393;
	buttonInfo[1].coordinates[3].x = 1410;
	pCtrl = (CGControl *) new CGButton(&m_eventList, IDC_RMX_MUTE_CH12, 
		48,269,16,17,m_pSkinMemDC, m_pSkinAlphaMemDC, 2, buttonInfo);
	AddControl(pCtrl);

	pCtrl = (CGControl *) new CGButton(&m_eventList, IDC_RMX_MUTE_CH34, 
		143,269,16,17,m_pSkinMemDC, m_pSkinAlphaMemDC, 2, buttonInfo);
	AddControl(pCtrl);

	// --- Line In / Phono ---
	for(i=0;i<4;++i) {
		buttonInfo[0].coordinates[i].y = 337;
		buttonInfo[1].coordinates[i].y = 337;
		buttonInfo[0].coordinates[i].x = 979;
		buttonInfo[1].coordinates[i].x = 1043;
	}
	buttonInfo[0].coordinates[2].x = 1370;
	buttonInfo[0].coordinates[2].y = 397;
	buttonInfo[0].nProcessAlpha = FALSE;
	buttonInfo[1].nProcessAlpha = FALSE;
	pCtrl = (CGControl *) new CGButton(&m_eventList, IDC_RMX_LINEIN_PHONO, 
		17,356,63,20,m_pSkinMemDC, m_pSkinAlphaMemDC, 2, buttonInfo);
	AddControl(pCtrl);

	// --- Mic ---
	for(i=0;i<4;++i) {
		buttonInfo[0].coordinates[i].y = 358;
		buttonInfo[1].coordinates[i].y = 358;
		buttonInfo[0].coordinates[i].x = 979;
		buttonInfo[1].coordinates[i].x = 1043;
	}
	buttonInfo[0].coordinates[2].x = 1370;
	buttonInfo[0].coordinates[2].y = 418;
	buttonInfo[0].nProcessAlpha = FALSE;
	buttonInfo[1].nProcessAlpha = FALSE;
	pCtrl = (CGControl *) new CGButton(&m_eventList, IDC_RMX_MIC, 
		17,338,63,17,m_pSkinMemDC, m_pSkinAlphaMemDC, 2, buttonInfo);
	AddControl(pCtrl);


	// --- Tab Button: Main ---
	for(i=0;i<4;++i) {
		buttonInfo[0].coordinates[i].y = 449;
		buttonInfo[1].coordinates[i].y = 449;
		buttonInfo[0].coordinates[i].x = 324;
	}
	buttonInfo[1].coordinates[0].x = 0;
	buttonInfo[1].coordinates[1].x = 108;
	buttonInfo[1].coordinates[2].x = 216;
	buttonInfo[1].coordinates[3].x = 324;
	buttonInfo[0].nProcessAlpha = FALSE;
	buttonInfo[1].nProcessAlpha = FALSE;
	pCtrl = (CGControl *) new CGButton(&m_eventList, IDC_RMX_TAB_MAIN, 
		204,68,107,32,m_pSkinMemDC, m_pSkinAlphaMemDC, 2, buttonInfo);
	AddControl(pCtrl);

	// --- Tab Button: ADVANCED ---
	for(i=0;i<4;++i) {
		buttonInfo[0].coordinates[i].y = 449;
		buttonInfo[1].coordinates[i].y = 449;
		buttonInfo[0].coordinates[i].x = 759;
	}
	buttonInfo[1].coordinates[0].x = 432;
	buttonInfo[1].coordinates[1].x = 541;
	buttonInfo[1].coordinates[2].x = 650;
	buttonInfo[1].coordinates[3].x = 759;
	buttonInfo[0].nProcessAlpha = FALSE;
	buttonInfo[1].nProcessAlpha = FALSE;
	pCtrl = (CGControl *) new CGButton(&m_eventList, IDC_RMX_TAB_ADVANCED, 
		311,68,108,32,m_pSkinMemDC, m_pSkinAlphaMemDC, 2, buttonInfo);
	AddControl(pCtrl);

	// --- Tab Button: ABOUT ---
	for(i=0;i<4;++i) {
		buttonInfo[0].coordinates[i].y = 449;
		buttonInfo[1].coordinates[i].y = 449;
		buttonInfo[0].coordinates[i].x = 1183;
	}
	buttonInfo[1].coordinates[0].x = 868;
	buttonInfo[1].coordinates[1].x = 973;
	buttonInfo[1].coordinates[2].x = 1078;
	buttonInfo[1].coordinates[3].x = 1183;
	buttonInfo[0].nProcessAlpha = FALSE;
	buttonInfo[1].nProcessAlpha = FALSE;
	pCtrl = (CGControl *) new CGButton(&m_eventList, IDC_RMX_TAB_ABOUT, 
		419,68,104,32,m_pSkinMemDC, m_pSkinAlphaMemDC, 2, buttonInfo);
	AddControl(pCtrl);

	// --- Line In / Phono 3-4 ---
	for(i=0;i<4;++i) {
		buttonInfo[0].coordinates[i].y = 397;
		buttonInfo[0].coordinates[i].x = 1301;
	}
	buttonInfo[0].coordinates[0].x = 1232;
	buttonInfo[0].nProcessAlpha = FALSE;
	pCtrl = (CGControl *) new CGButton(&m_eventList, IDC_RMX_LINEIN_PHONO_CH34, 
		116,342,68,34,m_pSkinMemDC, m_pSkinAlphaMemDC, 1, buttonInfo);
	AddControl(pCtrl);

	// --- Talkover Attenuation Sliders ---
	for(i=0;i<4;++i) {
		sliderInfo.coordinates[i].x = 458;
		sliderInfo.coordinates[i].y = 425;
		sliderInfo.coordinates[i].x_highlight = 458;
		sliderInfo.coordinates[i].y_highlight = 425;
		sliderInfo.coordinates[i].thumb_x = 634;
		sliderInfo.coordinates[i].thumb_y = 425;
		sliderInfo.coordinates[i].thumb_w = 32;
		sliderInfo.coordinates[i].thumb_h = 17;
	}
	sliderInfo.coordinates[0].thumb_x = 601;
	sliderInfo.coordinates[0].thumb_y = 425;
	sliderInfo.nThumbOffsetX = 0;
	sliderInfo.nThumbOffsetY = 0;
	sliderInfo.nProcessAlpha = TRUE;
	sliderInfo.nHorizontal = TRUE;
	sliderInfo.nBorderSizeAtMin = 0;
	sliderInfo.nBorderSizeAtMax = 0;

	pSlider = new CGSlider(&m_eventList, IDC_RMX_TALKOVER, 236, 136, 142, 17, 
		m_pSkinMemDC, m_pSkinAlphaMemDC, &sliderInfo);
	pSlider->SetRange(0, 2);
	AddControl((CGControl *) pSlider);

	// --- Prepare CheckBox ---
	for(i=0;i<4;++i) {
		checkboxInfo[0].coordinates[i].y = 285;
		checkboxInfo[1].coordinates[i].y = 285;

		checkboxInfo[0].coordinates[i].r = 0;
		checkboxInfo[0].coordinates[i].g = 0;
		checkboxInfo[0].coordinates[i].b = 0;
		checkboxInfo[1].coordinates[i].r = 0;
		checkboxInfo[1].coordinates[i].g = 0;
		checkboxInfo[1].coordinates[i].b = 0;
	}
	checkboxInfo[0].coordinates[0].r = 90;
	checkboxInfo[0].coordinates[0].g = 90;
	checkboxInfo[0].coordinates[0].b = 90;
	checkboxInfo[1].coordinates[0].r = 90;
	checkboxInfo[1].coordinates[0].g = 90;
	checkboxInfo[1].coordinates[0].b = 90;

	checkboxInfo[0].coordinates[0].x = 1291;
	checkboxInfo[0].coordinates[1].x = 1308;
	checkboxInfo[0].coordinates[2].x = 1325;
	checkboxInfo[0].coordinates[3].x = 1342;
	checkboxInfo[1].coordinates[0].x = 1359;
	checkboxInfo[1].coordinates[1].x = 1376;
	checkboxInfo[1].coordinates[2].x = 1393;
	checkboxInfo[1].coordinates[3].x = 1410;
	checkboxInfo[0].nProcessAlpha = FALSE;
	checkboxInfo[1].nProcessAlpha = FALSE;

	// --- CheckBox - Talkover Attenuation ---
	pCheckBox = new CGCheckBox(&m_eventList, IDC_RMX_CHECKBOX_TALK_ATT, 
		215, 114, 16, 17, g_LOCALIZATION.GetString(IDS_TALKOVER_ATT), 
		160, 16, m_pSkinMemDC, m_pSkinAlphaMemDC, 2, checkboxInfo, ALIGN_LEFT|VALIGN_CENTER);
	pCheckBox->SetFontAttributes(TRUE, FALSE);
	AddControl((CGControl *) pCheckBox);

	pCheckBox = new CGCheckBox(&m_eventList, IDC_RMX_CHECKBOX_USB_12, 
		215, 141, 16, 17, g_LOCALIZATION.GetString(IDS_USB_12_NO_MIX), 
		160, 16, m_pSkinMemDC, m_pSkinAlphaMemDC, 2, checkboxInfo, ALIGN_LEFT|VALIGN_CENTER);
	pCheckBox->SetFontAttributes(TRUE, FALSE);
	AddControl((CGControl *) pCheckBox);

	pCheckBox = new CGCheckBox(&m_eventList, IDC_RMX_CHECKBOX_USB_12_MIC, 
		215, 164, 16, 17, g_LOCALIZATION.GetString(IDS_USB_12_MIX_WITH_MIC), 
		160, 16, m_pSkinMemDC, m_pSkinAlphaMemDC, 2, checkboxInfo, ALIGN_LEFT|VALIGN_CENTER);
	pCheckBox->SetFontAttributes(TRUE, FALSE);
	AddControl((CGControl *) pCheckBox);

	pCheckBox = new CGCheckBox(&m_eventList, IDC_RMX_CHECKBOX_USB_12_LIN, 
		215, 187, 16, 17, g_LOCALIZATION.GetString(IDS_USB_12_MIX_WITH_LINE_IN), 
		160, 16, m_pSkinMemDC, m_pSkinAlphaMemDC, 2, checkboxInfo, ALIGN_LEFT|VALIGN_CENTER);
	pCheckBox->SetFontAttributes(TRUE, FALSE);
	AddControl((CGControl *) pCheckBox);



	// --- Static Information: Main, ASIO, Advanced, About ---
	pStatic = new CGStaticText(&m_eventList, IDC_RMX_STATIC_MAIN, g_LOCALIZATION.GetString(IDS_TAB_MAIN), 
		204,68,107,32, ALIGN_CENTER|VALIGN_CENTER);
	pStatic->SetFontAttributes(true, false);
	AddControl((CGControl *) pStatic);
	pStatic = new CGStaticText(&m_eventList, IDC_RMX_STATIC_ADVANCED, g_LOCALIZATION.GetString(IDS_TAB_ADVANCED), 
		311,68,108,32, ALIGN_CENTER|VALIGN_CENTER);
	pStatic->SetFontAttributes(true, false);
	AddControl((CGControl *) pStatic);
	pStatic = new CGStaticText(&m_eventList, IDC_RMX_STATIC_ABOUT, g_LOCALIZATION.GetString(IDS_TAB_ABOUT), 
		419,68,104,32, ALIGN_CENTER|VALIGN_CENTER);
	pStatic->SetFontAttributes(true, false);
	AddControl((CGControl *) pStatic);

	pStatic = new CGStaticText(&m_eventList, IDC_RMX_STATIC_OUT_CHANNEL, g_LOCALIZATION.GetString(IDS_OUTPUT_CHANNELS), 
		17,70,173,19, ALIGN_CENTER|VALIGN_CENTER);
	pStatic->SetFontAttributes(true, false);
	AddControl((CGControl *) pStatic);
	pStatic = new CGStaticText(&m_eventList, IDC_RMX_STATIC_OUT_CHANNEL, g_LOCALIZATION.GetString(IDS_INPUT_CHANNELS), 
		17,296,173,19, ALIGN_CENTER|VALIGN_CENTER);
	pStatic->SetFontAttributes(true, false);
	AddControl((CGControl *) pStatic);

	// --- Main Tab Labels ---
	pStatic = new CGStaticText(&m_eventList, IDC_RMX_STATIC_JOG_SETTINGS, 
		g_LOCALIZATION.GetString(IDS_JOG_WHEELS_SETTINGS), 
		219,167,219,18, ALIGN_LEFT|VALIGN_CENTER);
	pStatic->SetFontAttributes(true, false);
	AddControl((CGControl *) pStatic);
	pStatic = new CGStaticText(&m_eventList, IDC_RMX_STATIC_JOG_ENABLE, 
		g_LOCALIZATION.GetString(IDS_ENABLING_DISABLING), 
		219,186,219,18, ALIGN_LEFT|VALIGN_CENTER);
	pStatic->SetFontAttributes(true, false);
	AddControl((CGControl *) pStatic);
	pStatic = new CGStaticText(&m_eventList, IDC_RMX_STATIC_JOG_SENSITIV, 
		g_LOCALIZATION.GetString(IDS_SENSITIVITY), 
		219,230,219,16, ALIGN_LEFT|VALIGN_CENTER);
	pStatic->SetFontAttributes(true, false);
	AddControl((CGControl *) pStatic);
	pStatic = new CGStaticText(&m_eventList, IDC_RMX_STATIC_ATT_DB, "-6 dB", 
		443,133,63,20, ALIGN_CENTER|VALIGN_CENTER);
	pStatic->SetFontAttributes(true, false);
	pStatic->SetFontColor(255,255,255);
	AddControl((CGControl *) pStatic);

	// --- ADVANCED Tab Labels ---
	pStatic = new CGStaticText(&m_eventList, IDC_RMX_STATIC_OUT12_HWMIX, 
		g_LOCALIZATION.GetString(IDS_OUTPUT_12_HW_MIX_OPTION), 
		219,114,219,18, ALIGN_LEFT|VALIGN_CENTER);
	pStatic->SetFontAttributes(true, false);
	AddControl((CGControl *) pStatic);
	pStatic = new CGStaticText(&m_eventList, IDC_RMX_STATIC_MIDI_CH, 
		g_LOCALIZATION.GetString(IDS_MIDI_CHANNEL_FOR_CONTROLS), 
		219,226,219,18, ALIGN_LEFT|VALIGN_CENTER);
	pStatic->SetFontAttributes(true, false);
	AddControl((CGControl *) pStatic);

	// --- ABOUT Tab Labels ---
	pStatic = new CGStaticText(&m_eventList, IDC_RMX_STATIC_ABOUT1, 
		g_LOCALIZATION.GetString(IDS_TECH_SUPPORT_INFO_NOTE_1), 
		227,127,500,18, ALIGN_LEFT|VALIGN_TOP);
	pStatic->SetFontColor(255,255,255);
	pStatic->SetFontAttributes(true, false);
	AddControl((CGControl *) pStatic);
	pStatic = new CGStaticText(&m_eventList, IDC_RMX_STATIC_ABOUT2, 
		g_LOCALIZATION.GetString(IDS_TECH_SUPPORT_INFO_NOTE_2), 
		227,127+18*1,500,18, ALIGN_LEFT|VALIGN_TOP);
	pStatic->SetFontColor(255,255,255);
	pStatic->SetFontAttributes(true, false);
	AddControl((CGControl *) pStatic);

	pStatic = new CGStaticText(&m_eventList, IDC_RMX_STATIC_ABOUT3, "Package: n/a", 
		227,127+18*3,500,18, ALIGN_LEFT|VALIGN_TOP);
	pStatic->SetFontColor(255,255,255);
	pStatic->SetFontAttributes(true, false);
	AddControl((CGControl *) pStatic);
	pStatic = new CGStaticText(&m_eventList, IDC_RMX_STATIC_ABOUT4, "Firmware: n/a", 
		227,127+18*3+14*1,500,18, ALIGN_LEFT|VALIGN_TOP);
	pStatic->SetFontColor(255,255,255);
	pStatic->SetFontAttributes(true, false);
	AddControl((CGControl *) pStatic);
	pStatic = new CGStaticText(&m_eventList, IDC_RMX_STATIC_ABOUT5, "Driver: n/a", 
		227,127+18*3+14*2,500,18, ALIGN_LEFT|VALIGN_TOP);
	pStatic->SetFontColor(255,255,255);
	pStatic->SetFontAttributes(true, false);
	AddControl((CGControl *) pStatic);
	pStatic = new CGStaticText(&m_eventList, IDC_RMX_STATIC_ABOUT6, "CPL: n/a", 
		227,127+18*3+14*3,500,18, ALIGN_LEFT|VALIGN_TOP);
	pStatic->SetFontColor(255,255,255);
	pStatic->SetFontAttributes(true, false);
	AddControl((CGControl *) pStatic);
	pStatic = new CGStaticText(&m_eventList, IDC_RMX_STATIC_ABOUT7, 
		g_LOCALIZATION.GetString(IDS_RIGHTS_RESERVED), 
		227,127+10+18*3+14*4,500,18, ALIGN_LEFT|VALIGN_TOP);
	pStatic->SetFontColor(255,255,255);
	pStatic->SetFontAttributes(true, false);
	AddControl((CGControl *) pStatic);

	// --- Combo Box ---
	comboInfo.box[0].x = 0;
	comboInfo.box[0].y = 401;
	comboInfo.box[2].x = 0;
	comboInfo.box[2].y = 401;
	comboInfo.box[1].x = 289;
	comboInfo.box[1].y = 401;//476;
	comboInfo.box[3].x = 578;
	comboInfo.box[3].y = 401;//498;
	
	comboInfo.sbckBottom.x = 1295;
	comboInfo.sbckBottom.y = 367;
	comboInfo.sbckBottom.w = 16;
	comboInfo.sbckBottom.h = 2;

	comboInfo.sbckMiddle.x = 1278;
	comboInfo.sbckMiddle.y = 367;
	comboInfo.sbckMiddle.w = 16;
	comboInfo.sbckMiddle.h = 1;

	comboInfo.sbckTop.x = 1261;
	comboInfo.sbckTop.y = 367;
	comboInfo.sbckTop.w = 16;
	comboInfo.sbckTop.h = 2;

	comboInfo.sbutBottom[0].x = 1421;
	comboInfo.sbutBottom[0].y = 252;
	comboInfo.sbutBottom[0].w = 16;
	comboInfo.sbutBottom[0].h = 13;
	comboInfo.sbutBottom[1].x = 1438;
	comboInfo.sbutBottom[1].y = 252;
	comboInfo.sbutBottom[1].w = 16;
	comboInfo.sbutBottom[1].h = 13;
	comboInfo.sbutBottom[2].x = 1455;
	comboInfo.sbutBottom[2].y = 252;
	comboInfo.sbutBottom[2].w = 16;
	comboInfo.sbutBottom[2].h = 13;
	comboInfo.sbutBottom[3].x = 1472;
	comboInfo.sbutBottom[3].y = 252;
	comboInfo.sbutBottom[3].w = 16;
	comboInfo.sbutBottom[3].h = 13;

	comboInfo.sbutTop[0].x = 1421;
	comboInfo.sbutTop[0].y = 238;
	comboInfo.sbutTop[0].w = 16;
	comboInfo.sbutTop[0].h = 13;
	comboInfo.sbutTop[1].x = 1438;
	comboInfo.sbutTop[1].y = 238;
	comboInfo.sbutTop[1].w = 16;
	comboInfo.sbutTop[1].h = 13;
	comboInfo.sbutTop[2].x = 1455;
	comboInfo.sbutTop[2].y = 238;
	comboInfo.sbutTop[2].w = 16;
	comboInfo.sbutTop[2].h = 13;
	comboInfo.sbutTop[3].x = 1472;
	comboInfo.sbutTop[3].y = 238;
	comboInfo.sbutTop[3].w = 16;
	comboInfo.sbutTop[3].h = 13;

	comboInfo.stmbTop.x = 1312;
	comboInfo.stmbTop.y = 368;
	comboInfo.stmbTop.w = 12;
	comboInfo.stmbTop.h = 10;

	comboInfo.stmbMiddle.x = 1325;
	comboInfo.stmbMiddle.y = 367;
	comboInfo.stmbMiddle.w = 12;
	comboInfo.stmbMiddle.h = 5;

	comboInfo.stmbBottom.x = 1338;
	comboInfo.stmbBottom.y = 367;
	comboInfo.stmbBottom.w = 12;
	comboInfo.stmbBottom.h = 10;

	comboInfo.colorFont.r = 0x00;
	comboInfo.colorFont.g = 0x00;
	comboInfo.colorFont.b = 0x00;

	comboInfo.nBoxLeftSpace = 5;

	comboInfo.HighlightBckgrndColor.r = 0x00;
	comboInfo.HighlightBckgrndColor.g = 0x00;
	comboInfo.HighlightBckgrndColor.b = 0xFF;

	comboInfo.HighlightForegrndColor.r = 0xFF;
	comboInfo.HighlightForegrndColor.g = 0xFF;
	comboInfo.HighlightForegrndColor.b = 0xFF;

	comboInfo.nFontSizeBox = 8;
	comboInfo.nFontSizeList = 8;

	comboInfo.list.x = 1133;
	comboInfo.list.y = 221;

	comboInfo.borderList.l = 3;
	comboInfo.borderList.r = 1;
	comboInfo.borderList.t = 5;
	comboInfo.borderList.b = 10;

	pComboBox = new CGComboBox(&m_eventList, IDC_RMX_COMBO_JOG_SENSITIV, 219, 247, 288, 23, 63, 
		m_pSkinMemDC, m_pSkinAlphaMemDC,&comboInfo);

	pComboBox->AddToolTips(g_LOCALIZATION.GetString(IDS_JOG_WHEEL_SENSITIVITY_TTIPS));
	AddControl((CGControl *) pComboBox);
	pComboBox->ResetContent();
	pComboBox->AddString(g_LOCALIZATION.GetString(IDS_NORMAL_DEFAULT));
	pComboBox->AddString(g_LOCALIZATION.GetString(IDS_LESS_SENSITIVE));
	pComboBox->AddString(g_LOCALIZATION.GetString(IDS_LEAST_SENSITIVE));

	comboInfo.borderList.l = 3;
	comboInfo.borderList.r = 1;
	comboInfo.borderList.t = 3;
	comboInfo.borderList.b = 0;

	pComboBox = new CGComboBox(&m_eventList, IDC_RMX_COMBO_JOG_ENABLE, 219, 203, 288, 23, 63, 
		m_pSkinMemDC, m_pSkinAlphaMemDC,&comboInfo);

	AddControl((CGControl *) pComboBox);
	pComboBox->ResetContent();
	pComboBox->AddString(g_LOCALIZATION.GetString(IDS_ENABLE_DEFAULT));
	pComboBox->AddString(g_LOCALIZATION.GetString(IDS_DISABLE_JOG_DECK_A));
	pComboBox->AddString(g_LOCALIZATION.GetString(IDS_DISABLE_JOG_DECK_B));
	pComboBox->AddString(g_LOCALIZATION.GetString(IDS_DISABLE_JOG_BOTH));

	// --- Combo Box (smaller) ---
	comboInfo.box[0].x = 0;
	comboInfo.box[0].y = 425;
	comboInfo.box[2].x = 153;
	comboInfo.box[2].y = 425;
	comboInfo.box[1].x = 153;
	comboInfo.box[1].y = 425;
	comboInfo.box[3].x = 306;
	comboInfo.box[3].y = 425;

	comboInfo.list.x = 827;
	comboInfo.list.y = 292;
	comboInfo.borderList.l = 3;
	comboInfo.borderList.r = 1;
	comboInfo.borderList.t = 7;
	comboInfo.borderList.b = 7;

	pComboBox = new CGComboBox(&m_eventList, IDC_RMX_COMBO_MIDI, 219, 246, 152, 23, 104, 
		m_pSkinMemDC, m_pSkinAlphaMemDC,&comboInfo);
	pComboBox->AddToolTips(g_LOCALIZATION.GetString(IDS_MIDI_CHANNEL_TTIPS));
	AddControl((CGControl *) pComboBox);
	pComboBox->ResetContent();
	for(i=0;i<16;++i)
	{
		if (i==0)
			sprintf(szText, "%d %s", i+1, g_LOCALIZATION.GetString(IDS_DEFAULT));
		else
			sprintf(szText, "%d", i+1);
		pComboBox->AddString(szText);
	}

	// --- CPL Test ---
	nCPLTab = 0;
	SetTab(0);
}

CDevRmxDlg::~CDevRmxDlg( )
{
}

// ---------------------------------------------------------------------------
// Function: SetTab
//
// Hide/Show controls base on the tab position (main, advanced or about).
// ---------------------------------------------------------------------------
bool CDevRmxDlg::SetTab( int nTab )
{
	CGButton *pButton;
	bool bTab1, bTab2, bTab3;

	if (nTab<0 || nTab>2)
		return false;

	bTab1 = (nTab!=0);
	bTab2 = (nTab!=1);
	bTab3 = (nTab!=2);

	pButton = (CGButton *) GetControl(IDC_RMX_TAB_MAIN);
	pButton->SetState(bTab1 ? 1 : 0);
	pButton = (CGButton *) GetControl(IDC_RMX_TAB_ADVANCED);
	pButton->SetState(bTab2 ? 1 : 0);
	pButton = (CGButton *) GetControl(IDC_RMX_TAB_ABOUT);
	pButton->SetState(bTab3 ? 1 : 0);

	GetControl(IDC_RMX_ADVANCED_TAB)->Hide(bTab2);
	GetControl(IDC_RMX_ABOUT_TAB)->Hide(bTab3);


	GetControl(IDC_RMX_STATIC_JOG_SETTINGS)->Hide(bTab1);
	GetControl(IDC_RMX_STATIC_JOG_ENABLE)->Hide(bTab1);
	GetControl(IDC_RMX_STATIC_JOG_SENSITIV)->Hide(bTab1);
	GetControl(IDC_RMX_STATIC_ATT_DB)->Hide(bTab1);
	GetControl(IDC_RMX_COMBO_JOG_SENSITIV)->Hide(bTab1);
	GetControl(IDC_RMX_COMBO_JOG_ENABLE)->Hide(bTab1);
	GetControl(IDC_RMX_CHECKBOX_TALK_ATT)->Hide(bTab1);
	GetControl(IDC_RMX_TALKOVER)->Hide(bTab1);

	GetControl(IDC_RMX_COMBO_MIDI)->Hide(bTab2);
	GetControl(IDC_RMX_STATIC_OUT12_HWMIX)->Hide(bTab2);
	GetControl(IDC_RMX_STATIC_MIDI_CH)->Hide(bTab2);
	GetControl(IDC_RMX_CHECKBOX_USB_12)->Hide(bTab2);
	GetControl(IDC_RMX_CHECKBOX_USB_12_MIC)->Hide(bTab2);
	GetControl(IDC_RMX_CHECKBOX_USB_12_LIN)->Hide(bTab2);

	GetControl(IDC_RMX_STATIC_ABOUT1)->Hide(bTab3);
	GetControl(IDC_RMX_STATIC_ABOUT2)->Hide(bTab3);
	GetControl(IDC_RMX_STATIC_ABOUT3)->Hide(bTab3);
	GetControl(IDC_RMX_STATIC_ABOUT4)->Hide(bTab3);
	GetControl(IDC_RMX_STATIC_ABOUT5)->Hide(bTab3);
	GetControl(IDC_RMX_STATIC_ABOUT6)->Hide(bTab3);
	GetControl(IDC_RMX_STATIC_ABOUT7)->Hide(bTab3);

	m_nTab = nTab;
	return true;
}

// ---------------------------------------------------------------------------
// Function: MouseEvent
//
// Process mouse events for all controls available on the DJ Console Rmx.
// ---------------------------------------------------------------------------
bool CDevRmxDlg::MouseEvent( int x, int y, int button, PREFRESH_RECT refreshRect )
{
	bool		bMouseEvent = false;
	bool		bProcessEvent, bResult;
	int		nControlID, nMsg, nValue;
	unsigned long	ulParam1, ulParam2;
	CGCheckBox *pCheckBox;
	CGButton *pButton;
	CGSlider *pSlider;
	CGStaticText *pStatic;
	int w1, w2, nvalue;
	char szText[40];
	JOG_WHEELS_DIS	eJogWheelsLock;
	JOGS_SENSITIVE	eJogWheelsSensitivity;

	bMouseEvent = CGDialog::MouseEvent(x,y,button, refreshRect);

	do
	{
		bProcessEvent = GetEvent(&nControlID, &nMsg, &ulParam1, &ulParam2);
		if (bProcessEvent) {
			switch(nControlID)
			{
			case IDC_RMX_TAB_MAIN:
			case IDC_RMX_TAB_ADVANCED:
			case IDC_RMX_TAB_ABOUT:
				SetTab(nControlID-IDC_RMX_TAB_MAIN);
				refreshRect->x = 0; refreshRect->y = 0;
				refreshRect->w = m_nWidth; refreshRect->h = m_nHeight;
				break;
			case IDC_RMX_HERCULES_LOGO:
				m_helpers.LaunchInternetBrowser(g_LOCALIZATION.GetString(IDS_HTTP_RMX));
				break;
			}
			if (m_pDManager!=NULL)
			{
				bResult = true;
				switch(nControlID)
				{
				case IDC_RMX_COMBO_JOG_ENABLE:
					eJogWheelsLock = ENABLE;
					switch(ulParam1)
					{
					case 1:
						eJogWheelsLock = DISABLE_A;
						break;
					case 2:
						eJogWheelsLock = DISABLE_B;
						break;
					case 3:
						eJogWheelsLock = DISABLE_BOTH;
						break;
					}
					bResult = m_pDManager->LockJogWheel(eJogWheelsLock, m_pDeviceState);
					break;
				case IDC_RMX_COMBO_JOG_SENSITIV:
					eJogWheelsSensitivity = NORMAL;
					switch(ulParam1)
					{
					case 1:
						eJogWheelsSensitivity = LESS;
						break;
					case 2:
						eJogWheelsSensitivity = LEAST;
						break;
					}
					bResult = m_pDManager->SetJogsSensitivity(
						eJogWheelsSensitivity, m_pDeviceState);
					break;
				case IDC_RMX_COMBO_MIDI:
					bResult = m_pDManager->SetMidiChannel(ulParam1, m_pDeviceState);
					break;
				case IDC_RMX_CHECKBOX_USB_12:
					bResult = m_pDManager->SetOutputMainHwMix(NONE, m_pDeviceState);
					pCheckBox = (CGCheckBox *) GetControl(IDC_RMX_CHECKBOX_USB_12);
					pCheckBox->SetState(1);
					pCheckBox = (CGCheckBox *) GetControl(IDC_RMX_CHECKBOX_USB_12_MIC);
					pCheckBox->SetState(0);
					pCheckBox = (CGCheckBox *) GetControl(IDC_RMX_CHECKBOX_USB_12_LIN);
					pCheckBox->SetState(0);
					break;
				case IDC_RMX_CHECKBOX_USB_12_MIC:
					bResult = m_pDManager->SetOutputMainHwMix(MIX_WITH_MIC, m_pDeviceState);
					pCheckBox = (CGCheckBox *) GetControl(IDC_RMX_CHECKBOX_USB_12);
					pCheckBox->SetState(0);
					pCheckBox = (CGCheckBox *) GetControl(IDC_RMX_CHECKBOX_USB_12_MIC);
					pCheckBox->SetState(1);
					pCheckBox = (CGCheckBox *) GetControl(IDC_RMX_CHECKBOX_USB_12_LIN);
					pCheckBox->SetState(0);
					break;
				case IDC_RMX_CHECKBOX_USB_12_LIN:
					bResult = m_pDManager->SetOutputMainHwMix(MIX_WITH_LINE_IN, m_pDeviceState);
					pCheckBox = (CGCheckBox *) GetControl(IDC_RMX_CHECKBOX_USB_12);
					pCheckBox->SetState(0);
					pCheckBox = (CGCheckBox *) GetControl(IDC_RMX_CHECKBOX_USB_12_MIC);
					pCheckBox->SetState(0);
					pCheckBox = (CGCheckBox *) GetControl(IDC_RMX_CHECKBOX_USB_12_LIN);
					pCheckBox->SetState(1);
					break;
				case IDC_RMX_LINEIN_PHONO:
					bResult = m_pDManager->SetRecordInput(LINE_IN, m_pDeviceState);
					pCheckBox = (CGCheckBox *) GetControl(IDC_RMX_LINEIN_PHONO);
					pCheckBox->SetState(1);
					pCheckBox = (CGCheckBox *) GetControl(IDC_RMX_MIC);
					pCheckBox->SetState(0);
					break;
				case IDC_RMX_MIC:
					bResult = m_pDManager->SetRecordInput(MIC, m_pDeviceState);
					pCheckBox = (CGCheckBox *) GetControl(IDC_RMX_LINEIN_PHONO);
					pCheckBox->SetState(0);
					pCheckBox = (CGCheckBox *) GetControl(IDC_RMX_MIC);
					pCheckBox->SetState(1);
					break;
				case IDC_RMX_VOLUME_1:
					m_pDeviceState->nVolumeToApply[0] = ulParam1;
					m_pDeviceState->bVolumeToApply[0] = true;
					if (m_pDeviceState->djConsoleRmx.bVolumeLink[0])
					{
						pSlider = (CGSlider *) GetControl(IDC_RMX_BALANCE_12);
						nValue = pSlider->GetPos();
						nValue = nValue * ulParam1 / 128;
						if (nValue>255) nvalue = 255;

						m_pDeviceState->nVolumeToApply[1] = nValue;
						m_pDeviceState->bVolumeToApply[1] = true;
						pSlider = (CGSlider *) GetControl(IDC_RMX_VOLUME_2);
						pSlider->SetPos(nValue);
					}
					else
					{
						nValue = 128;
						if ((int) ulParam1<m_pDeviceState->djConsoleRmx.nVolume[1])
						{
							nValue = 128+127*(m_pDeviceState->djConsoleRmx.nVolume[1]-ulParam1)/
								m_pDeviceState->djConsoleRmx.nVolume[1];
						}
						else if ((int) ulParam1>m_pDeviceState->djConsoleRmx.nVolume[1])
						{
							nValue = 128-128*(ulParam1-m_pDeviceState->djConsoleRmx.nVolume[1])/
								ulParam1;
						}
						pSlider = (CGSlider *) GetControl(IDC_RMX_BALANCE_12);
						pSlider->SetPos(nValue);
					}
					break;
				case IDC_RMX_VOLUME_2:
					m_pDeviceState->nVolumeToApply[1] = ulParam1;
					m_pDeviceState->bVolumeToApply[1] = true;
					if (m_pDeviceState->djConsoleRmx.bVolumeLink[0])
					{
						pSlider = (CGSlider *) GetControl(IDC_RMX_BALANCE_12);
						nValue = pSlider->GetPos();
						if (nValue<=128)
							nValue = 128 + (128-nValue);
						else
							nValue = 255 - nValue;
						nValue = nValue * ulParam1 / 128;
						if (nValue>255) nvalue = 255;
						m_pDeviceState->nVolumeToApply[0] = nValue;
						m_pDeviceState->bVolumeToApply[0] = true;
						pSlider = (CGSlider *) GetControl(IDC_RMX_VOLUME_1);
						pSlider->SetPos(nValue);
					}
					else
					{
						nValue = 128;
						if (m_pDeviceState->djConsoleRmx.nVolume[0]<(int) ulParam1)
						{
							nValue = 128+127*(ulParam1-m_pDeviceState->djConsoleRmx.nVolume[0])/
								ulParam1;
						}
						else if (m_pDeviceState->djConsoleRmx.nVolume[0]>(int) ulParam1)
						{
							nValue = 128-128*(m_pDeviceState->djConsoleRmx.nVolume[0]-ulParam1)/
								m_pDeviceState->djConsoleRmx.nVolume[0];
						}
						pSlider = (CGSlider *) GetControl(IDC_RMX_BALANCE_12);
						pSlider->SetPos(nValue);
					}
					break;

				case IDC_RMX_VOLUME_3:
					m_pDeviceState->nVolumeToApply[2] = ulParam1;
					m_pDeviceState->bVolumeToApply[2] = true;
					if (m_pDeviceState->djConsoleRmx.bVolumeLink[1])
					{
						pSlider = (CGSlider *) GetControl(IDC_RMX_BALANCE_34);
						nValue = pSlider->GetPos();
						nValue = nValue * ulParam1 / 128;
						if (nValue>255) nvalue = 255;

						m_pDeviceState->nVolumeToApply[3] = nValue;
						m_pDeviceState->bVolumeToApply[3] = true;
						pSlider = (CGSlider *) GetControl(IDC_RMX_VOLUME_4);
						pSlider->SetPos(nValue);
					}
					else
					{
						nValue = 128;
						if ((int) ulParam1<m_pDeviceState->djConsoleRmx.nVolume[3])
						{
							nValue = 128+127*(m_pDeviceState->djConsoleRmx.nVolume[3]-ulParam1)/
								m_pDeviceState->djConsoleRmx.nVolume[3];
						}
						else if ((int) ulParam1>m_pDeviceState->djConsoleRmx.nVolume[3])
						{
							nValue = 128-128*(ulParam1-m_pDeviceState->djConsoleRmx.nVolume[3])/
								ulParam1;
						}
						pSlider = (CGSlider *) GetControl(IDC_RMX_BALANCE_34);
						pSlider->SetPos(nValue);
					}
					break;
				case IDC_RMX_VOLUME_4:
					m_pDeviceState->nVolumeToApply[3] = ulParam1;
					m_pDeviceState->bVolumeToApply[3] = true;
					if (m_pDeviceState->djConsoleRmx.bVolumeLink[1])
					{
						pSlider = (CGSlider *) GetControl(IDC_RMX_BALANCE_34);
						nValue = pSlider->GetPos();
						if (nValue<=128)
							nValue = 128 + (128-nValue);
						else
							nValue = 255 - nValue;
						nValue = nValue * ulParam1 / 128;
						if (nValue>255) nvalue = 255;
						m_pDeviceState->nVolumeToApply[2] = nValue;
						m_pDeviceState->bVolumeToApply[2] = true;
						pSlider = (CGSlider *) GetControl(IDC_RMX_VOLUME_3);
						pSlider->SetPos(nValue);
					}
					else
					{
						nValue = 128;
						if (m_pDeviceState->djConsoleRmx.nVolume[2]<(int) ulParam1)
						{
							nValue = 128+127*(ulParam1-m_pDeviceState->djConsoleRmx.nVolume[2])/
								ulParam1;
						}
						else if (m_pDeviceState->djConsoleRmx.nVolume[2]>(int) ulParam1)
						{
							nValue = 128-128*(m_pDeviceState->djConsoleRmx.nVolume[2]-ulParam1)/
								m_pDeviceState->djConsoleRmx.nVolume[2];
						}
						pSlider = (CGSlider *) GetControl(IDC_RMX_BALANCE_34);
						pSlider->SetPos(nValue);
					}
					break;
				case IDC_RMX_BALANCE_12:
					if (nMsg==GEVENT_SLIDER_DCLICK)
					{
						pSlider = (CGSlider *) GetControl(IDC_RMX_BALANCE_12);
						pSlider->SetPos(128);
						w1 = w2 = 128;
					}
					else
					{
						w1 = (ulParam1<128) ? 128 : 128*(255-ulParam1)/127;
						w2 = (ulParam1>127) ? 128 : ulParam1;
					}
					pSlider = (CGSlider *) GetControl(IDC_RMX_VOLUME_1);
					nValue = pSlider->GetPos();
					pSlider = (CGSlider *) GetControl(IDC_RMX_VOLUME_2);
					if (pSlider->GetPos()>nValue)
						nValue = pSlider->GetPos();
					m_pDeviceState->nVolumeToApply[0] = w1 * nValue / 128;
					m_pDeviceState->nVolumeToApply[1] = w2 * nValue / 128;
					m_pDeviceState->bVolumeToApply[0] = true;
					m_pDeviceState->bVolumeToApply[1] = true;
					pSlider->SetPos(w2 * nValue / 128);
					pSlider = (CGSlider *) GetControl(IDC_RMX_VOLUME_1);
					pSlider->SetPos(w1 * nValue / 128);
					break;
				case IDC_RMX_BALANCE_34:
					if (nMsg==GEVENT_SLIDER_DCLICK)
					{
						pSlider = (CGSlider *) GetControl(IDC_RMX_BALANCE_34);
						pSlider->SetPos(128);
						w1 = w2 = 128;
					}
					else
					{
						w1 = (ulParam1<128) ? 128 : 128*(255-ulParam1)/127;
						w2 = (ulParam1>127) ? 128 : ulParam1;
					}
					pSlider = (CGSlider *) GetControl(IDC_RMX_VOLUME_3);
					nValue = pSlider->GetPos();
					pSlider = (CGSlider *) GetControl(IDC_RMX_VOLUME_4);
					if (pSlider->GetPos()>nValue)
						nValue = pSlider->GetPos();
					m_pDeviceState->nVolumeToApply[2] = w1 * nValue / 128;
					m_pDeviceState->nVolumeToApply[3] = w2 * nValue / 128;
					m_pDeviceState->bVolumeToApply[2] = true;
					m_pDeviceState->bVolumeToApply[3] = true;
					pSlider->SetPos(w2 * nValue / 128);
					pSlider = (CGSlider *) GetControl(IDC_RMX_VOLUME_3);
					pSlider->SetPos(w1 * nValue / 128);
					break;
				case IDC_RMX_LINK_VOL_CH12:
					pButton = (CGButton *) GetControl(IDC_RMX_LINK_VOL_CH12);
					m_pDeviceState->djConsoleRmx.bVolumeLink[0] = pButton->GetState()==0;
					break;
				case IDC_RMX_LINK_VOL_CH34:
					pButton = (CGButton *) GetControl(IDC_RMX_LINK_VOL_CH34);
					m_pDeviceState->djConsoleRmx.bVolumeLink[1] = pButton->GetState()==0;
					break;
				case IDC_RMX_MUTE_CH12:
					pButton = (CGButton *) GetControl(IDC_RMX_MUTE_CH12);
					bResult = m_pDManager->SetMute(m_pDeviceState, 0, pButton->GetState()==1);
					break;
				case IDC_RMX_MUTE_CH34:
					pButton = (CGButton *) GetControl(IDC_RMX_MUTE_CH34);
					bResult = m_pDManager->SetMute(m_pDeviceState, 1, pButton->GetState()==1);
					break;
				case IDC_RMX_CHECKBOX_TALK_ATT:
					pCheckBox = (CGCheckBox *) GetControl(IDC_RMX_CHECKBOX_TALK_ATT);
					pSlider = (CGSlider *) GetControl(IDC_RMX_TALKOVER);
					pSlider->Enable(pCheckBox->GetState()==1);
					bResult = m_pDManager->EnableTalkover(pCheckBox->GetState()==1,
						m_pDeviceState);
					break;
				case IDC_RMX_TALKOVER:
					pSlider = (CGSlider *) GetControl(IDC_RMX_TALKOVER);
					bResult = m_pDManager->SetTalkoverAttenuation(pSlider->GetPos()*3+3,
						m_pDeviceState);
					sprintf(szText, "-%d dB", m_pDeviceState->djConsoleRmx.nTalkoverAttenuation);
					pStatic = (CGStaticText *) GetControl(IDC_RMX_STATIC_ATT_DB);
					pStatic->SetLabel(szText);
					break;
				}

				if (!bResult)
				{
				}
			}
		}
	} while (bProcessEvent);

	return bMouseEvent;
}

// ---------------------------------------------------------------------------
// Function: InitializeMixerState
//
// Set the mixer (volume, mute) states base on the device state.
// ---------------------------------------------------------------------------
void CDevRmxDlg::InitializeMixerState( DJ_DEVICE_STATE *pDeviceState, CDManager *pDeviceManager )
{
	CGButton *pButton;
	CGSlider *pSlider;
	int nValue;

	// --- Volumes / Balance ---
	pSlider = (CGSlider *) GetControl(IDC_RMX_VOLUME_1);
	pSlider->SetPos(pDeviceState->djConsoleRmx.nVolume[0]);
	pSlider = (CGSlider *) GetControl(IDC_RMX_VOLUME_2);
	pSlider->SetPos(pDeviceState->djConsoleRmx.nVolume[1]);
	pSlider = (CGSlider *) GetControl(IDC_RMX_VOLUME_3);
	pSlider->SetPos(pDeviceState->djConsoleRmx.nVolume[2]);
	pSlider = (CGSlider *) GetControl(IDC_RMX_VOLUME_4);
	pSlider->SetPos(pDeviceState->djConsoleRmx.nVolume[3]);


	nValue = 128;
	if (pDeviceState->djConsoleRmx.nVolume[0]<pDeviceState->djConsoleRmx.nVolume[1])
	{
		nValue = 128+127*(pDeviceState->djConsoleRmx.nVolume[1] - pDeviceState->djConsoleRmx.nVolume[0])/
			pDeviceState->djConsoleRmx.nVolume[1];
	}
	else if (pDeviceState->djConsoleRmx.nVolume[0]>pDeviceState->djConsoleRmx.nVolume[1])
	{
		nValue = 128-128*(pDeviceState->djConsoleRmx.nVolume[0] - pDeviceState->djConsoleRmx.nVolume[1])/
			pDeviceState->djConsoleRmx.nVolume[0];
	}
	pSlider = (CGSlider *) GetControl(IDC_RMX_BALANCE_12);
	pSlider->SetPos(nValue);

	nValue = 128;
	if (pDeviceState->djConsoleRmx.nVolume[2]<pDeviceState->djConsoleRmx.nVolume[3])
	{
		nValue = 128+127*(pDeviceState->djConsoleRmx.nVolume[3] - pDeviceState->djConsoleRmx.nVolume[2])/
			pDeviceState->djConsoleRmx.nVolume[3];
	}
	else if (pDeviceState->djConsoleRmx.nVolume[2]>pDeviceState->djConsoleRmx.nVolume[3])
	{
		nValue = 128-128*(pDeviceState->djConsoleRmx.nVolume[2] - pDeviceState->djConsoleRmx.nVolume[3])/
			pDeviceState->djConsoleRmx.nVolume[2];
	}
	pSlider = (CGSlider *) GetControl(IDC_RMX_BALANCE_34);
	pSlider->SetPos(nValue);

	// --- Mutes Volumes ---
	pButton = (CGButton *) GetControl(IDC_RMX_MUTE_CH12);
	pButton->SetState(pDeviceState->djConsoleRmx.bMute[0]==true);
	pButton = (CGButton *) GetControl(IDC_RMX_MUTE_CH34);
	pButton->SetState(pDeviceState->djConsoleRmx.bMute[1]==true);
	DEBUG_PRINT("CDevRmxDlg::InitializeMixerState completed.");
}

// ---------------------------------------------------------------------------
// Function: ApplyVolume
//
// For each volume which need to be set, call SetVolume to adjust it.
// ---------------------------------------------------------------------------
bool CDevRmxDlg::ApplyVolume( DJ_DEVICE_STATE *pDeviceState )
{
	int nValue, i;
	bool bRefresh = false;

	for(i=0;i<4;++i)
	{
		if (pDeviceState->bVolumeToApply[i])
		{
			pDeviceState->bVolumeToApply[i] = false;
			nValue = pDeviceState->nVolumeToApply[i];
			m_pDManager->SetVolume(m_pDeviceState, i, nValue);
			pDeviceState->djConsoleRmx.nVolume[i] = nValue;
			bRefresh = true;
		}
	}

	return bRefresh;
}

// ---------------------------------------------------------------------------
// Function: InitializeDlgState
//
// Set various hardware setting (excluding HID and Audio Mixer).
// ---------------------------------------------------------------------------
void CDevRmxDlg::InitializeDlgState( DJ_DEVICE_STATE *pDeviceState, CDManager *pDeviceManager )
{
	char szText[80];
	CGStaticText *pStatic;
	CGComboBox *pCombo;
	CGCheckBox *pCheckBox;
	CGButton *pButton;
	CGSlider *pSlider;
	int nJogSensitive, nJogEnable;

	CGDialog::InitializeDlgState(pDeviceState, pDeviceManager);
	InitializeMixerState( pDeviceState, pDeviceManager );

	nJogSensitive = nJogEnable = 0;
	if (pDeviceState->djConsoleRmx.eJogWheelsLock==DISABLE_A)
		nJogEnable = 1;
	else if (pDeviceState->djConsoleRmx.eJogWheelsLock==DISABLE_B)
		nJogEnable = 2;
	else if (pDeviceState->djConsoleRmx.eJogWheelsLock==DISABLE_BOTH)
		nJogEnable = 3;

	if (pDeviceState->djConsoleRmx.eJogWheelsSensitivity==LESS)
		nJogSensitive = 1;
	else if (pDeviceState->djConsoleRmx.eJogWheelsSensitivity==LEAST)
		nJogSensitive = 2;

	pCombo = (CGComboBox *) GetControl(IDC_RMX_COMBO_JOG_SENSITIV);
	pCombo->SetCurSel(nJogSensitive);
	pCombo = (CGComboBox *) GetControl(IDC_RMX_COMBO_JOG_ENABLE);
	pCombo->SetCurSel(nJogEnable);

	// --- Link ---
	pButton = (CGButton *) GetControl(IDC_RMX_LINK_VOL_CH12);
	pButton->SetState(pDeviceState->djConsoleRmx.bVolumeLink[0]==false);
	pButton = (CGButton *) GetControl(IDC_RMX_LINK_VOL_CH34);
	pButton->SetState(pDeviceState->djConsoleRmx.bVolumeLink[1]==false);

	// --- Record Input : Line-In or Mic ---
	pButton = (CGButton *) GetControl(IDC_RMX_LINEIN_PHONO);
	pButton->SetState(!pDeviceState->djConsoleRmx.bEnableInputMic);
	pButton = (CGButton *) GetControl(IDC_RMX_MIC);
	pButton->SetState(pDeviceState->djConsoleRmx.bEnableInputMic);

	// --- Talkover Attenuation ---
	pCheckBox = (CGCheckBox *) GetControl(IDC_RMX_CHECKBOX_TALK_ATT);
	pCheckBox->SetState(pDeviceState->djConsoleRmx.bTalkoverAttenuation);
	pSlider = (CGSlider *) GetControl(IDC_RMX_TALKOVER);
	pSlider->Enable(pDeviceState->djConsoleRmx.bTalkoverAttenuation);
	pSlider->SetPos(pDeviceState->djConsoleRmx.nTalkoverAttenuation/3-1);
	sprintf(szText, "-%d dB", pDeviceState->djConsoleRmx.nTalkoverAttenuation);
	pStatic = (CGStaticText *) GetControl(IDC_RMX_STATIC_ATT_DB);
	pStatic->SetLabel(szText);

	// --- MIDI and Hardware Mix ---
	pCheckBox = (CGCheckBox *) GetControl(IDC_RMX_CHECKBOX_USB_12);
	pCheckBox->SetState(pDeviceState->djConsoleRmx.eOutput12Mix==NONE);
	pCheckBox = (CGCheckBox *) GetControl(IDC_RMX_CHECKBOX_USB_12_MIC);
	pCheckBox->SetState(pDeviceState->djConsoleRmx.eOutput12Mix==MIX_WITH_MIC);
	pCheckBox = (CGCheckBox *) GetControl(IDC_RMX_CHECKBOX_USB_12_LIN);
	pCheckBox->SetState(pDeviceState->djConsoleRmx.eOutput12Mix==MIX_WITH_LINE_IN);

	pCombo = (CGComboBox *) GetControl(IDC_RMX_COMBO_MIDI);
	pCombo->SetCurSel(pDeviceState->djConsoleRmx.nMidiChannel);


	// --- Information ---
	pStatic = (CGStaticText *) GetControl(IDC_RMX_STATIC_ABOUT3);
	sprintf(szText, "%s %s", g_LOCALIZATION.GetString(IDS_PACKAGE), INFO_PACKAGE_NAME);
	pStatic->SetLabel(szText);
	pStatic = (CGStaticText *) GetControl(IDC_RMX_STATIC_ABOUT4);

	sprintf(szText, "%s %d.%d.%d.%d", g_LOCALIZATION.GetString(IDS_FIRMWARE),
		(int) ((pDeviceState->djConsoleRmx.lFirmwareVersion>>24)&0xFF), 
		(int) ((pDeviceState->djConsoleRmx.lFirmwareVersion>>16)&0xFF),
		(int) ((pDeviceState->djConsoleRmx.lFirmwareVersion>>8)&0xFF),
		(int) ((pDeviceState->djConsoleRmx.lFirmwareVersion>>0)&0xFF));
	pStatic->SetLabel(szText);
	pStatic = (CGStaticText *) GetControl(IDC_RMX_STATIC_ABOUT5);
	sprintf(szText, "%s %d.%d.%d.%d", g_LOCALIZATION.GetString(IDS_DRIVER),
		ConvertBCDtoInt((int) (pDeviceState->ulBULK_Version>>24)&0xFF),
		ConvertBCDtoInt((int) (pDeviceState->ulBULK_Version>>16)&0xFF),
		ConvertBCDtoInt((int) (pDeviceState->ulBULK_Version>>8)&0xFF),
		ConvertBCDtoInt((int) (pDeviceState->ulBULK_Version>>0)&0xFF));
	pStatic->SetLabel(szText);
	
	pStatic = (CGStaticText *) GetControl(IDC_RMX_STATIC_ABOUT6);
	sprintf(szText, "%s %s", g_LOCALIZATION.GetString(IDS_CONTROL_PANEL), INFO_CONTROL_PANEL);
	pStatic->SetLabel(szText);
	DEBUG_PRINT("CDevRmxDlg::InitializeDlgState completed.");
}


