/////////////////////////////////////////////////////////////////////////////
// Name:        devsteeldlg.cpp
// Purpose:     Implement GUI for DJ Control Steel Dialog.
// Author:      Yann Hamiaux
// Modified by: -
// Created:     07/07/2008
// Copyright:   Written for Guillemot Corporation by Yann Hamiaux
// Licence:     The GNU General Public License v2+.
/////////////////////////////////////////////////////////////////////////////
#include "devsteeldlg.h"
#include "localization.h"

extern CLocalization	g_LOCALIZATION;


CDevSteelDlg::CDevSteelDlg( wxMemoryDC *pSkinMemDC, wxMemoryDC *pSkinAlphaMemDC ) : 
	CGDialog(pSkinMemDC, pSkinAlphaMemDC, 349, 355)
{
	STATIC_STATE_INFO	staticInfo[7];
	BUTTON_STATE_INFO	buttonInfo[4];
	char			szText[40];
	COMBO_INFO		comboInfo;
	CGStatic		*pStaticImg;
	CGControl		*pCtrl;
	CGStaticText	   	*pStatic;
	CGComboBox		*pComboBox;
	int			nCPLTab;
	int			i;

	// --- ABOUT Tab ---
	staticInfo[0].x = 350;
	staticInfo[0].y = 0;
	staticInfo[0].nProcessAlpha = FALSE;

	pStaticImg = new CGStatic(&m_eventList, IDC_STEEL_ABOUT_TAB, 
		0,0,349,355, m_pSkinMemDC, m_pSkinAlphaMemDC, 1, staticInfo);
	AddControl((CGControl *) pStaticImg);

	// --- Hercules Logo ---
	for(i=0;i<4;++i)
		buttonInfo[0].coordinates[i].y = 416;
	buttonInfo[0].nProcessAlpha = FALSE;
	buttonInfo[0].coordinates[0].x = 0;
	buttonInfo[0].coordinates[1].x = 98;
	buttonInfo[0].coordinates[2].x = 196;
	buttonInfo[0].coordinates[3].x = 294;

	pCtrl = (CGControl *) new CGButton(&m_eventList, IDC_STEEL_HERCULES_LOGO, 
		125,255,97,65,m_pSkinMemDC, m_pSkinAlphaMemDC, 1, buttonInfo);
	AddControl(pCtrl);

	// --- Tab Button: Main ---
	for(i=0;i<4;++i) {
		buttonInfo[0].coordinates[i].y = 356;
		buttonInfo[1].coordinates[i].y = 356;
	}
	buttonInfo[0].coordinates[0].x = 0;
	buttonInfo[0].coordinates[1].x = 95;
	buttonInfo[0].coordinates[2].x = 190;
	buttonInfo[0].coordinates[3].x = 285;
	buttonInfo[1].coordinates[0].x = 380;
	buttonInfo[1].coordinates[1].x = 475;
	buttonInfo[1].coordinates[2].x = 570;
	buttonInfo[1].coordinates[3].x = 665;

	buttonInfo[0].nProcessAlpha = FALSE;
	buttonInfo[1].nProcessAlpha = FALSE;
	pCtrl = (CGControl *) new CGButton(&m_eventList, IDC_STEEL_TAB_MAIN, 
		14,53,94,29,m_pSkinMemDC, m_pSkinAlphaMemDC, 2, buttonInfo);
	AddControl(pCtrl);

	
	// --- Tab Button: About ---
	for(i=0;i<4;++i) {
		buttonInfo[0].coordinates[i].y = 386;
		buttonInfo[1].coordinates[i].y = 386;
	}

	buttonInfo[0].nProcessAlpha = FALSE;
	buttonInfo[1].nProcessAlpha = FALSE;
	pCtrl = (CGControl *) new CGButton(&m_eventList, IDC_STEEL_TAB_ABOUT, 
		110,53,94,29,m_pSkinMemDC, m_pSkinAlphaMemDC, 2, buttonInfo);
	AddControl(pCtrl);

	// --- Static Information: Main, ASIO, Advanced, About ---
	pStatic = new CGStaticText(&m_eventList, IDC_STEEL_STATIC_MAIN, g_LOCALIZATION.GetString(IDS_TAB_MAIN), 
		14,53,94,29, ALIGN_CENTER|VALIGN_CENTER);
	pStatic->SetFontAttributes(true, false);
	pStatic->SetFontColor(0xFF, 0xFF, 0xFF);
	AddControl((CGControl *) pStatic);
	pStatic = new CGStaticText(&m_eventList, IDC_STEEL_STATIC_ABOUT, g_LOCALIZATION.GetString(IDS_TAB_ABOUT), 
		110,53,94,29, ALIGN_CENTER|VALIGN_CENTER);
	pStatic->SetFontColor(0xFF, 0xFF, 0xFF);
	pStatic->SetFontAttributes(true, false);
	AddControl((CGControl *) pStatic);

	// --- Main Tab Labels ---
	pStatic = new CGStaticText(&m_eventList, IDC_STEEL_STATIC_MIDI_CH, 
		g_LOCALIZATION.GetString(IDS_MIDI_CHANNEL_FOR_CONTROLS), 
		28,95,293,18, ALIGN_LEFT|VALIGN_CENTER);
	pStatic->SetFontAttributes(true, false);
	pStatic->SetFontColor(0xFF, 0xFF, 0xFF);
	AddControl((CGControl *) pStatic);

	pStatic = new CGStaticText(&m_eventList, IDC_STEEL_STATIC_JOG_SETTINGS,
		g_LOCALIZATION.GetString(IDS_JOG_WHEELS_SETTINGS), 
		28,150,293,18, ALIGN_CENTER|VALIGN_CENTER);
	pStatic->SetFontAttributes(true, false);
	pStatic->SetFontColor(0xFF, 0xFF, 0xFF);
	AddControl((CGControl *) pStatic);

	pStatic = new CGStaticText(&m_eventList, IDC_STEEL_STATIC_JOG_ENABLE,
		g_LOCALIZATION.GetString(IDS_ENABLING_DISABLING),
		28,167,293,18, ALIGN_LEFT|VALIGN_CENTER);
	pStatic->SetFontAttributes(true, false);
	pStatic->SetFontColor(0xFF, 0xFF, 0xFF);
	AddControl((CGControl *) pStatic);
	pStatic = new CGStaticText(&m_eventList, IDC_STEEL_STATIC_JOG_SENSITIVE,
		g_LOCALIZATION.GetString(IDS_SENSITIVITY),
		28,210,293,18, ALIGN_LEFT|VALIGN_CENTER);
	pStatic->SetFontAttributes(true, false);
	pStatic->SetFontColor(0xFF, 0xFF, 0xFF);
	AddControl((CGControl *) pStatic);


	// --- ABOUT Tab Labels ---
	pStatic = new CGStaticText(&m_eventList, IDC_STEEL_STATIC_ABOUT1,
		g_LOCALIZATION.GetString(IDS_TECH_SUPPORT_INFO_NOTE_1),
		36,109,500,18, ALIGN_LEFT|VALIGN_TOP);
	pStatic->SetFontAttributes(false, false);
	AddControl((CGControl *) pStatic);
	pStatic = new CGStaticText(&m_eventList, IDC_STEEL_STATIC_ABOUT2,
		g_LOCALIZATION.GetString(IDS_TECH_SUPPORT_INFO_NOTE_2),
		36,109+18*1,500,18, ALIGN_LEFT|VALIGN_TOP);
	pStatic->SetFontAttributes(false, false);
	AddControl((CGControl *) pStatic);

	pStatic = new CGStaticText(&m_eventList, IDC_STEEL_STATIC_ABOUT3, "Package: n/a", 
		36,109+18*3,500,18, ALIGN_LEFT|VALIGN_TOP);
	pStatic->SetFontAttributes(false, false);
	AddControl((CGControl *) pStatic);
	pStatic = new CGStaticText(&m_eventList, IDC_STEEL_STATIC_ABOUT4, "Firmware: n/a", 
		36,109+18*3+14*1,500,18, ALIGN_LEFT|VALIGN_TOP);
	pStatic->SetFontAttributes(false, false);
	AddControl((CGControl *) pStatic);
	pStatic = new CGStaticText(&m_eventList, IDC_STEEL_STATIC_ABOUT5, "Driver: n/a", 
		36,109+18*3+14*2,500,18, ALIGN_LEFT|VALIGN_TOP);
	pStatic->SetFontAttributes(false, false);
	AddControl((CGControl *) pStatic);
	pStatic = new CGStaticText(&m_eventList, IDC_STEEL_STATIC_ABOUT6, "CPL: n/a", 
		36,109+18*3+14*3,500,18, ALIGN_LEFT|VALIGN_TOP);
	pStatic->SetFontAttributes(false, false);
	AddControl((CGControl *) pStatic);
	pStatic = new CGStaticText(&m_eventList, IDC_STEEL_STATIC_ABOUT7, 
		g_LOCALIZATION.GetString(IDS_RIGHTS_RESERVED), 
		36,109+10+18*3+14*4,500,18, ALIGN_LEFT|VALIGN_TOP);
	pStatic->SetFontAttributes(false, false);
	AddControl((CGControl *) pStatic);

	// --- Combo Box ---
	comboInfo.box[0].x = 0;
	comboInfo.box[0].y = 487;
	comboInfo.box[2].x = 0;
	comboInfo.box[2].y = 510;
	comboInfo.box[1].x = 295;
	comboInfo.box[1].y = 487;//476;
	comboInfo.box[3].x = 295;
	comboInfo.box[3].y = 510;//498;
	
	comboInfo.sbckBottom.x = 622;
	comboInfo.sbckBottom.y = 487;
	comboInfo.sbckBottom.w = 16;
	comboInfo.sbckBottom.h = 2;

	comboInfo.sbckMiddle.x = 605;
	comboInfo.sbckMiddle.y = 487;
	comboInfo.sbckMiddle.w = 16;
	comboInfo.sbckMiddle.h = 1;

	comboInfo.sbckTop.x = 588;
	comboInfo.sbckTop.y = 487;
	comboInfo.sbckTop.w = 16;
	comboInfo.sbckTop.h = 2;

	comboInfo.sbutBottom[0].x = 686;
	comboInfo.sbutBottom[0].y = 447;
	comboInfo.sbutBottom[0].w = 16;
	comboInfo.sbutBottom[0].h = 13;
	comboInfo.sbutBottom[1].x = 703;
	comboInfo.sbutBottom[1].y = 447;
	comboInfo.sbutBottom[1].w = 16;
	comboInfo.sbutBottom[1].h = 13;
	comboInfo.sbutBottom[2].x = 720;
	comboInfo.sbutBottom[2].y = 447;
	comboInfo.sbutBottom[2].w = 16;
	comboInfo.sbutBottom[2].h = 13;
	comboInfo.sbutBottom[3].x = 737;
	comboInfo.sbutBottom[3].y = 447;
	comboInfo.sbutBottom[3].w = 16;
	comboInfo.sbutBottom[3].h = 13;

	comboInfo.sbutTop[0].x = 686;
	comboInfo.sbutTop[0].y = 433;
	comboInfo.sbutTop[0].w = 16;
	comboInfo.sbutTop[0].h = 13;
	comboInfo.sbutTop[1].x = 703;
	comboInfo.sbutTop[1].y = 433;
	comboInfo.sbutTop[1].w = 16;
	comboInfo.sbutTop[1].h = 13;
	comboInfo.sbutTop[2].x = 720;
	comboInfo.sbutTop[2].y = 433;
	comboInfo.sbutTop[2].w = 16;
	comboInfo.sbutTop[2].h = 13;
	comboInfo.sbutTop[3].x = 737;
	comboInfo.sbutTop[3].y = 433;
	comboInfo.sbutTop[3].w = 16;
	comboInfo.sbutTop[3].h = 13;

	comboInfo.stmbTop.x = 639;
	comboInfo.stmbTop.y = 487;
	comboInfo.stmbTop.w = 12;
	comboInfo.stmbTop.h = 11;

	comboInfo.stmbMiddle.x = 652;
	comboInfo.stmbMiddle.y = 487;
	comboInfo.stmbMiddle.w = 12;
	comboInfo.stmbMiddle.h = 6;

	comboInfo.stmbBottom.x = 665;
	comboInfo.stmbBottom.y = 487;
	comboInfo.stmbBottom.w = 12;
	comboInfo.stmbBottom.h = 11;

	comboInfo.colorFont.r = 0x00;
	comboInfo.colorFont.g = 0x00;
	comboInfo.colorFont.b = 0x00;

	comboInfo.nBoxLeftSpace = 5;

	comboInfo.HighlightBckgrndColor.r = 0x00;
	comboInfo.HighlightBckgrndColor.g = 0x00;
	comboInfo.HighlightBckgrndColor.b = 0xFF;

	comboInfo.HighlightForegrndColor.r = 0xFF;
	comboInfo.HighlightForegrndColor.g = 0xFF;
	comboInfo.HighlightForegrndColor.b = 0xFF;

	comboInfo.nFontSizeBox = 8;
	comboInfo.nFontSizeList = 8;

	comboInfo.list.x = 393;	// Buffer Size.
	comboInfo.list.y = 416;

	comboInfo.borderList.l = 3;
	comboInfo.borderList.r = 1;
	comboInfo.borderList.t = 5;
	comboInfo.borderList.b = 10+10;

	pComboBox = new CGComboBox(&m_eventList, IDC_STEEL_COMBO_JOG_SENSITIV, 28, 227, 292, 22, 70, 
		m_pSkinMemDC, m_pSkinAlphaMemDC,&comboInfo);

	AddControl((CGControl *) pComboBox);
	pComboBox->AddToolTips(g_LOCALIZATION.GetString(IDS_JOG_WHEEL_SENSITIVITY_TTIPS));
	pComboBox->ResetContent();
	pComboBox->AddString(g_LOCALIZATION.GetString(IDS_NORMAL_DEFAULT));
	pComboBox->AddString(g_LOCALIZATION.GetString(IDS_LESS_SENSITIVE));
	pComboBox->AddString(g_LOCALIZATION.GetString(IDS_LEAST_SENSITIVE));

	comboInfo.borderList.l = 3;
	comboInfo.borderList.r = 1;
	comboInfo.borderList.t = 3;
	comboInfo.borderList.b = 0+10;

	pComboBox = new CGComboBox(&m_eventList, IDC_STEEL_COMBO_JOG_ENABLE, 28, 184, 292, 22, 70, 
		m_pSkinMemDC, m_pSkinAlphaMemDC,&comboInfo);

	AddControl((CGControl *) pComboBox);
	pComboBox->ResetContent();
	pComboBox->AddString(g_LOCALIZATION.GetString(IDS_ENABLE_DEFAULT));
	pComboBox->AddString(g_LOCALIZATION.GetString(IDS_DISABLE_JOG_DECK_A));
	pComboBox->AddString(g_LOCALIZATION.GetString(IDS_DISABLE_JOG_DECK_B));
	pComboBox->AddString(g_LOCALIZATION.GetString(IDS_DISABLE_JOG_BOTH));

	
	comboInfo.borderList.l = 3;
	comboInfo.borderList.r = 1;
	comboInfo.borderList.t = 2;
	comboInfo.borderList.b = 2;

	pComboBox = new CGComboBox(&m_eventList, IDC_STEEL_COMBO_MIDI, 28, 112, 292, 22, 70, 
		m_pSkinMemDC, m_pSkinAlphaMemDC,&comboInfo);
	AddControl((CGControl *) pComboBox);
	pComboBox->AddToolTips(g_LOCALIZATION.GetString(IDS_MIDI_CHANNEL_TTIPS));
	pComboBox->ResetContent();
	for(i=0;i<16;++i)
	{
		if (i==0)
			sprintf(szText, "%d %s", i+1, g_LOCALIZATION.GetString(IDS_DEFAULT));
		else
			sprintf(szText, "%d", i+1);
		pComboBox->AddString(szText);
	}
	
	// --- CPL Test ---
	nCPLTab = 0;
	SetTab(nCPLTab);

	if (nCPLTab==0)
	{
		GetControl(IDC_STEEL_ABOUT_TAB)->Hide(TRUE);
	}
	else if (nCPLTab==1)
	{
	}

	if (nCPLTab!=0) {
		GetControl(IDC_STEEL_STATIC_MIDI_CH)->Hide(TRUE);
		GetControl(IDC_STEEL_STATIC_JOG_ENABLE)->Hide(TRUE);
		GetControl(IDC_STEEL_STATIC_JOG_SENSITIVE)->Hide(TRUE);
		GetControl(IDC_STEEL_STATIC_JOG_SETTINGS)->Hide(TRUE);
		GetControl(IDC_STEEL_COMBO_JOG_SENSITIV)->Hide(TRUE);
		GetControl(IDC_STEEL_COMBO_JOG_ENABLE)->Hide(TRUE);
		GetControl(IDC_STEEL_COMBO_MIDI)->Hide(TRUE);
		
	}
	
	if (nCPLTab!=1) {
		GetControl(IDC_STEEL_STATIC_ABOUT1)->Hide(TRUE);
		GetControl(IDC_STEEL_STATIC_ABOUT2)->Hide(TRUE);
		GetControl(IDC_STEEL_STATIC_ABOUT3)->Hide(TRUE);
		GetControl(IDC_STEEL_STATIC_ABOUT4)->Hide(TRUE);
		GetControl(IDC_STEEL_STATIC_ABOUT5)->Hide(TRUE);
		GetControl(IDC_STEEL_STATIC_ABOUT6)->Hide(TRUE);
		GetControl(IDC_STEEL_STATIC_ABOUT7)->Hide(TRUE);
	}
}

CDevSteelDlg::~CDevSteelDlg( )
{
}

// ---------------------------------------------------------------------------
// Function: SetTab
//
// Hide/Show controls base on the tab position (main or about).
// ---------------------------------------------------------------------------
bool CDevSteelDlg::SetTab( int nTab )
{
	CGButton *pButton;
	bool bTab1, bTab2;

	if (nTab<0 || nTab>1)
		return false;

	bTab1 = (nTab!=0);
	bTab2 = (nTab!=1);

	pButton = (CGButton *) GetControl(IDC_STEEL_TAB_MAIN);
	pButton->SetState(bTab1 ? 1 : 0);
	pButton = (CGButton *) GetControl(IDC_STEEL_TAB_ABOUT);
	pButton->SetState(bTab2 ? 1 : 0);

	GetControl(IDC_STEEL_ABOUT_TAB)->Hide(bTab2);

	GetControl(IDC_STEEL_STATIC_MIDI_CH)->Hide(bTab1);
	GetControl(IDC_STEEL_STATIC_JOG_ENABLE)->Hide(bTab1);
	GetControl(IDC_STEEL_STATIC_JOG_SENSITIVE)->Hide(bTab1);
	GetControl(IDC_STEEL_STATIC_JOG_SETTINGS)->Hide(bTab1);
	GetControl(IDC_STEEL_COMBO_JOG_SENSITIV)->Hide(bTab1);
	GetControl(IDC_STEEL_COMBO_JOG_ENABLE)->Hide(bTab1);
	GetControl(IDC_STEEL_COMBO_MIDI)->Hide(bTab1);

	GetControl(IDC_STEEL_STATIC_ABOUT1)->Hide(bTab2);
	GetControl(IDC_STEEL_STATIC_ABOUT2)->Hide(bTab2);
	GetControl(IDC_STEEL_STATIC_ABOUT3)->Hide(bTab2);
	GetControl(IDC_STEEL_STATIC_ABOUT4)->Hide(bTab2);
	GetControl(IDC_STEEL_STATIC_ABOUT5)->Hide(bTab2);
	GetControl(IDC_STEEL_STATIC_ABOUT6)->Hide(bTab2);
	GetControl(IDC_STEEL_STATIC_ABOUT7)->Hide(bTab2);
	m_nTab = nTab;
	return true;
}

// ---------------------------------------------------------------------------
// Function: MouseEvent
//
// Process mouse events for all controls available on the DJ Control Steel.
// ---------------------------------------------------------------------------
bool CDevSteelDlg::MouseEvent( int x, int y, int button, PREFRESH_RECT refreshRect )
{
	bool		bMouseEvent = false;
	bool		bProcessEvent, bResult;
	int		nControlID, nMsg;
	unsigned long	ulParam1, ulParam2;
	JOG_WHEELS_DIS	eJogWheelsLock;
	JOGS_SENSITIVE	eJogWheelsSensitivity;

	bMouseEvent = CGDialog::MouseEvent(x,y,button, refreshRect);

	do
	{
		bProcessEvent = GetEvent(&nControlID, &nMsg, &ulParam1, &ulParam2);
		if (bProcessEvent) {
			switch(nControlID)
			{
			case IDC_STEEL_TAB_MAIN:
			case IDC_STEEL_TAB_ABOUT:
				SetTab(nControlID-IDC_STEEL_TAB_MAIN);
				refreshRect->x = 0; refreshRect->y = 0;
				refreshRect->w = m_nWidth; refreshRect->h = m_nHeight;
				break;
			case IDC_STEEL_HERCULES_LOGO:
				m_helpers.LaunchInternetBrowser(g_LOCALIZATION.GetString(IDS_HTTP_STEEL));
				break;
			}

			if (m_pDManager!=NULL)
			{
				bResult = true;
				switch(nControlID)
				{
				case IDC_STEEL_COMBO_JOG_ENABLE:
					eJogWheelsLock = ENABLE;
					switch(ulParam1)
					{
					case 1:
						eJogWheelsLock = DISABLE_A;
						break;
					case 2:
						eJogWheelsLock = DISABLE_B;
						break;
					case 3:
						eJogWheelsLock = DISABLE_BOTH;
						break;
					}
					bResult = m_pDManager->LockJogWheel(eJogWheelsLock, m_pDeviceState);
					break;
				case IDC_STEEL_COMBO_JOG_SENSITIV:
					eJogWheelsSensitivity = NORMAL;
					switch(ulParam1)
					{
					case 1:
						eJogWheelsSensitivity = LESS;
						break;
					case 2:
						eJogWheelsSensitivity = LEAST;
						break;
					}
					bResult = m_pDManager->SetJogsSensitivity(
						eJogWheelsSensitivity, m_pDeviceState);
					break;
				case IDC_STEEL_COMBO_MIDI:
					bResult = m_pDManager->SetMidiChannel(ulParam1, m_pDeviceState);
					break;
				}

				if (!bResult)
				{
				}
			}
		}
	} while (bProcessEvent);

	return bMouseEvent;
}

// ---------------------------------------------------------------------------
// Function: InitializeDlgState
//
// Set various hardware setting (excluding HID and Audio Mixer).
// ---------------------------------------------------------------------------
void CDevSteelDlg::InitializeDlgState( DJ_DEVICE_STATE *pDeviceState, CDManager *pDeviceManager )
{
	char szText[80];
	CGStaticText *pStatic;
	CGComboBox *pCombo;
	int nJogSensitive, nJogEnable;

	CGDialog::InitializeDlgState(pDeviceState, pDeviceManager);

	nJogSensitive = nJogEnable = 0;
	if (pDeviceState->djControlSteel.eJogWheelsLock==DISABLE_A)
		nJogEnable = 1;
	else if (pDeviceState->djControlSteel.eJogWheelsLock==DISABLE_B)
		nJogEnable = 2;
	else if (pDeviceState->djControlSteel.eJogWheelsLock==DISABLE_BOTH)
		nJogEnable = 3;

	if (pDeviceState->djControlSteel.eJogWheelsSensitivity==LESS)
		nJogSensitive = 1;
	else if (pDeviceState->djControlSteel.eJogWheelsSensitivity==LEAST)
		nJogSensitive = 2;

	pCombo = (CGComboBox *) GetControl(IDC_STEEL_COMBO_JOG_SENSITIV);
	pCombo->SetCurSel(nJogSensitive);
	pCombo = (CGComboBox *) GetControl(IDC_STEEL_COMBO_JOG_ENABLE);
	pCombo->SetCurSel(nJogEnable);
	pCombo = (CGComboBox *) GetControl(IDC_STEEL_COMBO_MIDI);
	pCombo->SetCurSel(pDeviceState->djControlSteel.nMidiChannel);

	pStatic = (CGStaticText *) GetControl(IDC_STEEL_STATIC_ABOUT3);
	sprintf(szText, "%s %s", g_LOCALIZATION.GetString(IDS_PACKAGE), INFO_PACKAGE_NAME);
	pStatic->SetLabel(szText);
	pStatic = (CGStaticText *) GetControl(IDC_STEEL_STATIC_ABOUT4);
	sprintf(szText, "%s 1.0.%d.%d", g_LOCALIZATION.GetString(IDS_FIRMWARE),
		(int) (pDeviceState->djControlSteel.lFirmwareVersion>>8)&0xFF,
		(int) (pDeviceState->djControlSteel.lFirmwareVersion>>0)&0xFF);
	pStatic->SetLabel(szText);
	pStatic = (CGStaticText *) GetControl(IDC_STEEL_STATIC_ABOUT5);
	sprintf(szText, "%s %d.%d.%d.%d", g_LOCALIZATION.GetString(IDS_DRIVER),
		ConvertBCDtoInt((int) (pDeviceState->ulBULK_Version>>24)&0xFF),
		ConvertBCDtoInt((int) (pDeviceState->ulBULK_Version>>16)&0xFF),
		ConvertBCDtoInt((int) (pDeviceState->ulBULK_Version>>8)&0xFF),
		ConvertBCDtoInt((int) (pDeviceState->ulBULK_Version>>0)&0xFF));
	pStatic->SetLabel(szText);
	
	pStatic = (CGStaticText *) GetControl(IDC_STEEL_STATIC_ABOUT6);
	sprintf(szText, "%s %s", g_LOCALIZATION.GetString(IDS_CONTROL_PANEL), INFO_CONTROL_PANEL);
	pStatic->SetLabel(szText);
	DEBUG_PRINT("CDevSteelDlg::InitializeDlgState completed.");
}



