/////////////////////////////////////////////////////////////////////////////
// Name:        gcheckbox.h
// Purpose:     GUI check box implementation using wxWidgets.
// Author:      Yann Hamiaux
// Modified by: -
// Created:     04/04/2008
// Copyright:   Written for Guillemot Corporation by Yann Hamiaux
// Licence:     The GNU General Public License v2+.
/////////////////////////////////////////////////////////////////////////////
#include "wx/wx.h"
#include "gcontrol.h"

#ifndef _GUILLEMOT_CHECKBOX_H_
#define _GUILLEMOT_CHECKBOX_H_

#define CHECKBOX_STATE_DISABLE		0
#define CHECKBOX_STATE_NORMAL		1
#define CHECKBOX_STATE_HIGHLIGHT	2
#define CHECKBOX_STATE_PRESSED		3

typedef struct CHECKBOX_COORDINATE
{
	int x, y;	// Image Coordinates.
	int r, g, b;	// Text Colors.
} CHECKBOX_COORDINATE, *PCHECKBOX_COORDINATE;

typedef struct CHECKBOX_STATE_INFO
{
	CHECKBOX_COORDINATE	coordinates[4];
	int nProcessAlpha;	// If 0 BitBlt without processing alpha. Otherwise, 
				// consider 0xFF00FF has transparent color.
} CHECKBOX_STATE_INFO, *PCHECKBOX_STATE_INFO;


class CGCheckBox : public CGControl
{
public:
	CGCheckBox( PEVENT_LIST pEventList, int nControlID, int nPosX, int nPosY, 
		int nImageSizeX, int nImageSizeY, const char *szLabel, int nWidth, int nHeight,
		wxMemoryDC *pSkinMemDC, wxMemoryDC *pSkinAlphaMemDC, int nStateCount, 
		PCHECKBOX_STATE_INFO pStateInfo, unsigned long ulAlign = ALIGN_LEFT|VALIGN_TOP );
	virtual ~CGCheckBox();

	void SetFontSize( int nSize );
	void SetFontAttributes( int nBold, int nItalic );
	void SetFontName( char *strFontName );  // Be sure the Font exist on the OS.
	int  GetLabel(char *szLabel);
	void SetLabel(char *szLabel);

	int  GetState();
	void SetState(int nState);
	bool MouseEvent( int x, int y, int button, bool *bMouseOverCtrl, 
			PREFRESH_RECT pRefreshRect );
	void Enable( bool bEnable );

	void Paint( wxDC *pDC, PREFRESH_RECT refreshRect );

protected:
	wxMemoryDC		*m_pSkinMemDC, *m_pSkinAlphaMemDC;
	int			 m_nStateCount;
	PCHECKBOX_STATE_INFO	 m_pStateInfo;
	int			 m_nCurrentState, m_nCurrentSubState;
	char			 m_szLabel[512];
	char			 m_szFontName[512];
	int			 m_nFontSize, m_nFontBold, m_nFontItalic;
	int			 m_nImageSizeX, m_nImageSizeY;
	unsigned long		 m_ulAlign;

private:
};

#endif
