/////////////////////////////////////////////////////////////////////////////
// Name:        gcombobox.cpp
// Purpose:     GUI Combo Box implementation using wxWidgets.
// Author:      Yann Hamiaux
// Modified by: -
// Created:     04/26/2008
// Copyright:   Written for Guillemot Corporation by Yann Hamiaux
// Licence:     The GNU General Public License v2+.
/////////////////////////////////////////////////////////////////////////////
#include "gcombobox.h"

CGComboBox::CGComboBox(PEVENT_LIST pEventList, int nControlID, int nPosX, int nPosY, 
		int nWidth, int nHeight, int nOpenHeight, wxMemoryDC *pSkinMemDC, 
		wxMemoryDC *pSkinAlphaMemDC, PCOMBO_INFO pComboInfo) :
	CGControl(pEventList, nControlID, GCONTROL_TYPE_COMBO_BOX, nPosX, nPosY, nWidth, nHeight)
{
	wxFont	fontBox(pComboInfo->nFontSizeBox, wxFONTFAMILY_DEFAULT, wxFONTSTYLE_NORMAL, wxFONTWEIGHT_NORMAL);
	wxFont	fontList(pComboInfo->nFontSizeList, wxFONTFAMILY_DEFAULT, wxFONTSTYLE_NORMAL, wxFONTWEIGHT_NORMAL);
	wxSize	wxTextSize;

	m_pSkinMemDC = pSkinMemDC;
	m_pSkinAlphaMemDC = pSkinAlphaMemDC;
	memcpy(&m_comboInfo, pComboInfo, sizeof(COMBO_INFO));
	m_bComboOpen = false;
	m_nElemCount = 0;
	m_nElemSelect = -1;
	m_nOpenHeight = nOpenHeight;
	m_pComboList = NULL;
	m_nComboBoxState = GCOMBO_BOX_NORMAL;
	m_nTopButtonState = 1;
	m_nBottomButtonState = 1;

	// --- To be Determine ---
	m_pSkinMemDC->SetFont(fontBox);
	wxTextSize = m_pSkinMemDC->GetTextExtent(FONT_HEIGHT_STRING);	// We use some chars to get Font Height.
	m_nTextHeightInBox = wxTextSize.GetHeight();
	m_pSkinMemDC->SetFont(fontList);
	wxTextSize = m_pSkinMemDC->GetTextExtent(FONT_HEIGHT_STRING);
	m_nTextHeightInList = wxTextSize.GetHeight();
	m_nStartPosInListBox = 0;

	m_nVisibleElemCount = (m_nOpenHeight-(m_comboInfo.borderList.t+m_comboInfo.borderList.b))/
							m_nTextHeightInList;
	m_bHScrollBar = false;

	m_nThumbZoneSize = m_nOpenHeight-m_comboInfo.sbutBottom[m_nBottomButtonState].h-
				m_comboInfo.sbutTop[m_nBottomButtonState].h - m_comboInfo.borderList.t-
				m_comboInfo.borderList.b;

	m_nScrollBarZoneWidth = (m_comboInfo.sbutBottom[1].w<m_comboInfo.sbutTop[1].w) ?
		m_comboInfo.sbutTop[1].w : m_comboInfo.sbutBottom[1].w;
	m_nScrollBarZoneWidth = (m_comboInfo.sbckMiddle.w<m_nScrollBarZoneWidth) ?
		m_nScrollBarZoneWidth : m_comboInfo.sbckMiddle.w;
	m_nScrollBarZoneWidth+= m_comboInfo.borderList.r;
}

CGComboBox::~CGComboBox(void)
{
	ResetContent();
}


// ---------------------------------------------------------------------------
// Function: CloseComboBox
//
// When the mouse cursor click outside of the combo box open area, the combo
// box should close and cancel the action made (ie. scrolling among the items)
// ---------------------------------------------------------------------------
void CGComboBox::CloseComboBox( void )
{
	m_bComboOpen = false;
	m_nStartPosInListBox = m_nStartPosInListBoxSaved;
}

// ---------------------------------------------------------------------------
// Function: GetControlRect
//
// When the mouse cursor click outside of the combo box open area, the combo
// box should close and cancel the action made (ie. scrolling among the items)
// ---------------------------------------------------------------------------
void CGComboBox::GetControlRect( int *nPosX, int *nPosY, int *nWidth, int *nHeight )
{
	CGControl::GetControlRect(nPosX, nPosY, nWidth, nHeight);
	*nHeight += m_nOpenHeight;
}


// ---------------------------------------------------------------------------
// Function: MouseEvent
//
// Process mouse events (button click, mouse over, ...) within the combo box.
// ---------------------------------------------------------------------------
bool CGComboBox::MouseEvent( int x, int y, int button, bool *bMouseOverCtrl, 
			PREFRESH_RECT pRefreshRect )
{
	int	nTemp;
	int nSaveTopBtnState, nSaveBottomBtnState;
	bool	bResult = false;
	static int s_nPrevButton = 0;

	if (bMouseOverCtrl==NULL) {
		s_nPrevButton = 0;
		return false;
	}

	*bMouseOverCtrl = false;
	if (m_bHide || m_nComboBoxState==GCOMBO_BOX_DISABLE) {
		s_nPrevButton = 0;
		return false;
	}

	CGControl::MouseEvent(x,y,button,bMouseOverCtrl,pRefreshRect);
	nSaveTopBtnState = m_nTopButtonState;
	nSaveBottomBtnState = m_nBottomButtonState;
	m_nTopButtonState = GCOMBO_BOX_NORMAL;
	m_nBottomButtonState = GCOMBO_BOX_NORMAL;

	if (*bMouseOverCtrl)
	{
		// Inside the control.
		if (button&GMOUSE_LEFT_DOWN) {
			if (m_nComboBoxState!=GCOMBO_BOX_PRESS) {
				m_nComboBoxState = GCOMBO_BOX_PRESS;
			}
		}
		else {
			if (m_nComboBoxState!=GCOMBO_BOX_HIGHLIGHT) {
				if (m_nComboBoxState==GCOMBO_BOX_PRESS) {
					m_bComboOpen = !m_bComboOpen;
					if (m_bComboOpen)
						m_nStartPosInListBoxSaved = m_nStartPosInListBox;
					else
						m_nStartPosInListBox = m_nStartPosInListBoxSaved;

					m_nMouseElemSelect = -1;
				}
				m_nComboBoxState = GCOMBO_BOX_HIGHLIGHT;
			}
		}
		bResult = true;
	}
	else if (m_bComboOpen && 
		x>=m_nPosX && 
		(((m_bHScrollBar) && x<=m_nPosX+m_nWidth-m_nScrollBarZoneWidth-1) ||
		((!m_bHScrollBar) && x<=m_nPosX+m_nWidth)) && 
		y>=m_nPosY+m_nHeight && y<=m_nPosY+m_nHeight+m_nOpenHeight)
	{
		*bMouseOverCtrl = true;

		// --- Cursor inside the listbox opened ---
		nTemp = m_nMouseElemSelect;
		m_nMouseElemSelect = y-m_nPosY-m_nHeight-m_comboInfo.borderList.t;
		m_nMouseElemSelect/= m_nTextHeightInList;
		if (m_nMouseElemSelect>m_nVisibleElemCount-1)
			m_nMouseElemSelect = m_nVisibleElemCount-1;
		m_nMouseElemSelect+= m_nStartPosInListBox;

		if (!(button&GMOUSE_LEFT_DOWN) && (s_nPrevButton&GMOUSE_LEFT_DOWN)) {
			m_nElemSelect = m_nMouseElemSelect;
			SetEvent(GEVENT_COMBO_CURSEL, m_nElemSelect, 0);
			m_bComboOpen = false;
		}
		else if (nTemp==m_nMouseElemSelect) {
			goto end_CB_MouseEvent;
		}

		bResult = true;
	}
	else if (m_bComboOpen && m_bHScrollBar && 
		y>=m_nPosY+m_nHeight+m_comboInfo.borderList.t && 
		y<=m_nPosY+m_nHeight+m_nOpenHeight-m_comboInfo.borderList.b &&
		x>=m_nPosX+m_nWidth-m_nScrollBarZoneWidth-1 && x<=m_nPosX+m_nWidth) 
	{
		*bMouseOverCtrl = true;
		// --- Inside the Scroll Zone Bar ---
		if (y<m_nPosY+m_nHeight+m_comboInfo.borderList.t+m_comboInfo.sbutTop[1].h) {
			// --- Scroll Up Button ---
			m_nTopButtonState = (button&GMOUSE_LEFT_DOWN) ? GCOMBO_BOX_PRESS : GCOMBO_BOX_HIGHLIGHT;
			if (!(button&GMOUSE_LEFT_DOWN) && (s_nPrevButton&GMOUSE_LEFT_DOWN)) {
				if (m_nStartPosInListBox>0) {
					m_nStartPosInListBox = m_nStartPosInListBox-1;
					bResult = true;
				}
				if (m_nMouseElemSelect>0) {
					m_nMouseElemSelect = m_nMouseElemSelect -1;
					bResult = true;
				}
			}
		}
		else if (y>m_nPosY+m_nHeight+m_nOpenHeight-m_comboInfo.sbutBottom[1].h-m_comboInfo.borderList.b) {
			// --- Scroll Down Button ---
			m_nBottomButtonState = (button&GMOUSE_LEFT_DOWN) ? GCOMBO_BOX_PRESS : GCOMBO_BOX_HIGHLIGHT;
			if (!(button&GMOUSE_LEFT_DOWN) && (s_nPrevButton&GMOUSE_LEFT_DOWN)) {
				if (m_nStartPosInListBox<m_nElemCount-m_nVisibleElemCount) {
					m_nStartPosInListBox = m_nStartPosInListBox+1;
					bResult = true;
				}
				if (m_nMouseElemSelect<m_nElemCount-1) {
					m_nMouseElemSelect = m_nMouseElemSelect +1;
					bResult = true;
				}
			}
		}
		else
		{
			// --- Scroll Zone ---
			if (button&GMOUSE_LEFT_DOWN) {
				nTemp = m_nStartPosInListBox;
				m_nStartPosInListBox = (m_nElemCount-m_nVisibleElemCount+1) *
					(y-(m_nPosY+m_nHeight+m_comboInfo.borderList.t+m_comboInfo.sbutTop[1].h)) / 
					m_nThumbZoneSize;
				if (m_nStartPosInListBox<0)
					m_nStartPosInListBox = 0;
				if (m_nStartPosInListBox>m_nElemCount-m_nVisibleElemCount)
					m_nStartPosInListBox = m_nElemCount-m_nVisibleElemCount;
				if (nTemp!=m_nStartPosInListBox)
					bResult = true;
			}
		}
	}
	else
	{
		// Outside the control.
		if (m_nComboBoxState!=GCOMBO_BOX_NORMAL) {
			m_nComboBoxState = GCOMBO_BOX_NORMAL;
			bResult = true;
		}
	}

end_CB_MouseEvent:
	s_nPrevButton = button;
	if (m_nTopButtonState!=nSaveTopBtnState || m_nBottomButtonState!=nSaveBottomBtnState)
		return true;

	return bResult;
}

// ---------------------------------------------------------------------------
// Function: Enable
// ---------------------------------------------------------------------------
void CGComboBox::Enable( bool bEnable )
{
	m_nComboBoxState = (bEnable) ? GCOMBO_BOX_NORMAL : GCOMBO_BOX_DISABLE;
}

// ---------------------------------------------------------------------------
// Function: ResetContent
//
// Clear all elements from the combo box list.
// ---------------------------------------------------------------------------
void CGComboBox::ResetContent( void )
{
	PCOMBO_ELEM	pItem;

	while(m_pComboList!=NULL) {
		pItem = m_pComboList;
		m_pComboList = m_pComboList->pNext;
		delete pItem;
	}
	m_nElemCount = 0;
	m_nElemSelect = -1;
	m_bHScrollBar = false;
}

// ---------------------------------------------------------------------------
// Function: AddString
//
// Add a string element in the combobox list (elements are not sorted).
// ---------------------------------------------------------------------------
void CGComboBox::AddString( const char *szString )
{
	PCOMBO_ELEM	pNewItem, pCurItem;
	pNewItem = new COMBO_ELEM;
	memset(pNewItem, 0, sizeof(COMBO_ELEM));
	strcpy(pNewItem->szComboName, szString);
	pNewItem->pNext = NULL;
	if (m_pComboList==NULL)
		m_pComboList = pNewItem;
	else {
		pCurItem = m_pComboList;
		while(pCurItem->pNext!=NULL)
			pCurItem = pCurItem->pNext;
		pCurItem->pNext = pNewItem;
	}
	++m_nElemCount;
	if (m_nElemCount>m_nVisibleElemCount)
		m_bHScrollBar = true;
}

// ---------------------------------------------------------------------------
// Function: SetCurSel
// ---------------------------------------------------------------------------
void CGComboBox::SetCurSel( int nCurSel )
{
	if (nCurSel>=0 && nCurSel<m_nElemCount)
		m_nElemSelect = nCurSel;
}

// ---------------------------------------------------------------------------
// Function: GetCurSel
// ---------------------------------------------------------------------------
int CGComboBox::GetCurSel( void )
{
	return m_nElemSelect;
}

// ---------------------------------------------------------------------------
// Function: GetComboSize
// ---------------------------------------------------------------------------
int CGComboBox::GetComboSize( void )
{
	return m_nElemCount;
}

// ---------------------------------------------------------------------------
// Function: IsComboOpen
// ---------------------------------------------------------------------------
bool CGComboBox::IsComboOpen( void )
{
	return m_bComboOpen;
}

// ---------------------------------------------------------------------------
// Function: Paint
//
// Paint the combo box, this include the window that contain the list of all
// elements where the user can select a new item (when the combobox is open).
// ---------------------------------------------------------------------------
void CGComboBox::Paint( wxDC *pDC, PREFRESH_RECT refreshRect )
{
	PCOMBO_ELEM pCurComboElem;
	wxFont	fontBox(m_comboInfo.nFontSizeBox, wxFONTFAMILY_DEFAULT, wxFONTSTYLE_NORMAL, wxFONTWEIGHT_NORMAL);
	wxFont	fontList(m_comboInfo.nFontSizeList, wxFONTFAMILY_DEFAULT, wxFONTSTYLE_NORMAL, wxFONTWEIGHT_NORMAL);
	wxColor foregrndColor(m_comboInfo.colorFont.r, 
			m_comboInfo.colorFont.g, m_comboInfo.colorFont.b, wxALPHA_OPAQUE);
	wxColor HLforegrndColor(m_comboInfo.HighlightForegrndColor.r, 
			m_comboInfo.HighlightForegrndColor.g, m_comboInfo.HighlightForegrndColor.b, wxALPHA_OPAQUE);
	wxColor HLbackgrndColor(m_comboInfo.HighlightBckgrndColor.r, 
			m_comboInfo.HighlightBckgrndColor.g, m_comboInfo.HighlightBckgrndColor.b, wxALPHA_OPAQUE);
	wxPen	nullPen(HLbackgrndColor, 0, wxTRANSPARENT);
	wxBrush HLBrush(HLbackgrndColor);
	int	i, j;
	int	nPosY;
	int	nScrollBarLeftPos, nScrollThumbLeftPos;
	int	nThumbSize, nThumbPos, nAdjust;
	int	nElemPos;
	int	nScrollBarSize;

	if (m_bHide || pDC==NULL || m_pSkinMemDC==NULL)
		return;

	// --- If button is outside of the region, do not refresh it ---
	if (refreshRect->x>m_nPosX+m_nWidth || refreshRect->x+refreshRect->w<m_nPosX)
		return;

	if (refreshRect->y>m_nPosY+m_nHeight+m_nOpenHeight || refreshRect->y+refreshRect->h<m_nPosY)
		return;

	// --- Draw Combo Box ---
	pDC->Blit(m_nPosX, m_nPosY, m_nWidth, m_nHeight, m_pSkinMemDC, 
		m_comboInfo.box[m_nComboBoxState].x, m_comboInfo.box[m_nComboBoxState].y, wxCOPY);

	pCurComboElem = m_pComboList;
	i = 0;
	while(pCurComboElem!=NULL && i<m_nElemSelect) {
		pCurComboElem = pCurComboElem->pNext;
		++i;
	}
	pDC->SetFont(fontBox);
	pDC->SetTextForeground(foregrndColor);
	pDC->DrawText((pCurComboElem==NULL) ? "" : pCurComboElem->szComboName, 
		m_nPosX + m_comboInfo.nBoxLeftSpace, m_nPosY + (m_nHeight - m_nTextHeightInBox)/2);


	// --- Draw Combo List ---
	if (m_bComboOpen) 
	{
		nScrollBarLeftPos = m_nPosX+m_nWidth-m_nScrollBarZoneWidth;
		nScrollThumbLeftPos = nScrollBarLeftPos + (m_comboInfo.sbckMiddle.w - m_comboInfo.stmbMiddle.w)/2;

		if (m_nMouseElemSelect<0)
			m_nMouseElemSelect = m_nElemSelect;

		// --- Background Combo Box ---
		pDC->Blit(m_nPosX, m_nPosY+m_nHeight, m_nWidth, m_nOpenHeight, m_pSkinMemDC, 
			m_comboInfo.list.x, m_comboInfo.list.y, wxCOPY);

		pCurComboElem = m_pComboList;
		j = 0;
		while(pCurComboElem!=NULL && j<m_nStartPosInListBox) {
			pCurComboElem = pCurComboElem->pNext;
			++j;
		}
		nElemPos = j;

		pDC->SetPen(nullPen);
		pDC->SetBrush(HLBrush);
		pDC->SetFont(fontList);

		for(i=0;i<m_nVisibleElemCount;++i) {
			if (i+nElemPos==m_nMouseElemSelect) {
				pDC->SetTextForeground(HLforegrndColor);
				if (m_bHScrollBar)
					pDC->DrawRectangle(m_nPosX + m_comboInfo.borderList.l,
						m_nPosY + m_nHeight + m_comboInfo.borderList.t + i*m_nTextHeightInList,
						m_nWidth - m_comboInfo.borderList.l - m_nScrollBarZoneWidth-1,
						m_nTextHeightInList);
				else
					pDC->DrawRectangle(m_nPosX + m_comboInfo.borderList.l,
						m_nPosY + m_nHeight + m_comboInfo.borderList.t + i*m_nTextHeightInList,
						m_nWidth - m_comboInfo.borderList.l - m_comboInfo.borderList.r,
						m_nTextHeightInList);
			}
			else
				pDC->SetTextForeground(foregrndColor);

			pDC->DrawText((pCurComboElem==NULL) ? "" : pCurComboElem->szComboName, 
				m_nPosX + m_comboInfo.borderList.l + 2, m_nPosY + m_nHeight + 
				m_comboInfo.borderList.t + i *m_nTextHeightInList);
			if (pCurComboElem!=NULL) pCurComboElem = pCurComboElem->pNext;
		}

		if (m_bHScrollBar) 
		{
			// --- Button Combo Box Scroll Up ---
			nPosY = m_nPosY+m_nHeight+m_comboInfo.borderList.t;
			pDC->Blit(nScrollBarLeftPos, nPosY, 
				m_comboInfo.sbutTop[m_nTopButtonState].w, 
				m_comboInfo.sbutTop[m_nTopButtonState].h, m_pSkinAlphaMemDC, 
				m_comboInfo.sbutTop[m_nTopButtonState].x, 
				m_comboInfo.sbutTop[m_nTopButtonState].y, wxAND);
			pDC->Blit(nScrollBarLeftPos, nPosY, 
				m_comboInfo.sbutTop[m_nTopButtonState].w, 
				m_comboInfo.sbutTop[m_nTopButtonState].h, m_pSkinMemDC, 
				m_comboInfo.sbutTop[m_nTopButtonState].x, m_comboInfo.sbutTop[m_nTopButtonState].y, wxOR);

			// --- Top ComboBox Background ---
			nPosY += m_comboInfo.sbutTop[m_nTopButtonState].h;
			pDC->Blit(nScrollBarLeftPos, nPosY, 
				m_comboInfo.sbckTop.w, 
				m_comboInfo.sbckTop.h, m_pSkinAlphaMemDC, 
				m_comboInfo.sbckTop.x, 
				m_comboInfo.sbckTop.y, wxAND);
			pDC->Blit(nScrollBarLeftPos, nPosY,
				m_comboInfo.sbckTop.w, 
				m_comboInfo.sbckTop.h, m_pSkinMemDC, 
				m_comboInfo.sbckTop.x, 
				m_comboInfo.sbckTop.y, wxOR);

			// --- Middle ComboBox Background ---
			nScrollBarSize = m_nOpenHeight-(m_comboInfo.borderList.t+m_comboInfo.borderList.b+
				m_comboInfo.sbutTop[m_nTopButtonState].h+m_comboInfo.sbutBottom[m_nBottomButtonState].h+
				m_comboInfo.sbckTop.h+m_comboInfo.sbckBottom.h);

			nPosY += m_comboInfo.sbckTop.h;
			for(i=0;i<nScrollBarSize-m_comboInfo.sbckMiddle.h;i+=m_comboInfo.sbckMiddle.h) {
				pDC->Blit(nScrollBarLeftPos, nPosY, 
					m_comboInfo.sbckMiddle.w, 
					m_comboInfo.sbckMiddle.h, m_pSkinAlphaMemDC, 
					m_comboInfo.sbckMiddle.x, 
					m_comboInfo.sbckMiddle.y, wxAND);
				pDC->Blit(nScrollBarLeftPos, nPosY, 
					m_comboInfo.sbckMiddle.w, 
					m_comboInfo.sbckMiddle.h, m_pSkinMemDC, 
					m_comboInfo.sbckMiddle.x, 
					m_comboInfo.sbckMiddle.y, wxOR);
				nPosY+=m_comboInfo.sbckMiddle.h;
			}
			pDC->Blit(nScrollBarLeftPos, nPosY, 
				m_comboInfo.sbckMiddle.w, 
				nScrollBarSize-i, m_pSkinAlphaMemDC, 
				m_comboInfo.sbckMiddle.x, 
				m_comboInfo.sbckMiddle.y, wxAND);
			pDC->Blit(nScrollBarLeftPos, nPosY,
				m_comboInfo.sbckMiddle.w, 
				nScrollBarSize-i, m_pSkinMemDC, 
				m_comboInfo.sbckMiddle.x, 
				m_comboInfo.sbckMiddle.y, wxOR);

			// --- Bottom ComboBox Background ---
			nPosY+=nScrollBarSize-i;
			pDC->Blit(nScrollBarLeftPos, nPosY, 
				m_comboInfo.sbckBottom.w, 
				m_comboInfo.sbckBottom.h, m_pSkinAlphaMemDC, 
				m_comboInfo.sbckBottom.x, 
				m_comboInfo.sbckBottom.y, wxAND);
			pDC->Blit(nScrollBarLeftPos, nPosY,
				m_comboInfo.sbckBottom.w, 
				m_comboInfo.sbckBottom.h, m_pSkinMemDC, 
				m_comboInfo.sbckBottom.x, 
				m_comboInfo.sbckBottom.y, wxOR);


			// --- Button Combo Box Scroll Down ---
			nPosY+=m_comboInfo.sbckBottom.h;
			pDC->Blit(nScrollBarLeftPos, nPosY, 
				m_comboInfo.sbutBottom[m_nBottomButtonState].w, 
				m_comboInfo.sbutBottom[m_nBottomButtonState].h, m_pSkinAlphaMemDC, 
				m_comboInfo.sbutBottom[m_nBottomButtonState].x, 
				m_comboInfo.sbutBottom[m_nBottomButtonState].y, wxAND);
			pDC->Blit(nScrollBarLeftPos, nPosY, 
				m_comboInfo.sbutBottom[m_nBottomButtonState].w, 
				m_comboInfo.sbutBottom[m_nBottomButtonState].h, m_pSkinMemDC, 
				m_comboInfo.sbutBottom[m_nBottomButtonState].x, 
				m_comboInfo.sbutBottom[m_nBottomButtonState].y, wxOR);

			// --- Scroll Thumb ---
			nThumbSize = m_nVisibleElemCount * m_nThumbZoneSize / m_nElemCount;
			nAdjust = 0;

			if (nThumbSize<m_comboInfo.stmbTop.h+m_comboInfo.stmbBottom.h) {
				nAdjust = m_comboInfo.stmbTop.h+m_comboInfo.stmbBottom.h-nThumbSize;
				nThumbSize = m_comboInfo.stmbTop.h+m_comboInfo.stmbBottom.h;
			}
			nThumbPos = nElemPos * (m_nThumbZoneSize-nAdjust) / m_nElemCount;

			// --- Top Scroll Thumb ---
			nPosY = nThumbPos+m_nPosY + m_nHeight + m_comboInfo.sbutTop[m_nBottomButtonState].h+m_comboInfo.borderList.t;
			pDC->Blit(nScrollThumbLeftPos, nPosY, 
				m_comboInfo.stmbTop.w, m_comboInfo.stmbTop.h, m_pSkinAlphaMemDC, 
				m_comboInfo.stmbTop.x, m_comboInfo.stmbTop.y, wxAND);
			pDC->Blit(nScrollThumbLeftPos, nPosY,
				m_comboInfo.stmbTop.w, m_comboInfo.stmbTop.h, m_pSkinMemDC, 
				m_comboInfo.stmbTop.x, m_comboInfo.stmbTop.y, wxOR);

			// --- Middle Scroll Thumb ---
			nPosY+=m_comboInfo.stmbTop.h;
			for(i=m_comboInfo.stmbTop.h;i<nThumbSize-m_comboInfo.stmbBottom.h-m_comboInfo.stmbMiddle.h;i+=m_comboInfo.stmbMiddle.h)
			{
				pDC->Blit(nScrollThumbLeftPos, nPosY, 
					m_comboInfo.stmbMiddle.w, m_comboInfo.stmbMiddle.h, m_pSkinAlphaMemDC, 
					m_comboInfo.stmbMiddle.x, m_comboInfo.stmbMiddle.y, wxAND);
				pDC->Blit(nScrollThumbLeftPos, nPosY, 
					m_comboInfo.stmbMiddle.w, m_comboInfo.stmbMiddle.h, m_pSkinMemDC, 
					m_comboInfo.stmbMiddle.x, m_comboInfo.stmbMiddle.y, wxOR);
				nPosY += m_comboInfo.stmbMiddle.h;
			}

			if (nThumbSize-m_comboInfo.stmbBottom.h-i>0) {
				pDC->Blit(nScrollThumbLeftPos, nPosY, 
					m_comboInfo.stmbMiddle.w, nThumbSize-m_comboInfo.stmbBottom.h-i, m_pSkinAlphaMemDC, 
					m_comboInfo.stmbMiddle.x, m_comboInfo.stmbMiddle.y, wxAND);
				pDC->Blit(nScrollThumbLeftPos, nPosY,
					m_comboInfo.stmbMiddle.w, nThumbSize-m_comboInfo.stmbBottom.h-i, m_pSkinMemDC, 
					m_comboInfo.stmbMiddle.x, m_comboInfo.stmbMiddle.y, wxOR);
				nPosY+=nThumbSize-m_comboInfo.stmbBottom.h-i;
			}

			// --- Bottom Scroll Thumb ---
			pDC->Blit(nScrollThumbLeftPos, nPosY,
				m_comboInfo.stmbBottom.w, m_comboInfo.stmbBottom.h, m_pSkinAlphaMemDC, 
				m_comboInfo.stmbBottom.x, m_comboInfo.stmbBottom.y, wxAND);
			pDC->Blit(nScrollThumbLeftPos, nPosY,
				m_comboInfo.stmbBottom.w, m_comboInfo.stmbBottom.h, m_pSkinMemDC, 
				m_comboInfo.stmbBottom.x, m_comboInfo.stmbBottom.y, wxOR);
		}
	}
}


