/////////////////////////////////////////////////////////////////////////////
// Name:        gcontrol.h
// Purpose:     GUI base control implementation using wxWidgets.
// Author:      Yann Hamiaux
// Modified by: -
// Created:     02/25/2008
// Copyright:   Written for Guillemot Corporation by Yann Hamiaux
// Licence:     The GNU General Public License v2+.
/////////////////////////////////////////////////////////////////////////////
#include "wx/wx.h" 

#ifndef _GUILLEMOT_CONTROL_H_
#define _GUILLEMOT_CONTROL_H_

#define GCONTROL_TYPE_STATIC_TEXT	0
#define GCONTROL_TYPE_STATIC_IMAGE	1
#define GCONTROL_TYPE_BUTTON		2
#define GCONTROL_TYPE_CHECK_BOX		3
#define GCONTROL_TYPE_SLIDER		4
#define GCONTROL_TYPE_COMBO_BOX		5

#define GMOUSE_LEFT_DOWN		0x01
#define GMOUSE_RIGHT_DOWN		0x02
#define GMOUSE_LEFT_DCLICK		0x10

#define MAX_EVENT_ITEM_COUNT		512

#define GEVENT_BTN_CHANGE		1
#define GEVENT_SLIDER_MOVE		2
#define GEVENT_SLIDER_CLICK		3
#define GEVENT_SLIDER_DCLICK		4
#define GEVENT_COMBO_CURSEL		5

#define ALIGN_LEFT			0
#define ALIGN_CENTER			1
#define ALIGN_RIGHT			2
#define VALIGN_TOP			(0<<2)
#define VALIGN_CENTER			(1<<2)
#define VALIGN_BOTTOM			(2<<2)
#define ALIGN_MASK			3
#define VALIGN_MASK			(3<<2)

#define MAX_TOOLTIPS_LENGTH		1024
#define FONT_HEIGHT_STRING		"WQ8/qjTXI"	// String with various character to determine font height.

typedef struct EVENT_MSG {
	int		nControlID;
	int		nMsg;
	unsigned long	ulParam1;
	unsigned long	ulParam2;
} EVENT_MSG, *PEVENT_MSG;

typedef struct EVENT_LIST {
	int		nMaxCount;
	int		nIndexRead;
	int		nIndexWrite;
	PEVENT_MSG	pEventList;
} EVENT_LIST, *PEVENT_LIST;

typedef struct REFRESH_RECT {
	int		x, y;
	int		w, h;
} REFRESH_RECT, *PREFRESH_RECT;

class CGControl
{
public:
	CGControl( PEVENT_LIST pEventList, int nControlID, int nType, int nPosX, int nPosY, 
				int nWidth, int nHeight );
	virtual ~CGControl();

	virtual void GetControlRect( int *nPosX, int *nPosY, int *nWidth, int *nHeight );
	virtual bool MouseEvent( int x, int y, int button, bool *bMouseOverCtrl, 
				PREFRESH_RECT pRefreshRect );
	virtual void Enable( bool bEnable );
	virtual void Hide( bool bHide );

	bool IsEnable( void );
	bool IsHide( void );
	int  GetControlID( void ) { return m_nControlID; }
	int  GetType();
	void SetPos(int nPosX, int nPosY);
	void SetSize(int nWidth, int nHeight);

	void AddToolTips( const char *szText, int nWidth = -1, unsigned long ulDelayShow = 0,
			unsigned long ulDelayHide = 0 );
	void GetToolTips( char *szText, int *nWidth, unsigned long *ulDelayShow, 
			unsigned long *ulDelayHide );

	// --- Pure Virtual Functions ---
	virtual void Paint( wxDC *pDC, PREFRESH_RECT refreshRect ) = 0;


protected:
	bool SetEvent( int nMsg, unsigned long ulParam1, unsigned long ulParam2 );

	PEVENT_LIST	m_pEventList;
	int		m_nControlID;
	int		m_nType, m_nPosX, m_nPosY, m_nWidth, m_nHeight;
	bool		m_bEnable, m_bHide;

	char		m_szTTText[MAX_TOOLTIPS_LENGTH];
	int		m_nTTWidth;
	unsigned long	m_ulTTDelayShow, m_ulTTDelayHide;

private:
};

#endif

