/////////////////////////////////////////////////////////////////////////////
// Name:        gdialog.cpp
// Purpose:     GUI base Dialog implementation using wxWidgets.
// Author:      Yann Hamiaux
// Modified by: -
// Created:     02/15/2008
// Copyright:   Written for Guillemot Corporation by Yann Hamiaux
// Licence:     The GNU General Public License v2+.
/////////////////////////////////////////////////////////////////////////////
#include "gdialog.h"


// --- Constructor and Destructor ---
CGDialog::CGDialog( wxMemoryDC *pSkinMemDC, wxMemoryDC *pSkinAlphaMemDC, int nWidth, int nHeight )
{
	m_pDManager = NULL;
	m_pSkinMemDC = pSkinMemDC;
	m_pSkinAlphaMemDC = pSkinAlphaMemDC;
	m_nWidth = nWidth;
	m_nHeight = nHeight;

	m_memDCBitmap.Create(m_nWidth, m_nHeight);
	m_memDC.SelectObject(m_memDCBitmap);
	m_nTab = 0;

	m_eventList.nMaxCount = MAX_EVENT_ITEM_COUNT;
	m_eventList.nIndexRead = 0;
	m_eventList.nIndexWrite = 0;
	m_eventList.pEventList = new EVENT_MSG[MAX_EVENT_ITEM_COUNT];

	m_nToolTipsWidth = nWidth/2-5;
	m_nTTPosX = 0;
	m_nTTPosY = 0;
	m_pTTCtrl = NULL;
	m_ulTTTimeStart = 0;
	m_ulTTDelayShow = 500;
	m_ulTTDelayHide = m_ulTTDelayShow + 3000;
	m_nToolTipsEventDelay = 0;
	m_pCtrlLstHead = NULL;
	m_pComboLstHead = NULL;
}

CGDialog::~CGDialog()
{
	PCONTROL_LIST	pCtrlListItem;

	while(m_pCtrlLstHead!=NULL) {
		pCtrlListItem = m_pCtrlLstHead;
		m_pCtrlLstHead = m_pCtrlLstHead->pNext;
		if (pCtrlListItem->pControl!=NULL)
			delete pCtrlListItem->pControl;
		delete pCtrlListItem;
	}

	while(m_pComboLstHead!=NULL) {
		pCtrlListItem = m_pComboLstHead;
		m_pComboLstHead = m_pComboLstHead->pNext;
		delete pCtrlListItem;
	}

	if (m_eventList.pEventList!=NULL)
		delete m_eventList.pEventList;
	m_eventList.pEventList = NULL;

}

// ---------------------------------------------------------------------------
// Function: AddControl
//
// We maintain a list of all controls which belong to the dialog box. This
// allow us to manage them within this base class in which every device
// dialog box will derive from.
// ---------------------------------------------------------------------------
bool CGDialog::AddControl( CGControl *pCtrl )
{
	PCONTROL_LIST	pCtrlLstElem, pLstItem;


	if (pCtrl==NULL) return false;
	pCtrlLstElem = new CONTROL_LIST;
	pCtrlLstElem->pControl = pCtrl;
	pCtrlLstElem->pNext = NULL;

	if (m_pCtrlLstHead==NULL)
		m_pCtrlLstHead = pCtrlLstElem;
	else
	{
		pLstItem = m_pCtrlLstHead;
		while(pLstItem->pNext!=NULL) {
			pLstItem = pLstItem->pNext;
		}
		pLstItem->pNext = pCtrlLstElem;
	}

	// --- If control is a combo box, then add into a specific list ---
	if (pCtrl->GetType()==GCONTROL_TYPE_COMBO_BOX) {
		pCtrlLstElem = new CONTROL_LIST;
		pCtrlLstElem->pControl = pCtrl;
		pCtrlLstElem->pNext = NULL;

		if (m_pComboLstHead==NULL)
			m_pComboLstHead = pCtrlLstElem;
		else
		{
			pLstItem = m_pComboLstHead;
			while(pLstItem->pNext!=NULL) {
				pLstItem = pLstItem->pNext;
			}
			pLstItem->pNext = pCtrlLstElem;
		}
	}

	return true;
}

// ---------------------------------------------------------------------------
// Function: MouseEvent
//
// Process mouse events for all controls available on the dialog box.
// ---------------------------------------------------------------------------
bool CGDialog::MouseEvent( int x, int y, int button, PREFRESH_RECT refreshRect )
{
	PCONTROL_LIST	 pLstItem;
	bool		 bNeedRefresh = false, bCtrlNeedRefresh;
	bool		 bInsideCtrl;
	bool		 bDetectOutTTCtrl = false;
	unsigned long	 ulDelayShow, ulDelayHide;
	int		 nWidth;
	char		 szText[MAX_TOOLTIPS_LENGTH];
	static int	 s_nAllowCloseCombo = 0;
	unsigned long	 ulCurTime;
	REFRESH_RECT	 ctrlRect;
	CGComboBox	*pComboBox;

	memset(refreshRect, 0, sizeof(REFRESH_RECT));
	wxDateTime now = wxDateTime::UNow();
	ulCurTime = now.GetMillisecond();
	ulCurTime+=now.GetSecond()*1000;
	ulCurTime+=now.GetMinute()*1000*60;
	ulCurTime+=now.GetHour()*1000*60*60;
	ulCurTime+=now.GetDayOfYear()*1000*60*60*24;

	if (m_ulTTTimeStart+m_ulTTDelayShow>ulCurTime) {
		m_ulTTTimeStart = ulCurTime;
		m_pTTCtrl = NULL;
		m_nToolTipsEventDelay = 0;
	}

	pLstItem = m_pComboLstHead;
	while(pLstItem!=NULL) {
		pComboBox = (CGComboBox *) pLstItem->pControl;
		if (pComboBox->IsComboOpen()) {
			bCtrlNeedRefresh =  pLstItem->pControl->MouseEvent(x,y,button,&bInsideCtrl, refreshRect);
			if (bCtrlNeedRefresh) {
				pLstItem->pControl->GetControlRect(&ctrlRect.x, &ctrlRect.y, &ctrlRect.w, &ctrlRect.h);
				if (refreshRect->w==0 || refreshRect->h==0) {
					refreshRect->x = ctrlRect.x;
					refreshRect->y = ctrlRect.y;
					refreshRect->w = ctrlRect.w;
					refreshRect->h = ctrlRect.h;
				}
				else
				{
					if (refreshRect->x>ctrlRect.x) {
						refreshRect->w = ctrlRect.x-refreshRect->x;
						refreshRect->x = ctrlRect.x;
					}
					if (refreshRect->y>ctrlRect.y) {
						refreshRect->h = ctrlRect.y-refreshRect->y;
						refreshRect->y = ctrlRect.y;
					}

					if (refreshRect->x+refreshRect->w<ctrlRect.x+ctrlRect.w)
						refreshRect->w = ctrlRect.x+ctrlRect.w-refreshRect->x;
					if (refreshRect->y+refreshRect->h<ctrlRect.y+ctrlRect.h)
						refreshRect->h = ctrlRect.y+ctrlRect.h-refreshRect->y;
				}
			}
			bNeedRefresh = bCtrlNeedRefresh;
			if (!bInsideCtrl) {
				if (s_nAllowCloseCombo==2 && !(button&GMOUSE_LEFT_DOWN)) {
					pComboBox->CloseComboBox();
					s_nAllowCloseCombo = 0;
					return true;
				}
				else if (s_nAllowCloseCombo<2 && !(button&GMOUSE_LEFT_DOWN))
					s_nAllowCloseCombo = 1;
				else if (s_nAllowCloseCombo>0 && (button&GMOUSE_LEFT_DOWN))
					s_nAllowCloseCombo = 2;
			}

			return bNeedRefresh;
		}
		pLstItem = pLstItem->pNext;
	}

	s_nAllowCloseCombo = 0;
	pLstItem = m_pCtrlLstHead;
	while(pLstItem!=NULL) {
		bInsideCtrl = false;
		bCtrlNeedRefresh = pLstItem->pControl->MouseEvent(x,y,button,&bInsideCtrl, refreshRect);
		pLstItem->pControl->GetControlRect(&ctrlRect.x, &ctrlRect.y, &ctrlRect.w, &ctrlRect.h);
		if (bCtrlNeedRefresh) {
			if (refreshRect->w==0 || refreshRect->h==0) {
				refreshRect->x = ctrlRect.x;
				refreshRect->y = ctrlRect.y;
				refreshRect->w = ctrlRect.w;
				refreshRect->h = ctrlRect.h;
			}
			else
			{
				if (refreshRect->x>ctrlRect.x) {
					refreshRect->w = ctrlRect.x-refreshRect->x;
					refreshRect->x = ctrlRect.x;
				}
				if (refreshRect->y>ctrlRect.y) {
					refreshRect->h = ctrlRect.y-refreshRect->y;
					refreshRect->y = ctrlRect.y;
				}

				if (refreshRect->x+refreshRect->w<ctrlRect.x+ctrlRect.w)
					refreshRect->w = ctrlRect.x+ctrlRect.w-refreshRect->x;
				if (refreshRect->y+refreshRect->h<ctrlRect.y+ctrlRect.h)
					refreshRect->h = ctrlRect.y+ctrlRect.h-refreshRect->y;
			}
		}
		else if (refreshRect->w!=0 && refreshRect->h!=0)
		{
			// --- Check if the control touch to the zone, if so adjust the zone to include this control ---
			if (
				(ctrlRect.x>refreshRect->x && ctrlRect.x<refreshRect->x+refreshRect->w) ||
				(ctrlRect.x+ctrlRect.w>refreshRect->x && ctrlRect.x+ctrlRect.w<refreshRect->x+refreshRect->w) ||
				(ctrlRect.y>refreshRect->y && ctrlRect.y<refreshRect->y+refreshRect->h) ||
				(ctrlRect.y+ctrlRect.h>refreshRect->y && ctrlRect.y+ctrlRect.h<refreshRect->y+refreshRect->h))
			{
				if (refreshRect->x>ctrlRect.x) {
					refreshRect->w = ctrlRect.x-refreshRect->x;
					refreshRect->x = ctrlRect.x;
				}
				if (refreshRect->y>ctrlRect.y) {
					refreshRect->h = ctrlRect.y-refreshRect->y;
					refreshRect->y = ctrlRect.y;
				}

				if (refreshRect->x+refreshRect->w<ctrlRect.x+ctrlRect.w)
					refreshRect->w = ctrlRect.x+ctrlRect.w-refreshRect->x;
				if (refreshRect->y+refreshRect->h<ctrlRect.y+ctrlRect.h)
					refreshRect->h = ctrlRect.y+ctrlRect.h-refreshRect->y;
			}
		}

		bNeedRefresh |= bCtrlNeedRefresh;
		if (bInsideCtrl) {
			if (m_pTTCtrl==NULL || m_ulTTTimeStart+m_ulTTDelayHide<ulCurTime) {
				pLstItem->pControl->GetToolTips(szText, &nWidth, &ulDelayShow, &ulDelayHide);
				if (strlen(szText)>0)
				{
					m_pTTCtrl = pLstItem->pControl;
					m_ulTTTimeStart = ulCurTime;
					m_nToolTipsEventDelay = m_ulTTDelayShow;
					m_nTTPosX = x; m_nTTPosY = y;
					bNeedRefresh = true;
				}
			}
		}
		else if (m_pTTCtrl==pLstItem->pControl)
			bDetectOutTTCtrl = true;
		pLstItem = pLstItem->pNext;
	}

	pLstItem = m_pCtrlLstHead;
	if (refreshRect->w!=0 && refreshRect->h!=0)
	{
		while(pLstItem!=NULL) {
			pLstItem->pControl->GetControlRect(&ctrlRect.x, &ctrlRect.y, &ctrlRect.w, &ctrlRect.h);
			// --- Check if the control touch to the zone, if so adjust the zone to include this control ---
			if (
				(ctrlRect.x>refreshRect->x && ctrlRect.x<refreshRect->x+refreshRect->w) ||
				(ctrlRect.x+ctrlRect.w>refreshRect->x && ctrlRect.x+ctrlRect.w<refreshRect->x+refreshRect->w) ||
				(ctrlRect.y>refreshRect->y && ctrlRect.y<refreshRect->y+refreshRect->h) ||
				(ctrlRect.y+ctrlRect.h>refreshRect->y && ctrlRect.y+ctrlRect.h<refreshRect->y+refreshRect->h))
			{
				if (refreshRect->x>ctrlRect.x) {
					refreshRect->w = ctrlRect.x-refreshRect->x;
					refreshRect->x = ctrlRect.x;
				}
				if (refreshRect->y>ctrlRect.y) {
					refreshRect->h = ctrlRect.y-refreshRect->y;
					refreshRect->y = ctrlRect.y;
				}

				if (refreshRect->x+refreshRect->w<ctrlRect.x+ctrlRect.w)
					refreshRect->w = ctrlRect.x+ctrlRect.w-refreshRect->x;
				if (refreshRect->y+refreshRect->h<ctrlRect.y+ctrlRect.h)
					refreshRect->h = ctrlRect.y+ctrlRect.h-refreshRect->y;
			}

			pLstItem = pLstItem->pNext;
		}
	}


	if (bDetectOutTTCtrl) {
		if (m_pTTCtrl!=NULL)
			bNeedRefresh = true;
		m_pTTCtrl = NULL;
		m_nToolTipsEventDelay = 0;
		refreshRect->x = 0;
		refreshRect->y = 0;
		refreshRect->w = m_nWidth;
		refreshRect->h = m_nHeight;
	}

	return bNeedRefresh;
}

// ---------------------------------------------------------------------------
// Function: GetSize
//
// Return dialog box size.
// ---------------------------------------------------------------------------
void CGDialog::GetSize( int *nWidth, int *nHeight )
{
	if (nWidth!=NULL) *nWidth = m_nWidth;
	if (nHeight!=NULL) *nHeight = m_nHeight;
}

// ---------------------------------------------------------------------------
// Function: GetControl
//
// Return pointer to a control base on its IDC.
// ---------------------------------------------------------------------------
CGControl *CGDialog::GetControl( int nControlIDC )
{
	PCONTROL_LIST	pCtrl;
	pCtrl = m_pCtrlLstHead;
	while(pCtrl!=NULL)
	{
		if (pCtrl->pControl->GetControlID()==nControlIDC)
			return pCtrl->pControl;
		pCtrl = pCtrl->pNext;
	}

	DEBUG_PRINT("GetControl failed to found IDC=%d", nControlIDC);
	return NULL;
}

// ---------------------------------------------------------------------------
// Function: SetTab
//
// Default function (1 tab by default, otherwise this function is overwrite
// by the class which derive from it).
// ---------------------------------------------------------------------------
bool CGDialog::SetTab( int nTab )
{
	if (nTab==0) return true;
	return false;
}

// ---------------------------------------------------------------------------
// Function: Paint
//
// Draw background and controls over it.
// ---------------------------------------------------------------------------
void CGDialog::Paint( wxDC *pDC, PREFRESH_RECT refreshRect )
{
	PCONTROL_LIST	pCtrlListItem = m_pCtrlLstHead;

	if (refreshRect->w==0 || refreshRect->h==0)
		return;

	// --- Paint Background on Dialog Box ---
	m_memDC.Blit( refreshRect->x, refreshRect->y, 
		refreshRect->w, refreshRect->h, m_pSkinMemDC, refreshRect->x, refreshRect->y);

	// --- Paint each controls ---
	while(pCtrlListItem!=NULL) {
		pCtrlListItem->pControl->Paint(&m_memDC,refreshRect);
		pCtrlListItem = pCtrlListItem->pNext;
	}

	// --- Paint Tool-Tip on Top of Controls ---
	PaintToolTips(&m_memDC);

	// --- Paint what it has been draw on Mem DC ---
	if (pDC!=NULL)
		pDC->Blit( 0, 0, m_nWidth, m_nHeight, &m_memDC, 0, 0);

}

// ---------------------------------------------------------------------------
// Function: GetEvent
//
// Retrieve a new event from the list, in order to be process by the caller.
// ---------------------------------------------------------------------------
bool CGDialog::GetEvent( int *nControlID, int *nMsg, unsigned long *ulParam1, unsigned long *ulParam2 )
{
	if (m_eventList.nIndexRead==m_eventList.nIndexWrite)
		return false;
	if (nControlID==NULL || nMsg==NULL || ulParam1==NULL || ulParam2==NULL)
		return false;

	*nControlID = m_eventList.pEventList[m_eventList.nIndexRead].nControlID;
	*nMsg = m_eventList.pEventList[m_eventList.nIndexRead].nMsg;
	*ulParam1 = m_eventList.pEventList[m_eventList.nIndexRead].ulParam1;
	*ulParam2 = m_eventList.pEventList[m_eventList.nIndexRead].ulParam2;
	m_eventList.nIndexRead = (m_eventList.nIndexRead+1)%m_eventList.nMaxCount;
	return true;
}

// ---------------------------------------------------------------------------
// Function: GetDelayForNextToolTipsEvent
//
// Get delay for next tooltips event.
// ---------------------------------------------------------------------------
int CGDialog::GetDelayForNextToolTipsEvent( void )
{
	return m_nToolTipsEventDelay;
}

// ---------------------------------------------------------------------------
// Function: PaintToolTips
//
// Paint the tooltips control.
// ---------------------------------------------------------------------------
#define MAX_LINES	15
void CGDialog::PaintToolTips( wxDC *pDC )
{
	wxColour penCol(0,0,0);
	wxColour brushCol(255, 255, 200);
	wxPen	pen(penCol);
	wxBrush	brush(brushCol);
	wxSize	size;
	int	left, right, top, bottom, nToolTipsWidth;
	char	szLine[MAX_LINES][512], szOneChar[2], szToolTips[MAX_TOOLTIPS_LENGTH];
	int	i, j, k, nLineHeight;
	unsigned long	ulDelayShow, ulDelayHide;
	wxFont	font(8, wxFONTFAMILY_DEFAULT, wxFONTSTYLE_NORMAL, wxFONTWEIGHT_NORMAL);
	unsigned long	ulCurTime;
	wxDateTime now = wxDateTime::UNow();
	ulCurTime = now.GetMillisecond();
	ulCurTime+=now.GetSecond()*1000;
	ulCurTime+=now.GetMinute()*1000*60;
	ulCurTime+=now.GetHour()*1000*60*60;
	ulCurTime+=now.GetDayOfYear()*1000*60*60*24;

	if (m_ulTTTimeStart+m_ulTTDelayShow<ulCurTime) {
		if (m_ulTTTimeStart+m_ulTTDelayShow+m_ulTTDelayHide<ulCurTime)
			m_nToolTipsEventDelay = 0;
		else
			m_nToolTipsEventDelay = m_ulTTDelayHide;
	}

	if (m_pTTCtrl==NULL || m_ulTTTimeStart+m_ulTTDelayShow>ulCurTime ||
		m_ulTTTimeStart+m_ulTTDelayHide<ulCurTime) {
		return;
	}

	m_pTTCtrl->GetToolTips(szToolTips, &nToolTipsWidth, &ulDelayShow, &ulDelayHide);
	if (strlen(szToolTips)==0) return;

	if (nToolTipsWidth<1)
		nToolTipsWidth = m_nToolTipsWidth;

	left = m_nTTPosX;
	top = m_nTTPosY;
	pDC->SetPen(pen);
	pDC->SetBrush(brushCol);
	pDC->SetFont(font);
	pDC->SetTextForeground(penCol);
	size = pDC->GetTextExtent(FONT_HEIGHT_STRING);
	nLineHeight = size.GetHeight();
	size = pDC->GetTextExtent(szToolTips);
	if (size.GetWidth()<nToolTipsWidth)
		right = left + size.GetWidth()+6;
	else
		right = left + nToolTipsWidth+6;
	bottom = top +6;
	for(i=0;i<MAX_LINES;++i)
		szLine[i][0] = '\0';

	j = 0;
	szOneChar[1] = 0;
	for(i=0;j<MAX_LINES && i<(int) strlen(szToolTips);++i)
	{
		szOneChar[0] = szToolTips[i];
		if (szToolTips[i]=='\n') {
			++j;
		}
		else {
			strcat(szLine[j], szOneChar);
			size = pDC->GetTextExtent(szLine[j]);
			if (size.GetWidth()>nToolTipsWidth) {
				k = 1;
				while(szLine[j][strlen(szLine[j])-k]!=' ')
					++k;
				szLine[j][strlen(szLine[j])-k] = '\0';
				i-=k;
				while(szToolTips[i+1]==' ')
					++i;

				++j;
			}
		}
	}
	++j;
	bottom+=j*nLineHeight;

	if (left-(right-left)>0) {
		k = left;
		left -= right-left;
		right = k;
	}
	if (top-(bottom-top)>0) {
		k = top;
		top -= bottom-top;
		bottom = k;
	}

	pDC->DrawRectangle(left, top, right-left, bottom-top);
	for(i=0;i<MAX_LINES;++i) {
		if (strlen(szLine[i])>0) {
			pDC->DrawText(szLine[i], left+3, top+3+i*nLineHeight);
		}
	}
}

// ---------------------------------------------------------------------------
// Function: InitializeDlgState
//
// Set basic pointers, so other functions can access it. Those pointers need
// to stay valid until the destruction of the dialog box.
// ---------------------------------------------------------------------------
void CGDialog::InitializeDlgState( DJ_DEVICE_STATE *pDeviceState, CDManager *pDeviceManager )
{
	m_pDManager = pDeviceManager;
	m_pDeviceState = pDeviceState;
}

// ---------------------------------------------------------------------------
// Function: ConvertBCDtoInt
//
// Convert binary-coded-decimal to integer (maximum 2 digits).
// ---------------------------------------------------------------------------
int CGDialog::ConvertBCDtoInt( int nBCD )
{
	int nNumber;

	nNumber = (nBCD/16)*10 + (nBCD%16);
	return nNumber;
}


