/////////////////////////////////////////////////////////////////////////////
// Name:        gslider.cpp
// Purpose:     GUI slider implementation using wxWidgets.
// Author:      Yann Hamiaux
// Modified by: -
// Created:     03/21/2008
// Copyright:   Written for Guillemot Corporation by Yann Hamiaux
// Licence:     The GNU General Public License v2+.
/////////////////////////////////////////////////////////////////////////////
#include "gslider.h"

CGSlider::CGSlider(PEVENT_LIST pEventList, int nControlID, int nPosX, int nPosY, int nWidth, int nHeight,
			wxMemoryDC *pSkinMemDC, wxMemoryDC *pSkinAlphaMemDC, PSLIDER_INFO pInfo) :
	CGControl(pEventList, nControlID, GCONTROL_TYPE_SLIDER, nPosX, nPosY, nWidth, nHeight)
{
	int		i;

	m_pSkinMemDC = pSkinMemDC;
	m_pSkinAlphaMemDC = pSkinAlphaMemDC;
	m_nRangeMin = 0;
	m_nRangeMax = 100;
	m_nPos = 0;
	m_bMouseThumbMove = false;
	m_bMouseNextAllowThumbMove = false;

	m_nCurrentState = SLIDER_STATE_NORMAL;
	m_pInfo = new SLIDER_INFO;
	m_pInfo->nHorizontal = pInfo->nHorizontal;
	m_pInfo->nProcessAlpha = pInfo->nProcessAlpha;
	m_pInfo->nThumbOffsetX = pInfo->nThumbOffsetX;
	m_pInfo->nThumbOffsetY = pInfo->nThumbOffsetY;
	m_pInfo->nBorderSizeAtMax = pInfo->nBorderSizeAtMax;
	m_pInfo->nBorderSizeAtMin = pInfo->nBorderSizeAtMin;
	for(i=0;i<4;++i) {
		m_pInfo->coordinates[i].x = pInfo->coordinates[i].x;
		m_pInfo->coordinates[i].y = pInfo->coordinates[i].y;
		m_pInfo->coordinates[i].x_highlight = pInfo->coordinates[i].x_highlight;
		m_pInfo->coordinates[i].y_highlight = pInfo->coordinates[i].y_highlight;
		m_pInfo->coordinates[i].thumb_x = pInfo->coordinates[i].thumb_x;
		m_pInfo->coordinates[i].thumb_y = pInfo->coordinates[i].thumb_y;
		m_pInfo->coordinates[i].thumb_w = pInfo->coordinates[i].thumb_w;
		m_pInfo->coordinates[i].thumb_h = pInfo->coordinates[i].thumb_h;
	}
}

CGSlider::~CGSlider(void)
{
	if (m_pInfo!=NULL) {
		delete m_pInfo;
	}
}

// ---------------------------------------------------------------------------
// Function: MouseEvent
//
// Process mouse events (button click, mouse over, ...) within the slider.
// ---------------------------------------------------------------------------
bool CGSlider::MouseEvent( int x, int y, int button, bool *bMouseOverCtrl, PREFRESH_RECT pRefreshRect )
{
	int		nValue, nPrevPos;
	int		nEffectiveLength;
	bool	bPrevMouseThumbMove;

	if (bMouseOverCtrl==NULL)
		return false;

	*bMouseOverCtrl = false;
	if (m_bHide || m_nCurrentState==SLIDER_STATE_DISABLE)
		return false;

	nPrevPos = m_nPos;
	CGControl::MouseEvent(x,y,button,bMouseOverCtrl,pRefreshRect);

	bPrevMouseThumbMove = m_bMouseThumbMove;

	if (m_bMouseNextAllowThumbMove && *bMouseOverCtrl && !m_bMouseThumbMove && (button&GMOUSE_LEFT_DOWN))
		m_bMouseThumbMove = true;
	else if (!(button&GMOUSE_LEFT_DOWN) && m_bMouseThumbMove)
		m_bMouseThumbMove = false;

	m_bMouseNextAllowThumbMove = (*bMouseOverCtrl && !(button&GMOUSE_LEFT_DOWN));


	if (m_bMouseThumbMove) {
		if (m_pInfo->nHorizontal) {
			nEffectiveLength = m_nWidth - (m_pInfo->nBorderSizeAtMin+m_pInfo->nBorderSizeAtMax + 
				m_pInfo->coordinates[m_nCurrentState].thumb_w);
			nValue = x-(m_nPosX+m_pInfo->nBorderSizeAtMin+m_pInfo->coordinates[m_nCurrentState].thumb_w/2);
			if (nValue<0) nValue = 0;

			if (nValue<m_nWidth-(m_pInfo->nBorderSizeAtMin+m_pInfo->nBorderSizeAtMax + 
				m_pInfo->coordinates[m_nCurrentState].thumb_w/2))
			{
				m_nPos = (m_nRangeMax-m_nRangeMin) * 
					(nValue+nEffectiveLength/(2*(m_nRangeMax-m_nRangeMin))) / nEffectiveLength
					+ m_nRangeMin;
				if (m_nPos>m_nRangeMax)
					m_nPos = m_nRangeMax;
			}
			else
				m_nPos = m_nRangeMax;
		}
		else {
			nEffectiveLength = m_nHeight-(m_pInfo->nBorderSizeAtMin+m_pInfo->nBorderSizeAtMax + 
				m_pInfo->coordinates[m_nCurrentState].thumb_h);
			nValue = y-(m_nPosY+m_pInfo->nBorderSizeAtMax+m_pInfo->coordinates[m_nCurrentState].thumb_h/2);
			if (nValue<0)
				nValue = 0;
			if (nValue<m_nHeight-(m_pInfo->nBorderSizeAtMin+m_pInfo->nBorderSizeAtMax + 
				m_pInfo->coordinates[m_nCurrentState].thumb_h/2)) {
				m_nPos = (m_nRangeMax-m_nRangeMin) * 
					(nValue+nEffectiveLength/(2*(m_nRangeMax-m_nRangeMin))) / nEffectiveLength
					+ m_nRangeMin;
				if (m_nPos>m_nRangeMax)
					m_nPos = m_nRangeMax;
			}
			else
				m_nPos = m_nRangeMax;
			m_nPos = m_nRangeMax-m_nPos;

		}
		if (m_nPos!=nPrevPos) {
			if (m_bMouseThumbMove && m_bMouseThumbMove!=bPrevMouseThumbMove)
				SetEvent(GEVENT_SLIDER_CLICK, m_nPos, 0);
			if (button&GMOUSE_LEFT_DCLICK && (*bMouseOverCtrl))
				SetEvent(GEVENT_SLIDER_DCLICK, m_nPos, 0);
			SetEvent(GEVENT_SLIDER_MOVE, m_nPos, 0);
			return true;
		}
	}

	if (button&GMOUSE_LEFT_DCLICK && (*bMouseOverCtrl))
		SetEvent(GEVENT_SLIDER_DCLICK, m_nPos, 0);

	return false;
}

// ---------------------------------------------------------------------------
// Function: Enable
// ---------------------------------------------------------------------------
void CGSlider::Enable( bool bEnable )
{
	CGControl::Enable(bEnable);
	if (!m_bEnable)
		m_nCurrentState = SLIDER_STATE_DISABLE;
	else
		m_nCurrentState = SLIDER_STATE_NORMAL;
}

// ---------------------------------------------------------------------------
// Function: Paint
//
// Draw a horizontal or vertical slider with the thumb located at the
// slider position.
// ---------------------------------------------------------------------------
void CGSlider::Paint( wxDC *pDC, PREFRESH_RECT refreshRect )
{
	int		nThumbPos, nAdjustSize;
	if (m_bHide || pDC==NULL || m_pSkinMemDC==NULL || m_pInfo==NULL)
		return;

	// --- If button is outside of the region, do not refresh it ---
	if (refreshRect->x>m_nPosX+m_nWidth || refreshRect->x+refreshRect->w<m_nPosX)
		return;
	if (refreshRect->y>m_nPosY+m_nHeight || refreshRect->y+refreshRect->h<m_nPosY)
		return;

	if (m_pInfo->nHorizontal) {
		// --- Compute Position in pixel considering the Width ---
		nThumbPos = (m_nWidth - 
			(m_pInfo->nBorderSizeAtMin+m_pInfo->nBorderSizeAtMax+m_pInfo->coordinates[m_nCurrentState].thumb_w))
			* (m_nPos-m_nRangeMin) / (m_nRangeMax-m_nRangeMin);

		// --- Draw Background from RangeMin to Current Position ---
		nAdjustSize = nThumbPos + m_pInfo->nBorderSizeAtMax + m_pInfo->coordinates[m_nCurrentState].thumb_w/2;

		// --- Draw Background from Current Position to RangeMax ---
		if (m_pInfo->nProcessAlpha) {
			pDC->Blit(
				m_nPosX, 
				m_nPosY, 
				nAdjustSize, 
				m_nHeight, 
				m_pSkinAlphaMemDC, 
				m_pInfo->coordinates[m_nCurrentState].x_highlight, 
				m_pInfo->coordinates[m_nCurrentState].y_highlight, 
				wxAND);
			pDC->Blit(
				m_nPosX, 
				m_nPosY, 
				nAdjustSize, 
				m_nHeight, 
				m_pSkinMemDC, 
				m_pInfo->coordinates[m_nCurrentState].x_highlight, 
				m_pInfo->coordinates[m_nCurrentState].y_highlight, 
				wxOR);

			pDC->Blit(
				m_nPosX+nAdjustSize,
				m_nPosY,
				m_nWidth-nAdjustSize,
				m_nHeight,
				m_pSkinAlphaMemDC,
				m_pInfo->coordinates[m_nCurrentState].x+nAdjustSize,
				m_pInfo->coordinates[m_nCurrentState].y,
				wxAND);
			pDC->Blit(
				m_nPosX+nAdjustSize,
				m_nPosY,
				m_nWidth-nAdjustSize,
				m_nHeight,
				m_pSkinMemDC,
				m_pInfo->coordinates[m_nCurrentState].x+nAdjustSize,
				m_pInfo->coordinates[m_nCurrentState].y,
				wxOR);
		}
		else {
			pDC->Blit(
				m_nPosX, 
				m_nPosY, 
				nAdjustSize, 
				m_nHeight, 
				m_pSkinMemDC, 
				m_pInfo->coordinates[m_nCurrentState].x_highlight, 
				m_pInfo->coordinates[m_nCurrentState].y_highlight, 
				wxCOPY);
			pDC->Blit(
				m_nPosX+nAdjustSize,
				m_nPosY,
				m_nWidth-nAdjustSize,
				m_nHeight,
				m_pSkinMemDC,
				m_pInfo->coordinates[m_nCurrentState].x+nAdjustSize,
				m_pInfo->coordinates[m_nCurrentState].y,
				wxCOPY);
		}

		// --- Draw Thumb ---
		if (m_pInfo->nProcessAlpha) {
			pDC->Blit(
				m_nPosX + nAdjustSize - m_pInfo->coordinates[m_nCurrentState].thumb_w/2 + m_pInfo->nThumbOffsetX, 
				m_nPosY + (m_nHeight-m_pInfo->coordinates[m_nCurrentState].thumb_h)/2 + m_pInfo->nThumbOffsetY, 
				m_pInfo->coordinates[m_nCurrentState].thumb_w, 
				m_pInfo->coordinates[m_nCurrentState].thumb_h, 
				m_pSkinAlphaMemDC, 
				m_pInfo->coordinates[m_nCurrentState].thumb_x, 
				m_pInfo->coordinates[m_nCurrentState].thumb_y, 
				wxAND);
			pDC->Blit(
				m_nPosX + nAdjustSize - m_pInfo->coordinates[m_nCurrentState].thumb_w/2 + m_pInfo->nThumbOffsetX, 
				m_nPosY + (m_nHeight-m_pInfo->coordinates[m_nCurrentState].thumb_h)/2 + m_pInfo->nThumbOffsetY, 
				m_pInfo->coordinates[m_nCurrentState].thumb_w, 
				m_pInfo->coordinates[m_nCurrentState].thumb_h, 
				m_pSkinMemDC, 
				m_pInfo->coordinates[m_nCurrentState].thumb_x, 
				m_pInfo->coordinates[m_nCurrentState].thumb_y, 
				wxOR);
		}
		else {
			pDC->Blit(
				m_nPosX + nAdjustSize - m_pInfo->coordinates[m_nCurrentState].thumb_w/2 + m_pInfo->nThumbOffsetX, 
				m_nPosY + (m_nHeight-m_pInfo->coordinates[m_nCurrentState].thumb_h)/2 + m_pInfo->nThumbOffsetY, 
				m_pInfo->coordinates[m_nCurrentState].thumb_w, 
				m_pInfo->coordinates[m_nCurrentState].thumb_h, 
				m_pSkinMemDC, 
				m_pInfo->coordinates[m_nCurrentState].thumb_x, 
				m_pInfo->coordinates[m_nCurrentState].thumb_y, 
				wxCOPY);
		}
	}
	else {
		// --- Compute Position in pixel considering the Height ---
		nThumbPos = (m_nHeight - 
			(m_pInfo->nBorderSizeAtMin+m_pInfo->nBorderSizeAtMax+m_pInfo->coordinates[m_nCurrentState].thumb_h))
			* (m_nRangeMax - m_nPos) / (m_nRangeMax-m_nRangeMin);

		// --- Draw Background from RangeMin to Current Position ---
		nAdjustSize = nThumbPos + m_pInfo->nBorderSizeAtMax + m_pInfo->coordinates[m_nCurrentState].thumb_h/2;
		if (m_pInfo->nProcessAlpha) {
			pDC->Blit(
				m_nPosX, 
				m_nPosY + nAdjustSize, 
				m_nWidth, 
				m_nHeight - nAdjustSize, 
				m_pSkinAlphaMemDC, 
				m_pInfo->coordinates[m_nCurrentState].x_highlight, 
				m_pInfo->coordinates[m_nCurrentState].y_highlight + nAdjustSize, 
				wxAND);
			pDC->Blit(
				m_nPosX, 
				m_nPosY + nAdjustSize, 
				m_nWidth, 
				m_nHeight - nAdjustSize, 
				m_pSkinMemDC, 
				m_pInfo->coordinates[m_nCurrentState].x_highlight, 
				m_pInfo->coordinates[m_nCurrentState].y_highlight + nAdjustSize, 
				wxOR);

			// --- Draw Background from Current Position to RangeMax ---
			pDC->Blit(
				m_nPosX,
				m_nPosY,
				m_nWidth,
				nAdjustSize,
				m_pSkinAlphaMemDC,
				m_pInfo->coordinates[m_nCurrentState].x,
				m_pInfo->coordinates[m_nCurrentState].y,
				wxAND);
			pDC->Blit(
				m_nPosX,
				m_nPosY,
				m_nWidth,
				nAdjustSize,
				m_pSkinMemDC,
				m_pInfo->coordinates[m_nCurrentState].x,
				m_pInfo->coordinates[m_nCurrentState].y,
				wxOR);
		}
		else {
			pDC->Blit(
				m_nPosX, 
				m_nPosY + nAdjustSize, 
				m_nWidth, 
				m_nHeight - nAdjustSize, 
				m_pSkinMemDC, 
				m_pInfo->coordinates[m_nCurrentState].x_highlight, 
				m_pInfo->coordinates[m_nCurrentState].y_highlight + nAdjustSize, 
				wxCOPY);

			// --- Draw Background from Current Position to RangeMax ---
			pDC->Blit(
				m_nPosX,
				m_nPosY,
				m_nWidth,
				nAdjustSize,
				m_pSkinMemDC,
				m_pInfo->coordinates[m_nCurrentState].x,
				m_pInfo->coordinates[m_nCurrentState].y,
				wxCOPY);
		}

		// --- Draw Thumb ---
		if (m_pInfo->nProcessAlpha) {
			pDC->Blit(
				m_nPosX + (m_nWidth-m_pInfo->coordinates[m_nCurrentState].thumb_w)/2 + m_pInfo->nThumbOffsetX, 
				m_nPosY + nAdjustSize - m_pInfo->coordinates[m_nCurrentState].thumb_h/2 + m_pInfo->nThumbOffsetY, 
				m_pInfo->coordinates[m_nCurrentState].thumb_w, 
				m_pInfo->coordinates[m_nCurrentState].thumb_h, 
				m_pSkinAlphaMemDC, 
				m_pInfo->coordinates[m_nCurrentState].thumb_x, 
				m_pInfo->coordinates[m_nCurrentState].thumb_y, 
				wxAND);
			pDC->Blit(
				m_nPosX + (m_nWidth-m_pInfo->coordinates[m_nCurrentState].thumb_w)/2 + m_pInfo->nThumbOffsetX, 
				m_nPosY + nAdjustSize - m_pInfo->coordinates[m_nCurrentState].thumb_h/2 + m_pInfo->nThumbOffsetY, 
				m_pInfo->coordinates[m_nCurrentState].thumb_w, 
				m_pInfo->coordinates[m_nCurrentState].thumb_h, 
				m_pSkinMemDC, 
				m_pInfo->coordinates[m_nCurrentState].thumb_x, 
				m_pInfo->coordinates[m_nCurrentState].thumb_y, 
				wxOR);
		}
		else {
			pDC->Blit(
				m_nPosX + (m_nWidth-m_pInfo->coordinates[m_nCurrentState].thumb_w)/2 + m_pInfo->nThumbOffsetX, 
				m_nPosY + nAdjustSize - m_pInfo->coordinates[m_nCurrentState].thumb_h/2 + m_pInfo->nThumbOffsetY, 
				m_pInfo->coordinates[m_nCurrentState].thumb_w, 
				m_pInfo->coordinates[m_nCurrentState].thumb_h, 
				m_pSkinMemDC, 
				m_pInfo->coordinates[m_nCurrentState].thumb_x, 
				m_pInfo->coordinates[m_nCurrentState].thumb_y, 
				wxCOPY);
		}
	}
}

// ---------------------------------------------------------------------------
// Function: SetRange
// ---------------------------------------------------------------------------
void CGSlider::SetRange( int nMin, int nMax )
{
	m_nRangeMin = nMin;
	m_nRangeMax = nMax;
	if (m_nRangeMax<m_nRangeMin)
		m_nRangeMin = m_nRangeMax;
}

// ---------------------------------------------------------------------------
// Function: GetRange
// ---------------------------------------------------------------------------
void CGSlider::GetRange( int *nMin, int *nMax )
{
	*nMin = m_nRangeMin;
	*nMax = m_nRangeMax;
}

// ---------------------------------------------------------------------------
// Function: SetPos
// ---------------------------------------------------------------------------
void CGSlider::SetPos( int nPos )
{
	m_nPos = nPos;
	if (m_nPos<m_nRangeMin)
		m_nPos = m_nRangeMin;
	if (m_nPos>m_nRangeMax)
		m_nPos = m_nRangeMax;
}

// ---------------------------------------------------------------------------
// Function: GetPos
// ---------------------------------------------------------------------------
int CGSlider::GetPos( void )
{
	return m_nPos;
}

