/////////////////////////////////////////////////////////////////////////////
// Name:        gslider.h
// Purpose:     GUI slider implementation using wxWidgets.
// Author:      Yann Hamiaux
// Modified by: -
// Created:     03/21/2008
// Copyright:   Written for Guillemot Corporation by Yann Hamiaux
// Licence:     The GNU General Public License v2+.
/////////////////////////////////////////////////////////////////////////////
#include "gcontrol.h"

#ifndef _GUILLEMOT_SLIDER_H_
#define _GUILLEMOT_SLIDER_H_


#define SLIDER_STATE_DISABLE		0
#define SLIDER_STATE_NORMAL		1
#define SLIDER_STATE_HIGHLIGHT		2
#define SLIDER_STATE_PRESSED		3

typedef struct SLIDER_COORDINATE
{
	int		x, y;
	int		x_highlight, y_highlight;
	int		thumb_x, thumb_y;
	int		thumb_w, thumb_h;
} SLIDER_COORDINATE, *PSLIDER_COORDINATE;

typedef struct SLIDER_INFO
{
	SLIDER_COORDINATE	coordinates[4];
	int nProcessAlpha;	// 0 if we don't need to process alpha.
	int nHorizontal;	// Horizontal/Vertical.
	int nThumbOffsetX, nThumbOffsetY;
	int nBorderSizeAtMin, nBorderSizeAtMax;
} SLIDER_INFO, *PSLIDER_INFO;


class CGSlider : public CGControl
{
public:
	CGSlider( PEVENT_LIST pEventList, int nControlID, int nPosX, int nPosY, int nWidth, int nHeight,
			wxMemoryDC *pSkinMemDC, wxMemoryDC *pSkinAlphaMemDC, PSLIDER_INFO pInfo );
	virtual ~CGSlider(void);

	bool MouseEvent( int x, int y, int button, bool *bMouseOverCtrl, PREFRESH_RECT pRefreshRect );
	void Enable( bool bEnable );

	void Paint( wxDC *pDC, PREFRESH_RECT refreshRect );
	void SetRange( int nMin, int nMax );
	void GetRange( int *nMin, int *nMax );

	void SetPos( int nPos );
	int  GetPos( void );

protected:
	wxMemoryDC	*m_pSkinMemDC, *m_pSkinAlphaMemDC;
	PSLIDER_INFO	 m_pInfo;
	int		 m_nRangeMin, m_nRangeMax, m_nPos;
	int		 m_nCurrentState;
	bool		 m_bMouseThumbMove, m_bMouseNextAllowThumbMove;
};

#endif

